-- ARCHIVO CON LAS ACTUALIZACIONES DE DATA DE SQL PARA MIGRAR AL NUEVO BUILD DEL NOMBRE DE LA CARPETA
-- DECLARAMOS DOS VARIABLES, UNA CON LA VERSION DE LA QUE PARTIMOS Y OTRA CON LA NUEVA VERSION QUE ESTAMOS APUNTANDO
DECLARE @OLD_DATABASE_BUILD_VERSION VARCHAR(50) = '2.1.1'
DECLARE @NEW_DATABASE_BUILD_VERSION VARCHAR(50) = '2.1.2'

-- INICIAMOS UN TRY PARA EL CASO CAIGA EN CATCH HAGAMOS ROLLBACK
BEGIN TRY
    -- VALIDAMOS QUE LA VERSION EXISTENTE COINCIDE CON NUESTRA NEW_DATABASE_BUILD_VERSION
    IF NOT EXISTS (
        SELECT 1 
            FROM [dbo].[Version] V 
            WHERE V.[BuildVersion] = @OLD_DATABASE_BUILD_VERSION
    )	
        -- LANZAMOS UN MENSAJE DE ERROR INDICANDO QUE LA VERSION ACTUAL NO COINCIDE CON LA OLD_DATABASE_BUILD_VERSION
        RAISERROR('DATABASE_ERROR_INCORRECT_TARGET_VERSION', 16, 16)
        
    -- INICIAMOS LA TRANSACCION
    BEGIN TRANSACTION




    -- AQUI EMPIEZA LA SECCION CON LOS INSERT/UPDATE/DELETE PARA LA NUEVA VERSION
    --Actualizar las queries por defecto de los vccs existentes con la version =1

    --CORREGIR QUERY \"line\" POR line ANTES DE PASAR A LA VERSION 1 en el vcc system

    UPDATE [dbo].[GenericQuery] SET [Query] = 'line' where [Description] ='buy' 

	--CORREGIR system cambiar querys ingles de v=2  a v=1
	UPDATE [dbo].[GenericQuery] SET [version] = 1 where [Description] in ('buy','hello') and [vcc]='system'

    --Actualizar a version 1 y prefijos a en todas las query en ingles por defecto

    UPDATE [dbo].[GenericQuery] SET [version] = 1, [name] = 'en_'+[name] where [Description] in ('buy','hello') and [vcc] <>'system'

    --Actualizar a version 1 y prefijos a en todas las query en espaniol por defecto

    UPDATE [dbo].[GenericQuery] SET [version] = 1, [name] = 'es_'+[name] where [Description] in ('compro','hola') and [vcc] <> 'system'


    --Crear Data por defecto para todos los vccs existentes
    
    DECLARE @vcc varchar(50)
    CREATE TABLE #TempGenericQuery
    (
    [VCC] [varchar](50) NOT NULL,
        [Name] [varchar](50) NOT NULL,
        [Description] [varchar](500) NULL,
        [Query] [varchar](max) NULL,
        [RawData] [varchar](max) NULL,
        [CreatedDate] [datetime] NULL,
        [CreatedByUserId] [varchar](50) NULL,
        [LastModifiedDate] [datetime] NULL,
        [LastModifiedByUserId] [varchar](50) NULL,
        [TimeStamp] [datetime] NULL,
        [Version] [smallint] NULL
        
    )
    
    DECLARE vcc_cursor CURSOR FOR   
    SELECT [vcc]
    FROM [dbo].[VCC]  
    WHERE [vcc] <> 'system'  

    
    OPEN vcc_cursor  
    
    FETCH NEXT FROM vcc_cursor   
    INTO @vcc
    
    WHILE @@FETCH_STATUS = 0  
    BEGIN  
        
        --insertamos en una temporal solo la configuracion de genericquery faltante para el vcc actual
        insert into #TempGenericQuery
        select @vcc,name,description,query, rawdata,getutcdate(),'analytic',getutcdate(), 'analytic',getutcdate(),1 	
        from 
        [dbo].[GenericQuery] where [vcc] = 'system' and [description] not in(select [Description] from [dbo].[GenericQuery] where [vcc] = @vcc and [Description] in ('compro','hola','buy','hello'))
    
       
        
        FETCH NEXT FROM vcc_cursor   
        INTO @vcc  
    END   
    CLOSE vcc_cursor;  
    DEALLOCATE vcc_cursor


    INSERT INTO [dbo].[GenericQuery]
    SELECT * FROM #TempGenericQuery


    DROP TABLE  #TempGenericQuery

    
    


    -- AQUI TERMINA LA SECCION CON LOS INSERT/UPDATE/DELETE PARA LA NUEVA VERSION


    

    -- TERMINAMOS LA ACTUALIZACION DE DATA ACTUALIZANDO EL BUILDVERSION
    UPDATE [dbo].[Version] 
        SET [BuildVersion] = @NEW_DATABASE_BUILD_VERSION, 
            [IsRegistered] = 0,
            [TimeStamp] = GETUTCDATE() 
        WHERE [BuildVersion] = @OLD_DATABASE_BUILD_VERSION
    PRINT 'UPDATED_DATABASE_BUILD_VERSION'

    -- COMPLETAMOS LA TRANSACCION
    COMMIT TRANSACTION
END TRY
BEGIN CATCH
    IF @@TRANCOUNT > 0 ROLLBACK TRANSACTION

    DECLARE @Message nvarchar(2048) = ERROR_MESSAGE()
    DECLARE @Severity integer = ERROR_SEVERITY()
    DECLARE @State integer = ERROR_STATE()

    RAISERROR(@Message, @Severity, @State)
    --RETURN -1
END CATCH



