PRINT N'Iniciando recompilación de la tabla [dbo].[Study]...';


GO
BEGIN TRANSACTION;

SET TRANSACTION ISOLATION LEVEL SERIALIZABLE;

SET XACT_ABORT ON;

CREATE TABLE [dbo].[tmp_ms_xx_Study] (
    [VCC]                  VARCHAR (50)  NOT NULL,
    [ProcessId]            VARCHAR (50)  NOT NULL,
    [TemplateId]           VARCHAR (50)  NOT NULL,
    [Name]                 VARCHAR (200) NOT NULL,
    [Description]          VARCHAR (100) NULL,
    [Total]                INT           NULL,
    [Progress]             INT           NULL,
    [Error]                INT           NULL,
    [Percentage]           FLOAT (53)    NULL,
    [StatusDescription]    VARCHAR (MAX) NULL,
    [Status]               FLOAT (53)    NULL,
    [Type]                 VARCHAR (50)  NULL,
    [LastQueryId]          VARCHAR (50)  NULL,
    [ErrorMessage]         VARCHAR (800) NULL,
    [BatchStatus]          VARCHAR (50)  NULL,
    [BatchScheduleId]      VARCHAR (50)  NULL,
    [CreatedDate]          DATETIME      NULL,
    [CreatedByUserId]      VARCHAR (50)  NULL,
    [LastModifiedDate]     DATETIME      NULL,
    [LastModifiedByUserId] VARCHAR (50)  NULL,
    [TimeStamp]            DATETIME      NULL,
    CONSTRAINT [tmp_ms_xx_constraint_PK_Study_11] PRIMARY KEY CLUSTERED ([VCC] ASC, [ProcessId] ASC, [TemplateId] ASC, [Name] ASC)
);

IF EXISTS (SELECT TOP 1 1 
           FROM   [dbo].[Study])
    BEGIN
        INSERT INTO [dbo].[tmp_ms_xx_Study] ([VCC], [ProcessId], [TemplateId], [Name], [Description], [Total], [Progress], [Error], [Percentage], [StatusDescription], [Status], [Type], [LastQueryId], [ErrorMessage], [BatchStatus], [CreatedDate], [CreatedByUserId], [LastModifiedDate], [LastModifiedByUserId], [TimeStamp])
        SELECT   [VCC],
                 [ProcessId],
                 [TemplateId],
                 [Name],
                 [Description],
                 [Total],
                 [Progress],
                 [Error],
                 [Percentage],
                 [StatusDescription],
                 [Status],
                 [Type],
                 [LastQueryId],
                 [ErrorMessage],
                 [BatchStatus],
                 [CreatedDate],
                 [CreatedByUserId],
                 [LastModifiedDate],
                 [LastModifiedByUserId],
                 [TimeStamp]
        FROM     [dbo].[Study]
        ORDER BY [VCC] ASC, [ProcessId] ASC, [TemplateId] ASC, [Name] ASC;
    END

DROP TABLE [dbo].[Study];

EXECUTE sp_rename N'[dbo].[tmp_ms_xx_Study]', N'Study';

EXECUTE sp_rename N'[dbo].[tmp_ms_xx_constraint_PK_Study_11]', N'PK_Study_1', N'OBJECT';

COMMIT TRANSACTION;

SET TRANSACTION ISOLATION LEVEL READ COMMITTED;


GO
PRINT N'Modificando [dbo].[BulkProgress]...';


GO
ALTER PROCEDURE [dbo].[BulkProgress]
AS
BEGIN
	
	INSERT INTO [Progress] ([Key]
		  ,[VCC]
		  ,[ProcessId]
		  ,[Type]
		  ,[TypeId]
		  ,[Total]
		  ,[Progress]
		  ,[Error]
		  ,[Percentage]
		  ,[StatusDescription])  
	SELECT [Key]
		  ,[VCC]
		  ,[ProcessId]
		  ,[Type]
		  ,[TypeId]
		  ,[Total]
		  ,[Progress]
		  ,[Error]
		  ,[Percentage]
		  ,[StatusDescription]
	  FROM [dbo].[#ProgressTemp]

	-----------ESTADOS DE PROCESS I6UPDATE-----------

	-- ACTUALIZAMOS EL ESTADO GENERAL DE PROCESS SOBRE LA ACTUALIZACION DE INTERACCIONES CALL I6
	UPDATE P 
		SET [Total] = PT.[Total]
			,[progress] = PT.[Progress]
			,[error] = PT.[Error]
			,[percentage] = CASE WHEN PT.[Total] > 0 THEN PT.[Percentage] ELSE 0 END
			,[StatusDescription] = CASE WHEN PT.[Total] >= 0 AND PT.[Percentage] = 1 AND  ISNULL(PT.[Error],0) > 0 THEN 'COMPLETED_WITH_ERROR' 
										WHEN PT.[Total] >= 0 AND PT.[Percentage] = 1 AND  ISNULL(PT.[Error],0) = 0 THEN 'COMPLETED' 
										ELSE  'IN_PROGRESS' END
			,[LastModifiedDate] = GETUTCDATE()
		FROM [dbo].[Process] P
		INNER JOIN [dbo].[#ProgressTemp] PT 
			ON P.[vcc] = PT.[vcc] 
				AND PT.ProcessId = P.[Name] 
		WHERE PT.[Type] = 'i6update'

	-- ACTUALIZAMOS EL ESTADO DEL PROCESS TERMINADO
	UPDATE A
		SET [Status] = CASE 
				WHEN B.total >= 0 AND B.total <= B.[updated] + B.cancel AND B.cancel > B.[updated] THEN 'FAILED' 
				WHEN B.total >= 0 AND B.total <= B.[updated] + B.cancel THEN 'COMPLETE' 
				ELSE 'INPROCESS_I6_UPDATE' 
				END
			,[LastModifiedDate] = GETUTCDATE()
		FROM [dbo].[Process] AS A
		INNER JOIN (
			SELECT SUM(UT.total)									'total',
					SUM(UT.cancel)									'cancel',
					SUM(UT.[updated])								'updated',
					UT.processId									'processId',
					UT.vcc											'vcc'
				FROM (
					SELECT COUNT(1)										'total'
							,COUNT(A.[isCancel])						'cancel'
							,COUNT(IIF(A.[NeedI6Update] = 0, 1, 0))		'updated' 
							,PT.[ProcessId]								'processId'
							,PT.[vcc]									'vcc'
						FROM [dbo].[ProcessAudio] PA (NOLOCK)
						INNER JOIN [#ProgressTemp] PT 
							ON PA.[vcc] = PT.[vcc] 
								AND PA.ProcessId = PT.ProcessId 
								AND PT.[Percentage] = 1
						INNER JOIN [dbo].[Audio] A (NOLOCK) 
							ON PA.[VCC] = A.VCC 
								AND PA.[AudioId] = A.ID 
						WHERE PT.[Type] = 'i6update'
						GROUP BY PT.ProcessId, PT.vcc
				) UT 
				GROUP BY UT.processId, UT.vcc
		) B ON A.[vcc] = B.[vcc] 
			AND A.[Name] = B.[ProcessId]
	  
	------------ESTADOS DE PROCESS ---------------
	UPDATE A
		SET [Total] = PT.[Total]
			,[progress] = PT.[Progress]
			,[error] = PT.[Error]
			,[percentage] = CASE WHEN PT.[Total] > 0 THEN PT.[Percentage] ELSE 0 END
			,[StatusDescription] = CASE WHEN PT.[Total] >= 0 AND PT.[Percentage] = 1 AND  ISNULL(PT.[Error],0) > 0 THEN 'COMPLETED_WITH_ERROR' 
										WHEN PT.[Total] >= 0 AND PT.[Percentage] = 1 AND  ISNULL(PT.[Error],0) = 0 THEN 'COMPLETED' 
										ELSE  'IN_PROGRESS' END
			,[LastModifiedDate] = GETUTCDATE()
		FROM Process AS A
		INNER JOIN [dbo].[#ProgressTemp] PT 
			ON A.[vcc] = PT.[vcc] 
				AND A.[Name] = PT.ProcessId 
		WHERE PT.[Type] IS NULL

	-- ACTUALIZAMOS EL ESTADO DEL PROCESS TERMINADO
	UPDATE A
	SET [Status] = CASE 
			WHEN B.total >= 0 AND B.total <= B.transcription + B.cancel AND B.cancel > B.transcription THEN 'FAILED' 
			WHEN B.total >= 0 AND B.total <= B.transcription + B.cancel THEN 'COMPLETE' 
			ELSE 'INPROCESS_TRANSCRIPTION' 
			END
		,[LastModifiedDate] = GETUTCDATE()
	FROM Process AS A
	INNER JOIN (
		SELECT ISNULL(SUM(UT.total), 0)					'total',
				ISNULL(SUM(UT.cancel), 0)				'cancel',
				ISNULL(SUM(UT.transcription), 0)		'transcription',
				UT.processId							'processId',
				UT.vcc									'vcc'
			FROM (
			SELECT COUNT(1)					total
					,COUNT(C.isCancel)			cancel
					,COUNT(C.IsTranscribed)		transcription 
					,B.ProcessId				processId
					,B.vcc						vcc
				FROM [ProcessAudio] A (NOLOCK)
				INNER JOIN [#ProgressTemp] B 
					ON A.[vcc] = B.[vcc] 
						AND A.ProcessId = B.ProcessId 
						-- AND B.[Percentage] = 1 -- ESTA LINEA NO PERMITE ACTUALIZAR LA COLUMNA STATUS CUANDO EL PROCESS AUN NO TERMINA
				INNER JOIN Audio C (NOLOCK) 
					ON A.VCC = C.VCC 
						AND A.AudioId =C.ID 
						AND ISNULL(A.Section,0) = ISNULL(C.Section,0) 
						AND ISNULL(A.Part,0) = ISNULL(C.Part,0)
				WHERE B.[Type] IS NULL
				GROUP BY B.ProcessId, B.vcc
			UNION
			SELECT 
				COUNT(1)						total
				,COUNT(AI.IsCancel)			cancel
				,COUNT(AI.IsTranscribed)		transcription
				,PT.[ProcessId]				processId
				,PT.[vcc]						vcc
				FROM [ProcessAsyncInteraction] PAI (NOLOCK)
				INNER JOIN [#ProgressTemp] PT
					ON PAI.[VCC] = PT.[vcc]
						AND PAI.[ProcessId] = PT.[ProcessId]
						-- AND PT.[Percentage] = 1 -- ESTA LINEA NO PERMITE ACTUALIZAR LA COLUMNA STATUS CUANDO EL PROCESS AUN NO TERMINA
				INNER JOIN [AsyncInteraction] AI (NOLOCK) 
					ON AI.[VCC] = PT.[vcc]
						AND AI.[Channel] = PAI.[InteractionType]
						AND AI.[Folder] = PAI.[FormattedEndDate]
						AND AI.[Campaign] = PAI.[Campaign]
						AND AI.[ID] = PAI.[InteractionId]
				WHERE PT.[Type] IS NULL
				GROUP BY PT.ProcessId, PT.vcc
		) UT GROUP BY UT.processId, UT.vcc

	  ) B ON A.[vcc] = B.[vcc] 
		AND A.[Name] = B.ProcessId

	-- ACTUALIZAMOS EL ESTADO DE OTROS PROCESOS QUE ESTAN COMO FALLIDOS, COLGADOS, ETC QUE COINCIDEN CON LAS INTERACCIONES DEL PROCESS TERMINADO
	UPDATE P
		SET P.[Status] = CASE WHEN TMPP.[totalFailed] > TMPP.[totalSucced] THEN 'FAILED'
								ELSE 'COMPLETE' END,
			P.[StatusDescription] = CASE WHEN TMPP.[totalFailed] > 0 THEN 'COMPLETED_WITH_ERROR' 
											ELSE 'COMPLETED' END,
			P.[Percentage] = 1
			,P.[LastModifiedDate] = GETUTCDATE()
		FROM [dbo].[Process] P (NOLOCK)
		INNER JOIN (
			SELECT UT.[processId]							'processId',
					ISNULL(SUM(UT.[totalAudio]), 0)			'totalAudio',
					ISNULL(SUM(UT.[totalSucced]), 0)		'totalSucced',
					ISNULL(SUM(UT.[totalFailed]), 0)		'totalFailed'
				FROM (
					SELECT P.[Name] 'processId',
							COUNT(*) 'totalAudio',
							COUNT(CASE WHEN ISNULL(A.[IsTranscribed], 0) = 1 THEN 1 ELSE NULL END) 'totalSucced',
							COUNT(CASE WHEN ISNULL(A.[IsCancel], 0) = 1 THEN 1 ELSE NULL END) 'totalFailed'
						FROM [dbo].[Process] P (NOLOCK) 
						INNER JOIN [dbo].[ProcessAudio] PA (NOLOCK) 
							ON PA.[VCC] = P.[VCC]
								AND PA.[ProcessId] = P.[Name]
						INNER JOIN [dbo].[Audio] A (NOLOCK) 
							ON A.[VCC] = PA.[VCC]
								AND A.[ID] = PA.[AudioId]
								AND A.[Section] = PA.[Section]
								AND A.[Part] = PA.[Part]
						WHERE 
							(P.[StatusDescription] <> 'COMPLETED' AND P.[Status] <> 'COMPLETE')
							OR 
							(P.[StatusDescription] = 'COMPLETED' AND P.[Status] <> 'COMPLETE')
							OR 
							(P.[StatusDescription] = 'COMPLETED' AND P.[Status] IS NULL)
							OR 
							(P.[Total] = 0 AND P.[Percentage] = 0)
							-- AND P.[Status] = 'INPROCESS_TRANSCRIPTION'
							--AND P.[StatusDescription] = 'IN_PROGRESS'
						GROUP BY P.[Name]
			
					UNION

					SELECT P.[Name],
							COUNT(*) 'totalAudio',
							COUNT(CASE WHEN ISNULL(AI.[IsTranscribed], 0) = 1 THEN 1 ELSE NULL END) 'totalSucced',
							COUNT(CASE WHEN ISNULL(AI.[IsCancel], 0) = 1 THEN 1 ELSE NULL END) 'totalFailed'
						FROM [dbo].[Process] P (NOLOCK) 
						INNER JOIN [ProcessAsyncInteraction] PAI (NOLOCK)
							ON PAI.[VCC] = P.[vcc]
								AND PAI.[ProcessId] = P.[Name]
						INNER JOIN [AsyncInteraction] AI (NOLOCK) 
							ON AI.[VCC] = P.[vcc]
								AND AI.[Channel] = PAI.[InteractionType]
								AND AI.[Folder] = PAI.[FormattedEndDate]
								AND AI.[Campaign] = PAI.[Campaign]
								AND AI.[ID] = PAI.[InteractionId]
						WHERE 
							(P.[StatusDescription] <> 'COMPLETED' AND P.[Status] <> 'COMPLETE')
							OR 
							(P.[StatusDescription] = 'COMPLETED' AND P.[Status] <> 'COMPLETE')
							OR 
							(P.[StatusDescription] = 'COMPLETED' AND P.[Status] IS NULL)
							OR 
							(P.[Total] = 0 AND P.[Percentage] = 0)
						GROUP BY P.[Name]
					) UT GROUP BY UT.[processId]
		) TMPP
			ON TMPP.[processId] = P.[Name]
				AND TMPP.[totalAudio] = (ISNULL(TMPP.[totalSucced], 0) + ISNULL(TMPP.[totalFailed], 0))


	-- REGISTROS DE [dbo].[#ProgressTemp] CON [Percentage] = 1 YA ESTAN TERMINADO (CON O SIN ERRORES)
	-- SI EL PROCESS SE MARCA COMO FAILED TUVO MUCHO FRACASOS, PERO AUN ASI TUVO EXITOS QUE DEBERERIA COBRARSE
	INSERT INTO [dbo].[Batch] ([VCC], [BatchTypeName], [BatchTypeId], [IsFinished], [ClosedDate], [LastModifiedDate])
		SELECT PTMP.[vcc], 'TRANSCRIPTION', PTMP.[ProcessId], 1, GETUTCDATE(), GETUTCDATE()
			FROM [#ProgressTemp] PTMP
			INNER JOIN [dbo].[Process] P 
				ON P.[vcc] = PTMP.[vcc] 
					AND P.[Name] = PTMP.[ProcessId] 
					AND PTMP.[Type] IS NULL
			WHERE PTMP.[Percentage] = 1 
				AND PTMP.[Type] IS NULL -- EL NULL INDICA QUE ES PROCESS DE TRANSCRIPCION Y NO DE PLAN DE EVALUACION

	-- REGISTRAMOS LA(S) AGENDA(S) DE PLANTILLA PARA LOS PROCESS TERMINADO
	INSERT INTO [dbo].[BatchScheduleExecution] ([VCC], [Id], [BatchScheduleId], [ProcessId], [ExecutionDate], [Status], [CreatedByUserId], [CreatedDate], [TimeStamp])
		SELECT PTMP.[vcc],
				NEWID(),
				BS.[Id],
				PTMP.[ProcessId],
				GETUTCDATE(),
				'PENDING',
				'system',
				GETUTCDATE(),
				GETUTCDATE()
			FROM [#ProgressTemp] PTMP
			LEFT JOIN [dbo].[BatchSchedule] BS (NOLOCK)
				ON BS.[VCC] = PTMP.[vcc]
			WHERE PTMP.[Percentage] = 1 
				AND PTMP.[Type] IS NULL -- EL NULL INDICA QUE ES PROCESS DE TRANSCRIPCION Y NO DE PLAN DE EVALUACION
				AND BS.[BatchType] = 'TEMPLATE'
				AND GETUTCDATE() >= BS.[StartDate]
				AND (
					BS.[EndDate] IS NULL 
					OR
					GETUTCDATE() < BS.[EndDate]
				)

	------------ESTADOS DE ESTUDIOS --------------
	UPDATE A
		SET [Total] = B.[Total]
			,[progress] = B.[Progress]
			,[error] = B.[Error]
			,[percentage] = B.[Percentage]
			,[StatusDescription] = CASE WHEN B.[Percentage] = 1 AND  ISNULL(B.[Error],0) > 0 THEN 'COMPLETED_WITH_ERROR' 
										WHEN B.[Percentage] = 1 AND  ISNULL(B.[Error],0) = 0 THEN 'COMPLETED' 
										ELSE  'IN_PROGRESS' END
			,[Status] = B.[Percentage]
			,[LastModifiedDate] = GETUTCDATE()
			--,[BatchStatus] = CASE WHEN B.[Percentage] = 1 AND  ISNULL(B.[Error],0) > 0 THEN 'FINISHED_WITH_ERROR' 
				--					WHEN B.[Percentage] = 1 AND  ISNULL(B.[Error],0) = 0 THEN 'FINISHED' 
					--				ELSE 'RUNNING' END
		FROM Study AS A
		INNER JOIN [dbo].[#ProgressTemp] B 
			ON A.[vcc] = B.[vcc] 
				AND A.[ProcessId] = B.ProcessId 
				AND A.[Name] = B.[TypeId] 
				AND B.[Type] IN ('study', 'template')
				
	--Eliminar StudyResultSummary
	         DELETE SRS FROM [dbo].[StudyResultSummary] SRS 
	                    JOIN [dbo].[Study]  S 
	                         ON 
	                        (S.[VCC] = SRS.[VCC] 
	                       AND S.[Name] = SRS.[StudyId] 
	                       AND S.[TemplateId] = SRS.[TemplateId])
	                   JOIN [dbo].[TemplateTheme] TT
	                         ON 
	                           (TT.[VCC] = S.[VCC]
	                            AND TT.[TemplateId] = S.[TemplateId]
	                            AND TT.[ID] = SRS.[TemplateThemeId])
	                   JOIN [dbo].[#ProgressTemp] PT 
	                        ON  
	                       (S.[VCC] = PT.[vcc] 
							AND S.[ProcessId] = PT.ProcessId 
							AND S.[Name] = PT.[TypeId] 
							AND PT.[Type]  IN ('study', 'template'))
						--Si es negativo eliminar los que IsMatched = 1 
	                   WHERE SRS.[IsMatched] = IIF(TT.[IsNegative] = 1, 1, 0)
	                  
	           	        
	 -- Eliminar StudyResultSummaryDetail
	           	  DELETE SRSD FROM [dbo].[StudyResultSummaryDetail] SRSD 
	                    JOIN [dbo].[Study]  S 
	                         ON 
	                        (S.[VCC] = SRSD.[VCC] 
	                       AND S.[Name] = SRSD.[StudyId])
	                   JOIN [dbo].[TemplateTheme] TT
	                         ON 
	                           (TT.[VCC] = S.[VCC]
	                            AND TT.[TemplateId] = S.[TemplateId]
	                            AND TT.[ID] = SRSD.[TemplateThemeId])
	                   JOIN [dbo].[TemplateThemeItem] TTI 
	                          ON (TTI.[VCC] = S.[VCC]
	                              AND TTI.[TemplateThemeId] = TT.[ID]
	                              AND TTI.[ID] = SRSD.[TemplateThemeItemId])
	                   JOIN [dbo].[#ProgressTemp] PT 
	                        ON  
	                       (S.[VCC] = PT.[vcc] 
							AND S.[ProcessId] = PT.ProcessId 
							AND S.[Name] = PT.[TypeId] 
							AND PT.[Type]  IN ('study', 'template'))
						--Si es negativo eliminar los que IsMatched = 1 
	                   WHERE SRSD.[IsMatched] = IIF(TT.[IsNegative] = 1, 1, 0)
	
   	 -- Eliminar StudyResultSummaryDetail
	           	  DELETE SD FROM [dbo].[StudyDetail] SD 
	                    JOIN [dbo].[Study]  S 
	                         ON 
	                        (S.[VCC] = SD.[VCC] 
	                       AND S.[Name] = SD.[StudyId])
	                   JOIN [dbo].[TemplateTheme] TT
	                         ON 
	                           (TT.[VCC] = S.[VCC]
	                            AND TT.[TemplateId] = S.[TemplateId]
	                            AND TT.[ID] = SD.[TemplateThemeId])
	                   JOIN [dbo].[TemplateThemeItem] TTI 
	                          ON (TTI.[VCC] = S.[VCC]
	                              AND TTI.[TemplateThemeId] = TT.[ID]
	                              AND TTI.[ID] = SD.[TemplateThemeItemId])
	                   JOIN [dbo].[#ProgressTemp] PT 
	                        ON  
	                       (S.[VCC] = PT.[vcc] 
							AND S.[ProcessId] = PT.[ProcessId] 
							AND S.[Name] = PT.[TypeId] 
							AND PT.[Type] IN ('study', 'template'))
						--Si es negativo eliminar los que IsMatched = 1 
	                   WHERE SD.[IsMatched] = IIF(TT.[IsNegative] = 1, 1, 0)

	-- REGISTROS DE [dbo].[#ProgressTemp] CON [Percentage] = 1 YA ESTAN TERMINADO (CON O SIN ERRORES)
	INSERT INTO [dbo].[Batch] ([VCC], [BatchTypeName], [BatchTypeId], [IsFinished], [ClosedDate], [LastModifiedDate])
		SELECT PTMP.[vcc], UPPER(PTMP.[Type]), PTMP.[TypeId], 1, GETUTCDATE(), GETUTCDATE()
			FROM [#ProgressTemp] PTMP
			INNER JOIN [dbo].[Study] S 
				ON S.[vcc] = PTMP.[vcc] 
					AND S.[ProcessId] = PTMP.[ProcessId] 
					AND S.[Name] = PTMP.[TypeId]
					AND PTMP.[Type] IN ('study', 'template')
			WHERE PTMP.[Percentage] = 1 
				AND PTMP.[Type] IN ('study', 'template')

	-- ACTUALIZAMOS LA EJECUCION RELACIONADA AL BATCH TEMPLATE TERMINADO
	UPDATE BSE 
		SET BSE.[Status] = 'FINISHED',
			BSE.[LastModifiedByUserId] = 'system',
			BSE.[LastModifiedDate] = GETUTCDATE()
		FROM [#ProgressTemp] PTMP
		INNER JOIN [dbo].[BatchScheduleExecution] BSE 
			ON BSE.[vcc] = PTMP.[vcc] 
				AND BSE.[BatchId] = PTMP.[TypeId] 
		WHERE PTMP.[Percentage] = 1 
			AND PTMP.[Type] = 'template'

	------------Estados de plan de evaluacion --------------

	-- UPDATE PARA LA PARTE DE TRANSCRIPCION
	UPDATE A
	SET [Total] = B.[Total]
		,[progress] = B.[Progress]
		,[error] = B.[Error]
		,[percentage] = B.[Percentage]
		,[StatusDescription] = CASE WHEN B.[Percentage] = 1 AND  ISNULL(B.[Error],0) > 0 THEN 'COMPLETED_WITH_ERROR' 
									WHEN B.[Percentage] = 1 AND  ISNULL(B.[Error],0) = 0 THEN 'COMPLETED' 
									ELSE 'IN_PROGRESS' END
		,[Status] = CASE WHEN B.[Percentage] = 1 THEN 3 ELSE 2 END
		,[LastModifiedDate] = GETUTCDATE()
	FROM EvaluationPlan AS A
	INNER JOIN [dbo].[#ProgressTemp] B 
		ON A.[Instance] = B.[vcc] 
			AND A.[ProcessId] = B.ProcessId 
			AND B.[Type] IS NULL 
			AND A.[FilterByContentQueryName] IS NOT NULL 
			AND A.[FilterByContentQuery] IS NOT NULL

	-- UPDATE CONTEMPLADO PARA PLAN DE EVALUACION CON PASO 3 (FILTRO DE CONTENIDO)
	UPDATE A
	SET [Total] = B.[Total]
		,[progress] = B.[Progress]
		,[error] = B.[Error]
		,[percentage] = B.[Percentage]
		,[StatusDescription] = CASE WHEN B.[Percentage] = 1 AND  ISNULL(B.[Error],0) > 0 THEN 'COMPLETED_WITH_ERROR' 
									WHEN B.[Percentage] = 1 AND  ISNULL(B.[Error],0) = 0 THEN 'COMPLETED' 
									ELSE  'IN_PROGRESS' END
		,[Status] = CASE WHEN B.[Percentage] = 1 THEN 5 ELSE 4 END
		,[LastModifiedDate] = GETUTCDATE()
	FROM EvaluationPlan AS A
	INNER JOIN [dbo].[#ProgressTemp] B 
		ON A.[Instance] = B.[vcc] 
			AND A.[ProcessId] = B.ProcessId 
			AND A.Id = B.[TypeId] 
			AND B.[Type] = 'evaluationPlan'

	-- UPDATE PARA LA PARTE DE ANALISIS SEMANTICO/COGNITIVO
	UPDATE A
	SET [Total] = B.[Total]
		,[progress] = B.[Progress]
		,[error] = B.[Error]
		,[percentage] = B.[Percentage]
		,[StatusDescription] = CASE WHEN B.[Percentage] = 1 AND  ISNULL(B.[Error],0) > 0 THEN 'COMPLETED_WITH_ERROR' 
									WHEN B.[Percentage] = 1 AND  ISNULL(B.[Error],0) = 0 THEN 'COMPLETED' 
									ELSE  'IN_PROGRESS' END
		,[Status] = CASE WHEN B.[Percentage] = 1 THEN 5 ELSE 2 END
		,[LastModifiedDate] = GETUTCDATE()
	FROM EvaluationPlan AS A
	INNER JOIN [dbo].[#ProgressTemp] B ON A.[Instance] = B.[vcc] 
	AND A.[ProcessId] = B.ProcessId 
	AND B.[Type] IS NULL 
	AND A.[FilterByContentQueryName] IS NULL 
	AND A.[FilterByContentQuery] IS NULL 
	AND (
		A.[Evaluation_Mode] = 'A' 
		OR
		A.[Evaluation_Mode] = 'X'
	)

	-- ACTUALIZAMOS EL ESTADO DE LOS PLANES DE LA TABLA TEMPORAL
	UPDATE A
	SET [Total] = B.[Total]
		,[progress] = B.[Progress]
		,[error] = B.[Error]
		,[percentage] = B.[Percentage]
		,[StatusDescription] = CASE WHEN B.[Percentage] = 1 AND  ISNULL(B.[Error],0) > 0 THEN 'COMPLETED_WITH_ERROR' 
									WHEN B.[Percentage] = 1 AND  ISNULL(B.[Error],0) = 0 THEN 'COMPLETED' 
									ELSE  'IN_PROGRESS' END
		,[Status] = CASE WHEN B.[Percentage] = 1 THEN 7 ELSE 6 END
		,[LastModifiedDate] = GETUTCDATE() 
	FROM EvaluationPlan AS A
	INNER JOIN [dbo].[#ProgressTemp] B 
		ON A.[Instance] = B.[vcc] 
			AND A.[ProcessId] = B.ProcessId 
			AND A.Id = B.[TypeId] 
			AND B.[Type] = 'ability'

	-- EN UNA TABLA ADICIONAL PODRIA INSERTAR LOS RP STATUS 7 PARA LUEGO ENVIARLOS A CERRAR EN EL SC
	UPDATE AEP 
		SET AEP.[Completed] = 1
			,[StatusDescription] = 'COMPLETED'
			,[LastModifiedDate] = GETUTCDATE()
	FROM dbo.[AuditorEvaluationPlan] AEP 
	INNER JOIN dbo.[EvaluationPlan] EP 
		ON EP.[ID] = AEP.[IdEvaluationPlan]
	INNER JOIN [dbo].[#ProgressTemp] B 
		ON EP.[Instance] = B.[vcc] 
			AND EP.[ProcessId] = B.ProcessId 
			AND EP.Id = B.[TypeId] 
			AND B.[Type] = 'ability'
	WHERE EP.[Status] = 7
		AND AEP.[IdAuditor] = 'SPEECH' 
		AND (EP.[Evaluation_Mode] = 'A' OR EP.[Evaluation_Mode] = 'X') 

	-- REGISTROS DE [dbo].[#ProgressTemp] CON [Percentage] = 1 YA ESTAN TERMINADO (CON O SIN ERRORES)
	INSERT INTO [dbo].[Batch] ([VCC], [BatchTypeName], [BatchTypeId], [IsFinished], [ClosedDate], [LastModifiedDate])
		SELECT PTMP.[vcc], 'EVALUATION_PLAN', PTMP.[TypeId], 1, GETUTCDATE(), GETUTCDATE()
			FROM [#ProgressTemp] PTMP
			INNER JOIN [dbo].[EvaluationPlan] EP (NOLOCK)
				ON EP.[Instance] = PTMP.[vcc] 
					AND EP.[ProcessId] = PTMP.[ProcessId] 
					AND EP.[Id] = PTMP.[TypeId]
					AND (PTMP.[Type] = 'ability' OR PTMP.[Type] = 'evaluationPlan')
			WHERE PTMP.[Percentage] = 1 
				AND (PTMP.[Type] = 'ability' OR PTMP.[Type] = 'evaluationPlan')

	-- REGISTRAMOS LA(S) AGENDA(S) DE PLANTILLA PARA LOS PROCESS TERMINADO
	INSERT INTO [dbo].[BatchScheduleExecution] ([VCC], [Id], [BatchScheduleId], [ProcessId], [ExecutionDate], [Status], [CreatedByUserId], [CreatedDate], [TimeStamp])
		SELECT PTMP.[vcc],
				NEWID(),
				BS.[Id],
				PTMP.[ProcessId],
				GETUTCDATE(),
				'PENDING',
				'system',
				GETUTCDATE(),
				GETUTCDATE()
			FROM [#ProgressTemp] PTMP
			LEFT JOIN [dbo].[BatchSchedule] BS (NOLOCK)
				ON BS.[VCC] = PTMP.[vcc]
			WHERE PTMP.[Percentage] = 1 
				AND (PTMP.[Type] = 'ability' OR PTMP.[Type] = 'evaluationPlan') -- EL NULL INDICA QUE ES PROCESS DE PLAN DE EVALUACION
				AND BS.[BatchType] = 'TEMPLATE'
				AND GETUTCDATE() >= BS.[StartDate]
				AND (
					BS.[EndDate] IS NULL 
					OR
					GETUTCDATE() < BS.[EndDate]
				)

	-- INICIO MEDIDA PARA PLANES FINALIZADOS QUE NO TIENE RESULTS REGISTRADOS
	-- DECLARAMOS UNA VARIABLE PARA ALMACENAR LOS PLANES Y SU CORRESPONDIENTE VCC
	DECLARE MY_CURSOR CURSOR 
	LOCAL STATIC READ_ONLY FORWARD_ONLY -- SCROLL 
		FOR 
		-- CONSULTAMOS LOS ID DE PLANES EN LA TABLA TEMPORAL
		SELECT PTMP.[vcc] 'VCC', 
				PTMP.[TypeId] 'EVALUATION_PLAN_ID'
			FROM [#ProgressTemp] PTMP
			INNER JOIN [dbo].[EvaluationPlan] EP (NOLOCK)
				ON EP.[Instance] = PTMP.[vcc] 
					AND EP.[ProcessId] = PTMP.[ProcessId] 
					AND EP.[Id] = PTMP.[TypeId]
					AND (PTMP.[Type] = 'ability' OR PTMP.[Type] = 'evaluationPlan')
			WHERE PTMP.[Percentage] = 1 
				AND (PTMP.[Type] = 'ability' OR PTMP.[Type] = 'evaluationPlan')
			
	-- DECLARARAMOS VARIABLES PARA INDICAR EL PLAN Y VCC
	DECLARE @CURRENT_VCC VARCHAR(50) = ''
	DECLARE @CURRENT_EVALUATION_PLAN_ID VARCHAR(100) = ''
	DECLARE @CURRENT_EVALUATION_PLAN_MIN_AUTOMATIC_QUALIFICATION NUMERIC(5, 2) = 0

	-- ABRIMOS Y RECORREMOS EL ARRAY DE CANALES
	OPEN MY_CURSOR
	FETCH NEXT FROM MY_CURSOR INTO @CURRENT_VCC, @CURRENT_EVALUATION_PLAN_ID
	WHILE @@FETCH_STATUS = 0
	BEGIN 
		-- BUSCAMOS SI EXISTE RESULTS PARA EL PLAN ACTUAL
		IF NOT EXISTS (
			SELECT 1 
				FROM [dbo].[EvaluationResult] ER (NOLOCK) 
				WHERE ER.[Instance] = @CURRENT_VCC
					AND ER.[IdEvaluationPlan] = @CURRENT_EVALUATION_PLAN_ID
		)
		BEGIN
			-- EJECUTAMOS EL SP QUE INSERTA LOS RESULT BASE DE LOS PLANES QUE AUN NO LOS TIENEN
			EXEC [dbo].[SaveEvaluationBaseResult] @CURRENT_VCC, @CURRENT_EVALUATION_PLAN_ID, 'AUTOMATIC'

			-- ACTUALIZAMOS A COMPLETED LOS REGISTROS AUDITOR_EVALUATION_PLAN DEL PLAN ACTUAL
			UPDATE AEP
				SET AEP.[Completed] = '1'
					,AEP.[StatusDescription] = 'COMPLETED'
					,AEP.[LastModifiedDate] = GETUTCDATE()
				FROM AuditorEvaluationPlan AEP (NOLOCK)
				WHERE AEP.[Instance] = @CURRENT_VCC
					AND AEP.[IdEvaluationPlan] = @CURRENT_EVALUATION_PLAN_ID
		END

		FETCH NEXT FROM MY_CURSOR INTO @CURRENT_VCC, @CURRENT_EVALUATION_PLAN_ID
	END
	CLOSE MY_CURSOR
	DEALLOCATE MY_CURSOR
	-- FIN MEDIDA PARA PLANES FINALIZADOS QUE NO TIENE RESULTS REGISTRADOS





	-- INICIO DE ACTUALIZACION DE ESTADO PARA PLANES MIXTOS(TERMINADA LA FASE AUTOMATICA(ESTADO 7), PASA A LA MANUAL(ESTADO 8) Y ACABADA LA MANUAL REGRESA AL ESTADO 7)

	DECLARE @CURRENT_AUDITOR_ID VARCHAR(50) = ''

	-- DECLARAMOS UNA VARIABLE PARA ALMACENAR LOS PLANES Y SU CORRESPONDIENTE VCC
	DECLARE MY_CURSOR_2 CURSOR 
	LOCAL STATIC READ_ONLY FORWARD_ONLY -- SCROLL 
		FOR 
		-- CONSULTAMOS LOS ID DE PLANES EN LA TABLA TEMPORAL
		SELECT DISTINCT
				PT.[vcc]								'VCC', 
				PT.[TypeId]								'EVALUATION_PLAN_ID',
				EF.[MinAutomaticQualification]			'MIN_AUTOMATIC_QUALIFICATION'
			FROM [dbo].[EvaluationPlan] AS EP (NOLOCK)
			INNER JOIN [dbo].[#ProgressTemp] PT 
				ON EP.[Instance] = PT.[vcc] 
					AND EP.[ProcessId] = PT.[ProcessId] 
					AND EP.[Id] = PT.[TypeId] 
					AND PT.[Type] = 'ability'
			INNER JOIN [dbo].[EvaluationFormat] EF (NOLOCK)
				ON EF.[Instance] = EP.[Instance]
					AND EF.[ID] = EP.[IdEvaluationFormat]
			WHERE EP.[Status] = 7
				AND EP.[Evaluation_Mode] = 'X'

	-- ABRIMOS Y RECORREMOS EL ARRAY DE PLANES
	OPEN MY_CURSOR_2
	FETCH NEXT FROM MY_CURSOR_2 INTO @CURRENT_VCC, @CURRENT_EVALUATION_PLAN_ID, @CURRENT_EVALUATION_PLAN_MIN_AUTOMATIC_QUALIFICATION
	WHILE @@FETCH_STATUS = 0
	BEGIN 
		-- EVALUAMOS SI EL AUDITOR SPEECH CALIFICO CON NOTA MAYOR O IGUAL AL ACEPTABLE MINIMO PARA LA PARTE AUTOMATICA
		IF EXISTS (
			SELECT 1
				FROM [dbo].[AuditorEvaluationPlan] AEP (NOLOCK)
				WHERE AEP.[Instance] = @CURRENT_VCC
					AND AEP.[IdEvaluationPlan] = @CURRENT_EVALUATION_PLAN_ID
					AND AEP.[IdAuditor] = 'SPEECH'
					AND AEP.[Score] >= @CURRENT_EVALUATION_PLAN_MIN_AUTOMATIC_QUALIFICATION
		)
		BEGIN
			-- ACTUALIZAMOS EL ESTADO DEL PLAN MIXTO PARA PASAR A LA PARTE MANUAL
			UPDATE EP 
				SET EP.[percentage] = 0
					,EP.[StatusDescription] = 'IN_PROGRESS'
					,EP.[Status] = 8
					,EP.[LastModifiedDate] = GETUTCDATE() 
				FROM [dbo].[EvaluationPlan] AS EP (NOLOCK)
				WHERE EP.[Instance] = @CURRENT_VCC
					AND EP.[ID] = @CURRENT_EVALUATION_PLAN_ID

			-- DECLARAMOS UNA VARIABLE PARA ALMACENAR LOS ID DE AUDITORES CORRESPONDIENTES AL PLAN
			DECLARE MY_AUDITOR_CURSOR CURSOR 
			LOCAL STATIC READ_ONLY FORWARD_ONLY -- SCROLL 
				FOR 
				-- CONSULTAMOS LOS ID DE AUDITORES
				SELECT DISTINCT AEP.[IdAuditor]
					FROM [dbo].[AuditorEvaluationPlan] AEP (NOLOCK)
					WHERE  AEP.[Instance] = @CURRENT_VCC
						AND AEP.[IdEvaluationPlan] = @CURRENT_EVALUATION_PLAN_ID
						AND AEP.[IdAuditor] <> 'SPEECH'

			-- ABRIMOS Y RECORREMOS EL ARRAY DE PLANES
			OPEN MY_AUDITOR_CURSOR
			FETCH NEXT FROM MY_AUDITOR_CURSOR INTO @CURRENT_AUDITOR_ID
			WHILE @@FETCH_STATUS = 0
			BEGIN 
				-- INSERTARMOS LOS REGISTROS DE ER QUE TENIA EL AUDITOR SPEECH
				INSERT INTO [dbo].[EvaluationResult] (
					[Instance], [IdCampaign], [IdInteraction], [IdAgent], [IdEvaluationFormat],
					[MinQualificationAcceptable], [IdGroup], [IdSubGroup], [IdAbility], [Qualification],
					[IdEvaluator], [EvaluationDate], [MaxAbilityScore], [IdEvaluationPlan], [CreatedDate],
					[CreatedByUserId], [TimeStamp], [NotApplies], [ScoreDescription], [CampaignDescription],
					[AgentDescription], [InteractionDateini], [InteractionDatefin], [InteractionAddress], [AbilityOrder],
					[InteractionType], [IdAbilityEvaluationFormat], [IdAuditor], [Conditional]
				) 
					-- SELECCIONAMOS LOS RESULTADOS REGISTRADOS POR SPEECH
					SELECT ER.[Instance], ER.[IdCampaign], ER.[IdInteraction], ER.[IdAgent], ER.[IdEvaluationFormat],
							ER.[MinQualificationAcceptable], ER.[IdGroup], ER.[IdSubGroup], ER.[IdAbility], ER.[Qualification],
							ER.[IdEvaluator], ER.[EvaluationDate], ER.[MaxAbilityScore], ER.[IdEvaluationPlan], ER.[CreatedDate],
							ER.[CreatedByUserId], GETUTCDATE(), ER.[NotApplies], ER.[ScoreDescription], ER.[CampaignDescription],
							ER.[AgentDescription], ER.[InteractionDateini], ER.[InteractionDatefin], ER.[InteractionAddress], ER.[AbilityOrder],
							ER.[InteractionType], ER.[IdAbilityEvaluationFormat], @CURRENT_AUDITOR_ID, ER.[Conditional]
						FROM [dbo].[EvaluationResult] ER (NOLOCK)
						INNER JOIN [dbo].[AuditorEvaluationPlan] AEP (NOLOCK)
							ON AEP.[Instance] = ER.[Instance]
								AND AEP.[IdEvaluationPlan] = ER.[IdEvaluationPlan]
								AND AEP.[IdAuditor] = ER.[IdAuditor]
								AND AEP.[IdInteraction] = ER.[IdInteraction]
								AND AEP.[Score] >= @CURRENT_EVALUATION_PLAN_MIN_AUTOMATIC_QUALIFICATION
						WHERE ER.[Instance] = @CURRENT_VCC
							AND ER.[IdEvaluationPlan] = @CURRENT_EVALUATION_PLAN_ID
							AND ER.[IdAuditor] = 'SPEECH'

				-- REABRIMOS LAS EVALUACIONES DE LAS INTERACCIONES CON SCORE MAYOR O IGUAL AL UMBRAL
				UPDATE [dbo].[AuditorEvaluationPlan]
					SET [Completed] = 0,
						[AutomaticScore] = [Score],
						[ManualScore] = 0,
						[StatusDescription] = 'NEW',
						[LastModifiedDate] = GETUTCDATE(),
						[TimeStamp] = GETUTCDATE()
					WHERE [Instance] = @CURRENT_VCC
						AND [IdEvaluationPlan] = @CURRENT_EVALUATION_PLAN_ID
						AND [IdAuditor] = @CURRENT_AUDITOR_ID

				FETCH NEXT FROM MY_AUDITOR_CURSOR INTO @CURRENT_AUDITOR_ID
			END
			CLOSE MY_AUDITOR_CURSOR
			DEALLOCATE MY_AUDITOR_CURSOR

			-- COMPLETAMOS LOS REGISTROS DE ER PARA LAS HABILIDADES MANUALES <- LAS HAB. MANUALES DEBEN QUEDAN EN BLANCO PARA EL AUDITOR SPEECH
			-- EXEC [dbo].[SaveEvaluationBaseResult] @CURRENT_VCC, @CURRENT_EVALUATION_PLAN_ID, 'MANUAL'

			-- REMOVEMOS LOS REGISTROS DE SPEECH (AEP Y ER) QUE FUERON ASIGNADOS A LOS AUDITORES
			DELETE ER
				FROM [dbo].[EvaluationResult] ER
				INNER JOIN [dbo].[AuditorEvaluationPlan] AEP (NOLOCK)
					ON AEP.[Instance] = ER.[Instance]
						AND AEP.[IdEvaluationPlan] = ER.[IdEvaluationPlan]
						AND AEP.[IdInteraction] = ER.[IdInteraction]
						AND AEP.[Score] >= @CURRENT_EVALUATION_PLAN_MIN_AUTOMATIC_QUALIFICATION
				WHERE ER.[Instance] = @CURRENT_VCC
					AND ER.[IdEvaluationPlan] = @CURRENT_EVALUATION_PLAN_ID
					AND ER.[IdAuditor] = 'SPEECH'
					AND AEP.[Score] >= @CURRENT_EVALUATION_PLAN_MIN_AUTOMATIC_QUALIFICATION

			-- REMOVEMOS LOS REGISTROS DE SPEECH EN AEP QUE PASARON EL MINIMO PARA AUTOMATICO
			DELETE 
				FROM [dbo].[AuditorEvaluationPlan] 
				WHERE [Instance] = @CURRENT_VCC
					AND [IdEvaluationPlan] = @CURRENT_EVALUATION_PLAN_ID
					AND [IdAuditor] = 'SPEECH'
					AND [Score] >= @CURRENT_EVALUATION_PLAN_MIN_AUTOMATIC_QUALIFICATION

			-- REMOVEMOS LOS REGISTROS DE LOS OTROS AUDITORES QUE NO PASARON EL MINIMO PARA AUTOMATICO
			DELETE 
				FROM [dbo].[AuditorEvaluationPlan] 
				WHERE [Instance] = @CURRENT_VCC
					AND [IdEvaluationPlan] = @CURRENT_EVALUATION_PLAN_ID
					AND [IdAuditor] <> 'SPEECH'
					AND [IdInteraction] IN (
						SELECT [IdInteraction] 
							FROM [dbo].[AuditorEvaluationPlan] 
							WHERE [Instance] = @CURRENT_VCC
								AND [IdEvaluationPlan] = @CURRENT_EVALUATION_PLAN_ID
								AND [IdAuditor] = 'SPEECH'
								AND [Score] < @CURRENT_EVALUATION_PLAN_MIN_AUTOMATIC_QUALIFICATION
					)

			-- ACTUALIZAMOS LOS CAMPOS SCORE DE LAS EVALUACIONES DE SPEECH
			UPDATE [dbo].[AuditorEvaluationPlan]
					SET [AutomaticScore] = [Score],
						[ManualScore] = 0,
						[LastModifiedDate] = GETUTCDATE(),
						[TimeStamp] = GETUTCDATE()
					WHERE [Instance] = @CURRENT_VCC
						AND [IdEvaluationPlan] = @CURRENT_EVALUATION_PLAN_ID
						AND [IdAuditor] = 'SPEECH'

		END
		ELSE
		BEGIN
			-- ELIMINAMOS LOS REGISTROS DE LOS OTROS AUDITORES (AEP)
			DELETE FROM [dbo].[AuditorEvaluationPlan] 
				WHERE  [Instance] = @CURRENT_VCC
					AND [IdEvaluationPlan] = @CURRENT_EVALUATION_PLAN_ID
					AND [IdAuditor] <> 'SPEECH'

			-- COMPLETAMOS LOS REGISTROS DE ER PARA LAS HABILIDADES MANUALES <- LAS HAB. MANUALES DEBEN QUEDAN EN BLANCO PARA EL AUDITOR SPEECH
			-- EXEC [dbo].[SaveEvaluationBaseResult] @CURRENT_VCC, @CURRENT_EVALUATION_PLAN_ID, 'MANUAL'

		END

		FETCH NEXT FROM MY_CURSOR_2 INTO @CURRENT_VCC, @CURRENT_EVALUATION_PLAN_ID, @CURRENT_EVALUATION_PLAN_MIN_AUTOMATIC_QUALIFICATION
	END
	CLOSE MY_CURSOR_2
	DEALLOCATE MY_CURSOR_2

	-- INVALIDAR LAS AUDITORIAS CUYO AUDIO PRESENTAN ALGUN ERROR
	UPDATE AEP
		SET AEP.[StatusDescription] = 'INVALID'
		FROM [dbo].[AuditorEvaluationPlan] AEP (NOLOCK)
		JOIN [dbo].[Audio] A (NOLOCK)
		    ON AEP.[Instance] = A.[VCC] 
		        AND AEP.[IdInteraction] = A.[ID]
		JOIN [#ProgressTemp] PTMP (NOLOCK)
			ON AEP.[Instance] = PTMP.[vcc]
			    AND AEP.[IdEvaluationPlan] = PTMP.[TypeId]
		WHERE (A.[IsTranscribed] IS NULL OR A.[IsTranscribed]  <> 1)
		    AND (PTMP.[Type] = 'ability' OR PTMP.[Type] = 'evaluationPlan')        
		    -- AND A.[ErrorMessage] IN ('GET_AUDIO_REQUEST_FAILED','JSON_IDATHA_IS_NOT_FOUND','JSON_TRANSCRIPTION_CONTENT_IS_EMPTY')

	-- RECUPERAMOS LAS EVALUACIONES DE SPEECH DE LA TABLA AUDITOR EVALUATION PARA REPLICARLA

	/*
	-- ACTUALIZAMOS EL ESTADO DEL PLAN MIXTO PARA PASAR A LA PARTE MANUAL
	UPDATE EP 
		SET EP.[percentage] = 0
			,EP.[StatusDescription] = 'IN_PROGRESS'
			,EP.[Status] = 8
			,EP.[LastModifiedDate] = GETUTCDATE() 
		FROM [dbo].[EvaluationPlan] AS EP (NOLOCK)
		INNER JOIN [dbo].[#ProgressTemp] PT 
			ON EP.[Instance] = PT.[vcc] 
				AND EP.[ProcessId] = PT.[ProcessId] 
				AND EP.[Id] = PT.[TypeId] 
				AND PT.[Type] = 'ability'
		WHERE EP.[Status] = 7
			AND EP.[Evaluation_Mode] = 'X'
	*/
	

	-- FIN DE ACTUALIZACION DE ESTADO PARA PLANES MIXTOS





	-----------------------------------------------------

	DROP TABLE [dbo].[#ProgressTemp]

END
GO
PRINT N'Modificando [dbo].[FinishedBatchClose]...';


GO
ALTER PROCEDURE [dbo].[FinishedBatchClose](
	@VCC VARCHAR(50) = NULL,
	@BatchTypeName VARCHAR(50) = NULL,
	@BatchTypeId VARCHAR(50) = NULL
)
AS
BEGIN
	-- ESTE SP TIENE LA FINALIDAD DE ACTUALIZAR LOS SALDOS DE LAS CARTERAS DEL VCC
	SET NOCOUNT ON

	-- VERIFICAMOS QUE TENEMOS LOS PARAMETROS NECESARIOS
	IF @VCC IS NULL OR @BatchTypeName IS NULL OR @BatchTypeId IS NULL
		-- LANZAMOS MENSAJE AVISANDO QUE FALTA ACCOUNTID
		RAISERROR('DATABABASE_ERROR_MISSING_PARAMETERS', 16, 16)

	-- DECLARAMOS UNA VARIABLE PARA EL ID DE AGENDA
		DECLARE @SCHEDULE_BATCH_ID VARCHAR(50)

	-- DECLARAMOS UNA VARIABLE PARA CONTABILIZAR LAS EJECUCIONES AUN NO TERMINADAS
	DECLARE @SCHEDULE_EXECUTIONS INT = 0

	--SELECT * FROM [dbo].[Batch] 
	UPDATE [dbo].[Batch] 
		SET [FinishReported] = 1
			,[LastModifiedDate] = GETUTCDATE()
		WHERE [VCC] = @VCC
			AND [BatchTypeName] = @BatchTypeName 
			AND [BatchTypeId] = @BatchTypeId

	-- SEGUN EL BATCHTYPENAME ACTUALIZAMOS EL STATUS DE LA TABLA DEL BATCH
	IF @BatchTypeName = 'TRANSCRIPTION'
	BEGIN
		UPDATE [dbo].[Process] 
			SET [Status] = CASE WHEN ([Total] - ISNULL([Error], 0)) > ISNULL([Error], 0) THEN 'COMPLETE'
							WHEN ([Total] - ISNULL([Error], 0)) < ISNULL([Error], 0) THEN 'FAILED' END
				,[StatusDescription] = CASE WHEN ISNULL([Error], 0) > 0 THEN 'COMPLETED_WITH_ERROR' 
										WHEN ISNULL([Error], 0) = 0 THEN 'COMPLETED' END
			WHERE [VCC] = @VCC
				AND [Name] = @BatchTypeId
				AND [Percentage] = 1

		-- OBTENEMOS EL ID DE LA AGENDA EN CASO EXISTA
		SELECT @SCHEDULE_BATCH_ID = P.[BatchScheduleId]
			FROM [dbo].[Process] P (NOLOCK)
			WHERE P.[VCC] =  @VCC
				AND P.[Name] = @BatchTypeId

		IF @SCHEDULE_BATCH_ID IS NOT NULL
		BEGIN
			-- ACTUALIZAMOS LA EJECUCION EN CASO SEA UN PROCESS AGENDADO
			UPDATE BSE 
				SET BSE.[Status] = P.[StatusDescription],
					BSE.[LastModifiedByUserId] = 'system',
					BSE.[LastModifiedDate] = GETUTCDATE()
				FROM [dbo].[BatchScheduleExecution] BSE (NOLOCK)
				INNER JOIN [dbo].[Process] P (NOLOCK)
					ON P.[VCC] = BSE.[VCC]
						AND P.[Name] = BSE.[BatchId]
				WHERE BSE.[VCC] = @VCC
					AND P.[Name] = @BatchTypeId
					AND P.[BatchScheduleId] IS NOT NULL
			
			SELECT @SCHEDULE_EXECUTIONS = COUNT(BSE.[Id]) 
				FROM [dbo].[BatchScheduleExecution] BSE (NOLOCK)
				INNER JOIN [dbo].[BatchSchedule] BS (NOLOCK)
					ON BS.[VCC] = BSE.[VCC]
						AND BS.[Id] = BSE.[BatchScheduleId]
				WHERE BSE.[VCC] = @VCC
					AND BS.[BatchType] = 'TRANSCRIPTION'
					AND BSE.[BatchScheduleId] = @SCHEDULE_BATCH_ID
					AND BSE.[Status] IN ('PENDING', 'REGISTERED_ON_REDIS', 'BATCH_CREATED', 'BATCH_STARTED')

			-- SI TENEMOS 0 EJECUCIONES NO TERMINADAS, DAMOS POR FINALIZADA LA AGENDA
			IF @SCHEDULE_EXECUTIONS = 0
				UPDATE [dbo].[BatchSchedule]
					SET [Status] = 'FINISHED',
						[LastModifiedByUserId] = 'system',
						[LastModifiedDate] = GETUTCDATE()
					WHERE [VCC] = @VCC 
						AND [ID] = @SCHEDULE_BATCH_ID
		END
	END
	ELSE IF @BatchTypeName IN ('STUDY', 'TEMPLATE')
	BEGIN 
		UPDATE [dbo].[Study] 
			SET [StatusDescription] = CASE WHEN [Percentage] = 1 AND  ISNULL([Error],0) > 0 THEN 'COMPLETED_WITH_ERROR' 
										WHEN [Percentage] = 1 AND  ISNULL([Error],0) = 0 THEN 'COMPLETED' END
			WHERE [VCC] = @VCC
				AND [Name] = @BatchTypeId
				AND [Percentage] = 1

		-- OBTENEMOS EL ID DE LA AGENDA EN CASO EXISTA
		SELECT @SCHEDULE_BATCH_ID = S.[BatchScheduleId]
			FROM [dbo].[Study] S (NOLOCK)
			WHERE S.[VCC] =  @VCC
				AND S.[Name] = @BatchTypeId

		IF @SCHEDULE_BATCH_ID IS NOT NULL
		BEGIN
			-- ACTUALIZAMOS LA EJECUCION EN CASO SEA UN PROCESS AGENDADO 
			UPDATE BSE 
				SET BSE.[Status] = S.[StatusDescription],
					BSE.[LastModifiedByUserId] = 'system',
					BSE.[LastModifiedDate] = GETUTCDATE()
				FROM [dbo].[BatchScheduleExecution] BSE (NOLOCK)
				INNER JOIN [dbo].[Study] S (NOLOCK)
					ON S.[VCC] = BSE.[VCC]
						AND S.[Name] = BSE.[BatchId]
				WHERE BSE.[VCC] = @VCC
					AND S.[Name] = @BatchTypeId
					AND S.[BatchScheduleId] IS NOT NULL
			
			SELECT @SCHEDULE_EXECUTIONS = COUNT(BSE.[Id]) 
				FROM [dbo].[BatchScheduleExecution] BSE (NOLOCK)
				INNER JOIN [dbo].[BatchSchedule] BS (NOLOCK)
					ON BS.[VCC] = BSE.[VCC]
						AND BS.[Id] = BSE.[BatchScheduleId]
				WHERE BSE.[VCC] = @VCC
					AND BS.[BatchType] = 'TEMPLATE'
					AND BSE.[BatchScheduleId] = @SCHEDULE_BATCH_ID
					AND BSE.[Status] IN ('PENDING', 'REGISTERED_ON_REDIS', 'BATCH_CREATED', 'BATCH_STARTED')

			-- SI TENEMOS 0 EJECUCIONES NO TERMINADAS, DAMOS POR FINALIZADA LA AGENDA
			IF @SCHEDULE_EXECUTIONS = 0
				UPDATE [dbo].[BatchSchedule]
					SET [Status] = 'RUNNING',
						[LastModifiedByUserId] = 'system',
						[LastModifiedDate] = GETUTCDATE()
					WHERE [VCC] = @VCC 
						AND [ID] = @SCHEDULE_BATCH_ID
		END
	END
	ELSE IF @BatchTypeName = 'EVALUATION_PLAN'
	BEGIN 
		UPDATE [dbo].[EvaluationPlan] 
			SET [StatusDescription] = CASE WHEN [Percentage] = 1 AND  ISNULL([Error], 0) > 0 THEN 'COMPLETED_WITH_ERROR' 
									WHEN [Percentage] = 1 AND  ISNULL([Error], 0) = 0 THEN 'COMPLETED' END 
			WHERE [Instance] = @VCC
				AND [ID] = @BatchTypeId
				AND [Percentage] = 1
				AND ([Status] = 3 OR [Status] = 5 OR [Status] = 7)
	END

	SELECT 1 'result'

	SET NOCOUNT OFF
END
GO
PRINT N'Modificando [dbo].[GetBatchDetail]...';


GO
ALTER PROCEDURE [dbo].[GetBatchDetail](
	@VCC VARCHAR(50) = NULL,
	@BatchTypeName VARCHAR(50) = NULL,
	@BatchTypeId VARCHAR(50) = NULL
)
AS
BEGIN
	-- ESTE SP TIENE LA FINALIDAD DE ACTUALIZAR LOS SALDOS DE LAS CARTERAS DEL VCC
	SET XACT_ABORT, NOCOUNT ON

	-- VERIFICAMOS QUE TENEMOS LOS PARAMETROS NECESARIOS
	IF @VCC IS NULL OR @BatchTypeName IS NULL OR @BatchTypeId IS NULL 
		-- LANZAMOS MENSAJE AVISANDO QUE FALTA ACCOUNTID
		RAISERROR('DATABASE_ERROR_MISSING_PARAMETERS', 16, 16)

	-- VERIFICAMOS QUE EL BATCH TYPE SEA UN TIPO CONOCIDO DEL SISTEMA
	IF @BatchTypeName NOT IN ('TRANSCRIPTION', 'STUDY', 'TEMPLATE', 'EVALUATION_PLAN')
		-- LANZAMOS MENSAJE AVISANDO QUE HAN SOLICITADO UNA OPERACION DESCONOCIDA
		RAISERROR('DATABASE_ERROR_UNKNOWN_BATCH_TYPENAME', 16, 16)

	-- INICIAMOS UN TRY PARA EL CASO CAIGA EN CATCH HAGAMOS ROLLBACK
    BEGIN TRY
		
		-- DEPENDIENDO DEL BATCHTYPENAME CONSULTAMOS A UNA TABLA DIFERENTE
		IF @BatchTypeName = 'TRANSCRIPTION'
		BEGIN
			-- HACEMOS LA BUSQUEDA EN LA TABLA CORRESPONDIENTE SEGUN EL TIPO DE BATCH
			SELECT P.[VCC]						'vcc',
					@BatchTypeName				'batchTypeName',
					P.[Name]					'batchTypeId',
					P.[Description]				'description',
					p.[Percentage]				'percentage',
					P.[Status]					'status',
					P.[StatusDescription]		'statusDescription',
					B.[IsFinished]				'isFinished',
					B.[FinishReported]			'isReported'
				FROM [dbo].[Process] P (NOLOCK)
				LEFT JOIN [dbo].[Batch] B (NOLOCK)
					ON B.[VCC] = P.[VCC]
						AND B.BatchTypeId = P.[Name]
				WHERE P.[VCC] = @VCC 
					AND P.[Name] = @BatchTypeId
		END 
		ELSE IF @BatchTypeName IN ('STUDY', 'TEMPLATE')
		BEGIN
			SELECT S.[VCC]						'vcc',
					@BatchTypeName				'batchTypeName',
					S.[Name]					'batchTypeId',
					S.[Description]				'description',
					S.[Percentage]				'percentage',
					S.[Status]					'status',
					S.[StatusDescription]		'statusDescription' ,
					S.[BatchStatus]				'batchStatus',
					B.[IsFinished]				'isFinished',
					B.[FinishReported]			'isReported'
				FROM [dbo].[Study] S (NOLOCK)
				LEFT JOIN [dbo].[Batch] B (NOLOCK)
					ON B.[VCC] = S.[VCC]
						AND B.BatchTypeId = S.[Name]
				WHERE S.[VCC] = @VCC 
					AND S.[Name] = @BatchTypeId
		END 
		ELSE IF @BatchTypeName = 'EVALUATION_PLAN'
		BEGIN
			SELECT EP.[Instance]				'vcc',
					@BatchTypeName				'batchTypeName',
					EP.[ID]						'batchTypeId',
					EP.[Description]			'description',
					EP.[Percentage]				'percentage',
					EP.[Status]					'status',
					EP.[StatusDescription]		'statusDescription' ,
					EP.[BatchStatus]			'batchStatus',
					B.[IsFinished]				'isFinished',
					B.[FinishReported]			'isReported'
				FROM [dbo].[EvaluationPlan] EP (NOLOCK)
				LEFT JOIN [dbo].[Batch] B (NOLOCK)
					ON B.[VCC] = EP.[Instance]
						AND B.BatchTypeId = EP.[ID]
				WHERE EP.[Instance] = @VCC 
					AND EP.[ID] = @BatchTypeId
		END 

	END TRY
    BEGIN CATCH
        DECLARE @Message nvarchar(2048) = ERROR_MESSAGE()
        DECLARE @Severity integer = ERROR_SEVERITY()
        DECLARE @State integer = ERROR_STATE()

        RAISERROR(@Message, @Severity, @State)
        RETURN -1
    END CATCH
END
GO
PRINT N'Modificando [dbo].[GetStudy]...';


GO
--exec [GetStudy] 'default',''
ALTER PROCEDURE [dbo].[GetStudy] (
	@VCC Varchar(50) = NULL,		@StudyId Varchar(200) = NULL
	)
AS
BEGIN
	SET NOCOUNT ON

	SELECT
		[ProcessId]						'processId',
		[TemplateId]					'templateId',
		[Name]						    'name',
		[Description]					'description',
		[Type]							'type',
		[Status]						'status',
		[LastQueryId]					'lastQueryId',
		[ErrorMessage]					'errorMessage',
		[CreatedDate]					'createdDate',
		[CreatedByUserId]				'createdByUserId',
		[LastModifiedDate]				'lastModifiedDate',
		[LastModifiedByUserId]			'lastModifiedByUserId'
	FROM [Study] (NOLOCK)
	WHERE [VCC] = @VCC
	AND [Name] = @StudyId
	
	SET NOCOUNT OFF
END
GO
PRINT N'Modificando [dbo].[GetStudyByName]...';


GO
--exec [GetCategoryByName] 'default','BAnca'
ALTER PROCEDURE [dbo].[GetStudyByName] (
	@VCC Varchar(50) = NULL, @Name Varchar(200) = NULL
)
AS
BEGIN
	SET NOCOUNT ON

	SELECT
		[processId]						'processId',
		[templateId]					'templateId',
		[Name]						    'name',
		[Description]					'description',
		[Type]							'type',
		[Status]						'status',
		[CreatedDate]					'createdDate',
		[CreatedByUserId]				'createdByUserId',
		[LastModifiedDate]				'lastModifiedDate',
		[LastModifiedByUserId]			'lastModifiedByUserId'
	FROM [Study] (NOLOCK)
	WHERE [VCC] = @VCC
	AND [Name] = @Name
	
	SET NOCOUNT OFF
END
GO
PRINT N'Modificando [dbo].[SaveStudyStatus]...';


GO

-- [dbo].[SaveStudyStatus] 'inconcert', 'procesoallegro33', 'test_custom', 'Estudio_Prueba', 0, 'D234FD3D-6F5E-499C-942E-1AD5B92EE368', ''
ALTER PROCEDURE [dbo].[SaveStudyStatus]
(
	@VCC					VARCHAR(50),
	@ProcessId				VARCHAR(50),
	@TemplateId				VARCHAR(50),
	@StudyId				VARCHAR(200),
	@Status					FLOAT,
	@LastQueryId			VARCHAR(50),
	@ErrorMessage			VARCHAR(800),
	@LastModifiedDate		DATETIME,
	@LastModifiedByUserId	VARCHAR(50)
)
AS
BEGIN
	SET NOCOUNT ON

	UPDATE [dbo].[Study] SET
			[Status] = @Status,
			[LastQueryId] = @LastQueryId,
			[ErrorMessage] = CASE WHEN @ErrorMessage = '' THEN NULL ELSE @ErrorMessage END,
			[LastModifiedDate] = @LastModifiedDate,
			[LastModifiedByUserId] = @LastModifiedByUserId,
			[TimeStamp] = GETUTCDATE()
		WHERE
			[VCC] = @VCC
			AND [ProcessId] = @ProcessId
			AND [TemplateId] = @TemplateId
			AND [Name] = @StudyId
	
	-- DECLARAMOS UNA VARIABLE PARA IDENTIFICAR SI EL ESTUDIO PERTENECE A UNA AGENDA
	DECLARE @SCHEDULE_ID VARCHAR(50) = NULL

	-- OBTENEMOS EL ID DE AGENDA DEL ESTUDIO
	SELECT @SCHEDULE_ID = S.[BatchScheduleId]
		FROM [dbo].[Study] S (NOLOCK)
		WHERE S.[VCC] = @VCC 
			AND S.[Name] = @StudyId

	-- SI EL ESTUDIO PERTENECE A UNA AGENDA ACTUALIZAMOS
	IF @SCHEDULE_ID IS NOT NULL
	BEGIN
		-- ACTUALIZAMOS LA EJECUCION
		UPDATE [dbo].[BatchScheduleExecution]
			SET [Status] = 'BATCH_STARTED'
			WHERE [VCC] = @VCC
				AND [BatchScheduleId] = @SCHEDULE_ID
				AND [BatchId] = @StudyId
	END


	SELECT 1 AS 'result'

	SET NOCOUNT OFF
END
GO
PRINT N'Modificando [dbo].[GetAudiosProcess]...';


GO
-- [dbo].[GetAudiosProcess] 5, 1, 'allegro', 'proceso1', '', '2019-04-11 00:00:00.000', '2019-06-06 04:59:59.997', 22, 26, 23, 59, 'entrantes,PruebasJair,VideoCall', 'icagente', NULL, 'allegro', '', ''
ALTER PROCEDURE [dbo].[GetAudiosProcess]
(
	@PageSize				INT,
	@PageNumber				INT,
	@VCC					VARCHAR(50),
	@ProcessId				VARCHAR(50),
	@ID						VARCHAR(250),
	@StartDate				DATETIME = NULL,
	@EndDate				DATETIME = NULL,
	@StartHour				INT,
	@StartMinute			INT,
	@EndHour				INT,
	@EndMinute				INT,
	@Campaign				VARCHAR(MAX),
	@Agent					VARCHAR(MAX),
	@ResultCode				VARCHAR(MAX),
	@Type					VARCHAR(50),
	@IdathaResults			NVARCHAR(MAX),
	@TotalIdathaResults		INT,
	@InteractionType		VARCHAR(50),
	@InteractionIds         VARCHAR(MAX) = NULL,
	@Folder					VARCHAR(50),
	@ContactAddress			VARCHAR(300) = NULL
)
AS
BEGIN
	SET NOCOUNT ON
	
	-- DEFINIMOS UNA TABLE TEMPORAL PARA DEPOSITAR LA TODOS LAS INTERACCIONES DEL PROCESS
	CREATE TABLE #PROCESS_INTERACTIONS(
		vcc VARCHAR(50),
		interactionType VARCHAR(100),
		id VARCHAR(250),
		section VARCHAR(5),
		part VARCHAR(5),
		processId VARCHAR(100),
		number VARCHAR(100),
		name VARCHAR(100),
		silenceTime INT,
		durationTime INT,
		durationLinguisticTime INT,
		category1 VARCHAR(100),
		category2 VARCHAR(100),
		category3 VARCHAR(100),
		agent VARCHAR(100),
		agentName VARCHAR(150),
		description VARCHAR(100),
		environment VARCHAR(100),
		isTranscribed VARCHAR(100),
		errorMessage VARCHAR(MAX),
		createdDate DATETIME,
		endDate DATETIME,
		campaign VARCHAR(50),
		dispositionCode VARCHAR(250),
		folder VARCHAR(50),
		contactAddress varchar(300)
	)

	-- INSERTAMOS LOS REGISTROS CALL
	INSERT INTO #PROCESS_INTERACTIONS
		SELECT A.[VCC]														'vcc',
				'CALL'														'interactionType',
				A.[ID]														'id',
				A.[Section]													'section',
				A.[Part]													'part',
				PA.[ProcessId]												'processId',
				A.[Number]													'number',
				P.[Name]													'name',
				A.[SilenceTime]												'silenceTime',
				A.[DurationTime]											'durationTime',
				A.[DurationLinguisticTime]									'durationLinguisticTime',
				A.[Category1]												'category1',
				A.[Category2]												'category2',
				A.[Category3]												'category3',
				A.[Agent]													'agent',
				A.[AgentName]												'agentName',
				A.[Description]												'description',
				P.[Environment]												'environment',
				A.[IsTranscribed]											'isTranscribed',
				A.[ErrorMessage]											'errorMessage',
				A.[CreatedDate]												'createdDate',
				A.[EndDate]													'endDate',
				A.[Campaign]												'campaign',
				A.[DispositionCode]											'dispositionCode',
				NULL														'folder',
				A.[ContactAddress]											'contactAddress'
			FROM [dbo].[Audio] A (NOLOCK)
			INNER JOIN [dbo].[ProcessAudio] PA (NOLOCK) 
				ON A.[VCC] = PA.[VCC]
					AND A.ID = PA.AudioId 
					AND A.Section = PA.Section 
					AND A.Part = PA.Part
			INNER JOIN [dbo].[Process] P (NOLOCK) 
				ON P.[VCC] = PA.[VCC]
					AND PA.[ProcessId] = P.[Name]
			WHERE A.[VCC] = @VCC
				AND PA.[ProcessId] = @ProcessId
				AND P.[Type] = 'SPEECH'
				
	-- INSERTAMOS LOS REGISTROS DE INTERACCIONES DE OTROS CANALES
	INSERT INTO #PROCESS_INTERACTIONS
		SELECT AI.[VCC]																'vcc',
				AI.[Channel]														'interactionType',
				AI.[ID]																'id',
				NULL																'section',
				NULL																'part',
				PAI.[ProcessId]														'processId',
				AI.[ContactName]													'number',
				PAI.[ProcessId]														'name',
				NULL																'silenceTime',
				CASE WHEN TRY_CAST(AI.[DurationTime] AS INT) IS NULL THEN
					CAST(SUBSTRING(AI.[DurationTime], 1, CHARINDEX(':', AI.[DurationTime], 1) - 1) AS INT) * 3600
					+
					CAST(SUBSTRING(AI.[DurationTime], CHARINDEX(':', AI.[DurationTime], 1) + 1, 2) AS INT) * 60
					+
					CAST(SUBSTRING(AI.[DurationTime], CHARINDEX(':', AI.[DurationTime], CHARINDEX(':', AI.[DurationTime], 1) + 1) + 1, 2) AS INT)
				ELSE AI.[DurationTime]
				END																	'durationTime',
				NULL																'durationLinguisticTime',
				NULL																'category1',
				NULL																'category2',
				NULL																'category3',
				AI.[FirstTakedAgent]												'agent',
				ISNULL(AI.[LastTakedAgentName], AI.[LastTakedAgentName])			'agentName',
				AI.[DispositionCode]												'description',
				'I6'																'environment',
				AI.[IsTranscribed]													'isTranscribed',
				AI.[ErrorMessage]													'errorMessage',
				AI.[CreatedDate]													'createdDate',
				AI.[EndDate]														'endDate',
				AI.[Campaign]														'campaign',
				AI.[DispositionTreePath]											'dispositionCode',
				AI.[Folder]															'folder',
				AI.[ContactAddress]													'contactAddress'
			FROM [dbo].[ProcessAsyncInteraction] PAI (NOLOCK)
			INNER JOIN [dbo].[AsyncInteraction] AI (NOLOCK)
				ON AI.[VCC] = PAI.[VCC]
					--AND AI.[Campaign] = PAI.[Campaign]
					AND AI.[Channel] = PAI.[InteractionType]
					AND AI.[ID] = PAI.[InteractionId]
					AND AI.[Folder] = PAI.[FormattedEndDate]
			INNER JOIN [dbo].[Process] P (NOLOCK) 
				ON P.[VCC] = PAI.[VCC]
					AND P.[Name] = PAI.[ProcessId]
			WHERE PAI.[VCC] = @VCC
				AND PAI.[ProcessId] = @ProcessId
				AND P.[Type] = 'SPEECH'
		
	-- DECLARAMOS VARIABLE PARA LA CONSULTA ACUMULADA QUE LANZAREMOS
	DECLARE @SQL NVARCHAR(MAX) = ''
	DECLARE @SQL_WHERE_IDATHA NVARCHAR(MAX) = ''
    DECLARE @FILTERS_OPTIONAL_PART VARCHAR(MAX) = ''
	DECLARE @FILTERS_EXCLUDING_PART VARCHAR(MAX )= ''	
	
	SET @SQL_WHERE_IDATHA = ''

	-- HACEMOS EL PRIMER QUERY PARA SACAR EL NUMERO DE REGISTROS DEL PROCESS
	SET @SQL = ' SET NOCOUNT ON
	DECLARE @rows INT
	DECLARE @SYNC_INTERACTIONS INT
	DECLARE @ASYNC_INTERACTIONS INT
	DECLARE @maxDurationTime Numeric(12,3)

	SELECT @SYNC_INTERACTIONS = COUNT(*) FROM #PROCESS_INTERACTIONS PI WHERE PI.[interactionType] = ''CALL''
	SELECT @ASYNC_INTERACTIONS = COUNT(*) FROM #PROCESS_INTERACTIONS PI WHERE PI.[interactionType] <> ''CALL''
	SELECT @maxDurationTime = MAX([durationTime]) FROM #PROCESS_INTERACTIONS 
	'

	SET @SQL += '
		SET @rows = (
			SELECT COUNT(PI.[id])
				FROM #PROCESS_INTERACTIONS PI (NOLOCK)
				WHERE PI.[vcc] = ''' + @VCC + ''' 
					'
	IF (@ProcessId IS NOT NULL) 
			SET @SQL += 'AND PI.[ProcessId]= ''' + @ProcessId + ''' 
						'

	IF(@Type = 'query')
	BEGIN
		SET @SQL_WHERE_IDATHA += 'AND ((CONCAT(PI.[id], ''_'', PI.[section], ''_'', PI.[part]) IN (''' + @IdathaResults + '''))
						OR (PI.[id] IN (''' + @IdathaResults + ''')))
					'
	
		SET @SQL += @SQL_WHERE_IDATHA

	END
	ELSE IF(@Type = 'allegro' OR @Type = 'i6' OR @Type = 'ftp' OR @Type = 'sftp' OR @Type = 'fileSystem')
	BEGIN
		IF (@ID IS NOT NULL) 
			SET @FILTERS_OPTIONAL_PART += 'AND ((CONCAT(PI.[id], ''_'', PI.[section], ''_'', PI.[part]) LIKE ''%' + @ID + '%'')
						OR (PI.[id] = ''' + @ID + '''))
					'
		
		IF (@Campaign IS NOT NULL AND LEN(@Campaign) > 0) 
			SET @FILTERS_OPTIONAL_PART += 'AND PI.[campaign] IN (''' + @Campaign + ''')
						'
		
		IF (@Agent IS NOT NULL AND LEN(@Agent) > 0) 
			SET @FILTERS_OPTIONAL_PART += 'AND (
									(PI.[agent] IN (''' + @Agent + '''))
									OR 
									(PI.[agent] IS NULL)
								)
						'
		
		--CORREGIR
		-- (CONCAT(PI.campaign, ''_'', ISNULL(CONVERT(VARCHAR(4), PI.[dispositionCode]), '''') IN (''' + @ResultCode + '''))
		IF (@ResultCode IS NOT NULL AND LEN(@ResultCode) > 0) 
			SET @FILTERS_OPTIONAL_PART += 'AND (
									(CONCAT(PI.campaign, ''_'', ISNULL(CONVERT(VARCHAR(4), PI.[dispositionCode]), ''X'')) IN (''' + @ResultCode + '''))
									OR 
									--(CONCAT(PI.campaign, ''_'', ISNULL(PI.[dispositionCode], ''X'')) IN (''' + @ResultCode + '''))
									(CONCAT(PI.campaign, ISNULL(REPLACE(PI.[dispositionCode], ''/'', ''_''), ''_'')) IN (''' + @ResultCode + '''))
									) '
		
		IF (@InteractionType IS NOT NULL AND LEN(@InteractionType) > 0) 
			SET @FILTERS_OPTIONAL_PART += 'AND PI.[interactionType] = ''' + @InteractionType + ''' 
						'

		IF (@Folder IS NOT NULL AND LEN(@Folder) > 0) 
			SET @FILTERS_OPTIONAL_PART += 'AND PI.[folder] = ''' + @Folder + ''' 
						'

		IF (@Folder IS NOT NULL AND LEN(@Folder) > 0) 

		IF (@StartDate IS NOT NULL AND @EndDate IS NOT NULL) 
			SET @FILTERS_OPTIONAL_PART += 'AND PI.[endDate] BETWEEN ''' + CONVERT(VARCHAR(10), @StartDate, 120) + ''' 
						AND ''' + CONVERT(VARCHAR(10), @EndDate, 120) + '''
						'
		
		IF (@StartHour IS NOT NULL AND @EndHour IS NOT NULL) 
			SET @FILTERS_OPTIONAL_PART += 'AND DATEPART(HOUR, PI.[endDate]) >= ' + CONVERT(VARCHAR, @StartHour) + ' 
						AND DATEPART(HOUR, PI.[endDate]) <= ' + CONVERT(VARCHAR, @EndHour) + '
						'
		
		IF (@StartMinute IS NOT NULL AND @EndMinute IS NOT NULL) 
			SET @FILTERS_OPTIONAL_PART += 'AND DATEPART(MINUTE, PI.[endDate]) >= ' + CONVERT(VARCHAR, @StartMinute) + ' 
						AND DATEPART(MINUTE, PI.[endDate]) <= ' + CONVERT(VARCHAR, @EndMinute) + '
						'

		IF(@ContactAddress IS NOT NULL AND @ContactAddress <> '')
		BEGIN
			SET @FILTERS_OPTIONAL_PART += '
				AND ContactAddress LIKE ''%' + @ContactAddress + '%''
			'
		END	
		
		IF (@InteractionIds IS NOT NULL AND @InteractionIds <> '')
        BEGIN
			SET @FILTERS_OPTIONAL_PART = ''
			-- SET @FILTERS_EXCLUDING_PART = ' AND PI.[id] IN (SELECT Value FROM [dbo].[split](''' + @InteractionIds + ''','','')) 
			--			'
			SET @FILTERS_EXCLUDING_PART = ' AND (
						(CONCAT(PI.[id], ''_'', PI.[section], ''_'', PI.[part]) IN (SELECT Value FROM [dbo].[split](''' + @InteractionIds + ''','','')))
						OR 
						(PI.[id] IN (SELECT Value FROM [dbo].[split](''' + @InteractionIds + ''','','')))
						)
						'
	    END
		
	END

	SET @SQL += @FILTERS_OPTIONAL_PART + @FILTERS_EXCLUDING_PART
	SET @SQL += ') '
	SET @SQL += 'SELECT @rows AS total, 
						@maxDurationTime AS maxDurationTime,
						@ASYNC_INTERACTIONS AS asyncDetails, 
						@SYNC_INTERACTIONS AS audios '

	-- SECCION DE QUERY PARA RESUMEN DE CANALES
	SET @SQL += '
		SELECT PI.[interactionType]			''interactionType'',
				COUNT(*)					''interactions'' 
			FROM #PROCESS_INTERACTIONS PI 
			WHERE PI.[vcc] = ''' + @VCC + ''' 
	'

	IF(@ProcessId IS NOT NULL) 
		SET @SQL += '
				AND PI.[processId] = ''' + @ProcessId + ''' '
		
	SET @SQL += '
		GROUP BY  PI.[interactionType] '

	-- SECCION DE QUERY PARA RESUMEN DE CAMPANAS
	SET @SQL += '
		SELECT PI.[campaign]			''campaign''
			FROM #PROCESS_INTERACTIONS PI 
			WHERE PI.[vcc] = ''' + @VCC + ''' 
	'

	IF(@ProcessId IS NOT NULL) 
		SET @SQL += '
				AND PI.[processId] = ''' + @ProcessId + ''' '
		
	SET @SQL += '
		GROUP BY  PI.[campaign] '

	-- SECCION DE QUERY PARA LISTADO DE DETALLES(AUDIOS/TEXTOS)
	SET @SQL += '
		SELECT PI.[interactionType],
				PI.[id],
				PI.[section],
				PI.[part],
				PI.[processId],
				PI.[folder],
				PI.[campaign],
				PI.[number],
				PI.[name],
				PI.[silenceTime],
				PI.[durationTime],
				PI.[durationLinguisticTime],
				PI.[category1],
				PI.[category2],
				PI.[category3],
				PI.[agent],
				PI.[agentName],
				PI.[description],
				PI.[environment],
				PI.[isTranscribed],
				PI.[errorMessage],
				PI.[createdDate],
				PI.[endDate]
			FROM #PROCESS_INTERACTIONS PI
			WHERE PI.[vcc] = ''' + @VCC + ''' 
				'

	IF(@ProcessId IS NOT NULL) SET @SQL += 'AND PI.[processId] = ''' + @ProcessId + ''' '
			
	SET @SQL += ' '

	SET @SQL += @FILTERS_OPTIONAL_PART + @FILTERS_EXCLUDING_PART
	SET @SQL += @SQL_WHERE_IDATHA
	SET @SQL += 'ORDER BY PI.[ID], 
						PI.[ProcessId], 
						PI.[Agent], 
						PI.[AgentName], 
						PI.[Description], 
						PI.[Environment], 
						PI.[DurationTime], 
						PI.[CreatedDate]
			OFFSET ' + CONVERT(VARCHAR(50), @PageSize) + ' * (' + CONVERT(VARCHAR(50), @PageNumber) + ' - 1) ROWS
			FETCH NEXT ' + CONVERT(VARCHAR(50), @PageSize) + ' ROWS ONLY
			'

	SET @SQL += ' SET NOCOUNT OFF'
	-- select @SQL
	EXEC(@SQL)
	
	DROP TABLE #PROCESS_INTERACTIONS
END
GO
PRINT N'Modificando [dbo].[GetBatchScheduleExecutionsByCriteria]...';


GO
ALTER PROCEDURE [dbo].[GetBatchScheduleExecutionsByCriteria] (
	@VCC VARCHAR(50) = NULL, 
	@SearchCriteria VARCHAR(50) = NULL,
	@SearchExpression VARCHAR(500) = NULL
)
AS
BEGIN
	SET NOCOUNT ON

	DECLARE @SQL VARCHAR(MAX) = ''
	-- DECLARAMOS CADENAS PARA EL QUERY FINAL
	DECLARE @SQL_SELECT VARCHAR(MAX) = ''
	DECLARE @SQL_FROM VARCHAR(MAX) = ''
	DECLARE @SQL_EXTRA VARCHAR(MAX) = ''
    DECLARE @FILTERS_OPTIONAL_PART VARCHAR(MAX) = ''
    DECLARE @FILTERS_EXCLUDING_PART VARCHAR(MAX) = ''
    DECLARE @FILTERS_FIXED_PART     VARCHAR(MAX) = ''

	SET @SQL_SELECT = '
		SELECT BSE.[VCC]									''vcc'',
				BSE.[Id]									''id'', 
				BSE.[BatchScheduleId]						''batchScheduleId'', 
				BSE.[BatchId]								''batchId'', 
				BSE.[ProcessId]								''processId'', 
				BSE.[ExecutionDate]							''executionDate'', 
				BS.[ExecutionDelay]							''executionDelay'',
				BSE.[Order]									''order'', 
				BSE.[Status]								''status'', 
				BSE.[CreatedDate]							''createdDate'',
				BSE.[CreatedByUserId]						''createdByUserId'',
				BSE.[LastModifiedDate]						''lastModifiedDate'',
				BSE.[LastModifiedByUserId]					''lastModifiedByUserId'',
				RN = ROW_NUMBER() OVER(PARTITION BY BSE.[VCC],
													BSE.[BatchScheduleId]
										ORDER BY BSE.[ExecutionDate] DESC) '

	-- ARMAMOS LA PARTE DE TABLAS 
	SET @SQL_FROM += '
			FROM [dbo].[BatchScheduleExecution] BSE (NOLOCK)
			INNER JOIN [dbo].[BatchSchedule] BS (NOLOCK)
				ON BS.[VCC] = BSE.[VCC]
					AND BS.[Id] = BSE.[BatchScheduleId] '

	-- ARMAMOS LA PARTE BASE DE FILTROS
	SET @FILTERS_FIXED_PART = '
			WHERE BSE.[Id] IS NOT NULL '

	-- 
	IF @VCC IS NOT NULL
		SET @FILTERS_OPTIONAL_PART += '
				AND BSE.[VCC] = ''' + @VCC + ''' '

	/* DEPRECATED
	-- CUANDO SE HACE BUSQUEDA POR ULTIMA EJECUCIONES
	IF @SearchCriteria = 'ALREADY_EXECUTED_BY_BS_ID'
		SET @FILTERS_OPTIONAL_PART += '
				AND BSE.[BatchScheduleId] = ''' + @SearchExpression + ''' 
				AND BSE.[Status] <> ''PENDING'' '
	*/
	
	-- CUANDO SE HACE BUSQUEDA POR NO EJECUTADAS
	IF @SearchCriteria = 'NO_EXECUTED_BY_SCHEDULE_ID'
	SET @FILTERS_OPTIONAL_PART += '
				AND BSE.[BatchScheduleId] IN (SELECT Value FROM [dbo].[split](''' + @SearchExpression + ''','','')) 
				AND BSE.[Status] IN (''PENDING'', ''REGISTERED_ON_REDIS'') '

	-- CUANDO SE HACE BUSQUEDA MULTIPLE POR IDS
	IF @SearchCriteria = 'NOT_CREATED_BY_BS_ID'
		SET @FILTERS_OPTIONAL_PART += '
				AND BSE.[BatchScheduleId] IN (SELECT Value FROM [dbo].[split](''' + @SearchExpression + ''','',''))
				AND BSE.[BatchId] IS NULL 
				AND BSE.[Status] NOT LIKE ''CANCELLED_%'' '

	-- CUANDO SE HACE BUSQUEDA POR ULTIMA EJECUCIONES
	IF @SearchCriteria = 'LAST_CREATED_EXECUTIONS'
	SET @FILTERS_OPTIONAL_PART += '
				AND BSE.[BatchScheduleId] IN (SELECT Value FROM [dbo].[split](''' + @SearchExpression + ''','','')) '
	
	-- EL FILTRO POR DEFECTO
	IF @SQL_EXTRA IS NULL OR @SQL_EXTRA  = ''
		SET @SQL_EXTRA += '
			ORDER BY BSE.[ExecutionDate] ASC, BSE.[BatchScheduleId] '

	
	
	-- CUANDO SE HACE BUSQUEDA POR ULTIMA EJECUCIONES
	IF @SearchCriteria = 'LAST_CREATED_EXECUTIONS'
	BEGIN
		-- UNIMOS LAS PARTES DEL QUERY
		SET @SQL_SELECT += @SQL_FROM + @FILTERS_FIXED_PART + @FILTERS_OPTIONAL_PART + @FILTERS_EXCLUDING_PART
		
		--
		SET @SQL = ';WITH CTE AS (' + @SQL_SELECT + ')'

	
		SET @SQL += 'SELECT * FROM CTE BSE WHERE RN = 1 ORDER BY BSE.[ExecutionDate] DESC, BSE.[BatchScheduleId] '
	END
	ELSE
	BEGIN
		-- UNIMOS LAS PARTES DEL QUERY
		SET @SQL_SELECT += @SQL_FROM + @FILTERS_FIXED_PART + @FILTERS_OPTIONAL_PART + @FILTERS_EXCLUDING_PART + @SQL_EXTRA
		SET @SQL += @SQL_SELECT
	END

	-- EJECUTAMOS LA QUERY
	EXEC (@SQL)

	SET NOCOUNT OFF
END
GO
PRINT N'Modificando [dbo].[GetBatchSchedulesSummary]...';


GO
ALTER PROCEDURE [dbo].[GetBatchSchedulesSummary] (
	@VCC VARCHAR(50) = NULL, 
	@SearchCriteria VARCHAR(50) = NULL,
	@SearchExpression VARCHAR(500) = NULL,
	@BatchType VARCHAR(50) = NULL
)
AS
BEGIN
	SET NOCOUNT ON

	-- CREAMOS UNA TABLA TEMPORAL PARA LA ULTIMA EJECUCION DE CADA AGENDA
	CREATE TABLE #TMP_SCHEDULE_LAST_EXECUTION (
		[VCC] VARCHAR(50),
		[BatchScheduleId] VARCHAR(50),
		[BatchId] VARCHAR(50),
		[LastExecutionDate] DATETIME,
		[Status] VARCHAR(50)
	)
	-- BUSCAMOS LAS ULTIMAS EJECUCIONES DE CADA AGENDA
	;WITH CTE_LAST_VALID_EXECUTIONS AS (
		SELECT BSE.[VCC],
				BSE.[BatchScheduleId],
				BSE.[BatchId],
				BSE.[ExecutionDate],
				BSE.[Status],
				RN = ROW_NUMBER() OVER(PARTITION BY BSE.[VCC],
													BSE.[BatchScheduleId]
										ORDER BY BSE.[ExecutionDate] DESC)
			FROM [dbo].[BatchSchedule] BS (NOLOCK)
			INNER JOIN [dbo].[BatchScheduleExecution] BSE (NOLOCK)
				ON BSE.[VCC] = BS.[VCC]
					AND BSE.[BatchScheduleId] = BS.[Id]
			WHERE BS.[VCC] = @VCC
				AND BS.[BatchType] = @BatchType
				AND BS.[Status] IN ('CREATED', 'RUNNING', 'PAUSED', 'FINISHED')
				AND BSE.[Status] NOT IN ('PENDING', 'REGISTERED_ON_REDIS', 'READY_TO_EXECUTE', 'CANCELLED_BY_NO_INTERACTIONS_FOUND')
	)
	INSERT INTO #TMP_SCHEDULE_LAST_EXECUTION
		SELECT [VCC],
				[BatchScheduleId],
				[BatchId],
				[ExecutionDate],
				[Status]
			FROM CTE_LAST_VALID_EXECUTIONS 
			WHERE RN = 1

			--SELECT * FROM [dbo].[BatchScheduleExecution] (NOLOCK) WHERE [BatchScheduleId] = '20211030_0141_prueba'

	-- CREAMOS UNA TABLA TEMPORAL PARA LA PROXIMA EJECUCION DE CADA AGENDA
	CREATE TABLE #TMP_SCHEDULE_NEXT_EXECUTION (
		VCC VARCHAR(50),
		BatchScheduleId VARCHAR(50),
		NextExecutionDate DATETIME
	)
	-- BUSCAMOS LAS ULTIMAS EJECUCIONES DE CADA AGENDA
	;WITH CTE_NEXT_EXECUTIONS AS (
		SELECT BSE.[VCC],
				BSE.[BatchScheduleId],
				BSE.[BatchId],
				BSE.[ExecutionDate],
				BSE.[Status],
				RN = ROW_NUMBER() OVER(PARTITION BY BSE.[VCC],
													BSE.[BatchScheduleId]
										ORDER BY BSE.[ExecutionDate] ASC)
			FROM [dbo].[BatchSchedule] BS (NOLOCK)
			INNER JOIN [dbo].[BatchScheduleExecution] BSE (NOLOCK)
				ON BSE.[VCC] = BS.[VCC]
					AND BSE.[BatchScheduleId] = BS.[Id]
			WHERE BS.[VCC] = @VCC
				AND BS.[BatchType] = @BatchType
				AND BSE.[Status] IN ('PENDING', 'REGISTERED_ON_REDIS')
	)
	INSERT INTO #TMP_SCHEDULE_NEXT_EXECUTION
		SELECT [VCC],
				[BatchScheduleId],
				[ExecutionDate]
			FROM CTE_NEXT_EXECUTIONS 
			WHERE RN = 1



	-- BUSCAMOS LOS RESUMENES DE LAS EJECUCIONES
	;WITH CTE_SUMMARY AS (
		SELECT BS.[VCC], 
				BS.[Id]																							'BatchScheduleId',	
				COUNT(BSE.[Id])																					'Total',
				COUNT(IIF(BSE.[STATUS] LIKE 'REGISTERED_%', 1, NULL))											'Preparing',
				COUNT(IIF(BSE.[STATUS] LIKE '%_CREATED' OR BSE.[STATUS] LIKE '%_STARTED', 1, NULL))				'Running',
				COUNT(IIF(BSE.[STATUS] LIKE 'CANCELLED_%', 1, NULL))											'Cancelled',
				COUNT(IIF(BSE.[STATUS] LIKE 'COMPLETED%' OR BSE.[STATUS] = 'FAILED', 1, NULL))					'Finished',
				COUNT(IIF(BSE.[STATUS] = 'COMPLETED', 1, NULL))													'Succeed',
				COUNT(IIF(BSE.[STATUS] LIKE '%_WITH_ERRORS', 1, NULL))											'Error',
				COUNT(IIF(BSE.[STATUS] LIKE '%FAILED%', 1, NULL))												'Failed'
			FROM [dbo].[BatchSchedule] BS (NOLOCK)
			LEFT JOIN [dbo].[BatchScheduleExecution] BSE (NOLOCK)
				ON BSE.[VCC] = BS.[VCC]
					AND BSE.[BatchScheduleId] = BS.[Id]
			WHERE BS.[VCC] = @VCC
				AND BS.[BatchType] = @BatchType
				AND BS.[Status] IN ('CREATED', 'RUNNING', 'PAUSED', 'FINISHED')
				AND BSE.[Status] <> 'PENDING'
			GROUP BY BS.[VCC], BS.[Id]
	) -- Select * FROM [dbo].[BatchSchedule] BS (NOLOCK)
		SELECT BS.[VCC]																	'vcc',
				BS.[Id]																	'id',
				BS.[BatchType]															'batchType',
				CASE WHEN BS.[BatchType] = 'TEMPLATE' THEN BS.[BatchData]
					ELSE '' END															'batchData',
				BS.[Frequency]															'frequency',
				-- BS.[Weekday]															'weekday',
				-- BS.[Monthday]														'monthday',
				BS.[DaysInterval]														'daysInterval',
				BS.[HoursInterval]														'hoursInterval',
				BS.[StartDate]															'startDate',
				BS.[EndDate]															'endDate',
				BS.[FirstExecutionDate]													'firstExecutionDate',
				BS.[Status]																'status',
				-- BS.[LastExecutionDate]												'lastExecutionDate',
				-- BS.[FinalExecutionDate]												'finalExecutionDate', 
				ISNULL(CTE_S.[Total], 0)												'total',
				ISNULL(CTE_S.[Preparing], 0)											'preparing',
				ISNULL(CTE_S.[Running], 0)												'running',
				ISNULL(CTE_S.[Cancelled], 0)											'cancelled',
				ISNULL(CTE_S.[Finished], 0)												'finished',
				ISNULL(CTE_S.[Succeed], 0)												'succeed',
				ISNULL(CTE_S.[Error], 0)												'error',
				ISNULL(CTE_S.[Failed], 0)												'failed',
				TMP_LE.[LastExecutionDate]												'lastExecutionDate',
				TMP_LE.[Status]															'lastExecutionStatus',
				TMP_NE.[NextExecutionDate]												'nextExecutionDate',
				BS.[CreatedDate]														'createdDate',
				BS.[CreatedByUserId]													'createdByUserId',
				BS.[LastModifiedDate]													'lastModifiedDate',
				BS.[LastModifiedByUserId]												'lastModifiedByUserId'
			FROM [dbo].[BatchSchedule] BS (NOLOCK)
			LEFT JOIN CTE_SUMMARY CTE_S
				ON CTE_S.[VCC] = BS.[VCC]
					AND CTE_S.[BatchScheduleId] = BS.[Id]
			LEFT JOIN #TMP_SCHEDULE_LAST_EXECUTION TMP_LE 
				ON TMP_LE.[VCC] = BS.[VCC]
					AND TMP_LE.[BatchScheduleId] = BS.[Id]
			LEFT JOIN #TMP_SCHEDULE_NEXT_EXECUTION TMP_NE 
				ON TMP_NE.[VCC] = BS.[VCC]
					AND TMP_NE.[BatchScheduleId] = BS.[Id]
			WHERE BS.[VCC] = @VCC
				AND BS.[BatchType] = @BatchType
				AND ISNULL(BS.[Id], '') LIKE CASE WHEN @SearchCriteria = 'NAME' THEN '%' + @SearchExpression + '%' ELSE '%' END

	-- ELIMINAMOS LAS TABLAS TEMPORALES
	IF OBJECT_ID('tempdb..#TMP_SCHEDULE_LAST_EXECUTION') IS NOT NULL DROP TABLE #TMP_SCHEDULE_LAST_EXECUTION
	IF OBJECT_ID('tempdb..#TMP_SCHEDULE_NEXT_EXECUTION') IS NOT NULL DROP TABLE #TMP_SCHEDULE_NEXT_EXECUTION
		
	

	/*
	-- BUSCAMOS LAS ULTIMAS EJECUCIONES DE CADA AGENDA
	;WITH CTE_LAST_VALID_EXECUTIONS AS (
		SELECT BSE.[VCC],
				BSE.[BatchScheduleId],
				BSE.[BatchId],
				BSE.[ExecutionDate],
				BSE.[Status],
				RN = ROW_NUMBER() OVER(PARTITION BY BSE.[VCC],
													BSE.[BatchScheduleId]
										ORDER BY BSE.[ExecutionDate] DESC)
			FROM [dbo].[BatchSchedule] BS (NOLOCK)
			INNER JOIN [dbo].[BatchScheduleExecution] BSE (NOLOCK)
				ON BSE.[VCC] = BS.[VCC]
					AND BSE.[BatchScheduleId] = BS.[Id]
			WHERE BS.[VCC] = @VCC
				AND BS.[Status] IN ('CREATED', 'RUNNING', 'PAUSED')
				AND BSE.[Status] NOT IN ('PENDING', 'REGISTERED_ON_REDIS', 'CANCELLED_BY_NO_INTERACTIONS_FOUND')
				-- AND BSE.[Status] = 'COMPLETED'
	),
	CTE_LAST_EXECUTIONS AS (
		SELECT CTE_VE.[VCC], 
				CTE_VE.[BatchScheduleId], 
				CTE_VE.[BatchId], 
				CASE WHEN CTE_VE.[Status] = 'REGISTERED_ON_REDIS' THEN NULL ELSE CTE_VE.[ExecutionDate] END		'LastExecutionDate', 
				CTE_VE.[Status]
			FROM CTE_LAST_VALID_EXECUTIONS CTE_VE
			WHERE CTE_VE.[RN] = 1
	),
	CTE_NEXT_VALID_EXECUTIONS AS (
		SELECT BSE.[VCC],
				BSE.[BatchScheduleId],
				BSE.[BatchId],
				BSE.[ExecutionDate],
				BSE.[Status],
				CTE_LA.[LastExecutionDate],
				RN = ROW_NUMBER() OVER(PARTITION BY BSE.[VCC],
													BSE.[BatchScheduleId]
										ORDER BY BSE.[ExecutionDate] ASC)
			FROM [dbo].[BatchSchedule] BS (NOLOCK)
			INNER JOIN [dbo].[BatchScheduleExecution] BSE (NOLOCK)
				ON BSE.[VCC] = BS.[VCC]
					AND BSE.[BatchScheduleId] = BS.[Id]
			INNER JOIN CTE_LAST_EXECUTIONS CTE_LA
				ON CTE_LA.[VCC] = BS.[VCC]
					AND CTE_LA.[BatchScheduleId] = BS.[Id]
			WHERE BS.[VCC] = @VCC
				AND BSE.[Status] = 'PENDING'
	),
	CTE_NEXT_EXECUTIONS AS (
		SELECT CTE_VE.[VCC], 
				CTE_VE.[BatchScheduleId], 
				CTE_VE.[BatchId], 
				CTE_VE.[ExecutionDate]																			'NextExecutionDate', 
				CTE_VE.[LastExecutionDate]																		'LastExecutionDate', 
				CTE_VE.[Status]
			FROM CTE_NEXT_VALID_EXECUTIONS CTE_VE
			WHERE CTE_VE.[RN] = 1
	),
	CTE_SUMMARY AS (
		SELECT BS.[VCC], 
				BS.[Id]																							'BatchScheduleId',	
				CTE_NE.[BatchId], 
				CTE_NE.[NextExecutionDate], 
				CTE_NE.[LastExecutionDate], 
				CTE_NE.[Status],
				COUNT(BSE.[Id])																					'Total',
				COUNT(IIF(BSE.[STATUS] LIKE 'REGISTERED_%', 1, NULL))											'Preparing',
				COUNT(IIF(BSE.[STATUS] LIKE '%_CREATED' OR BSE.[STATUS] LIKE '%_STARTED', 1, NULL))				'Running',
				COUNT(IIF(BSE.[STATUS] LIKE 'CANCELLED_%', 1, NULL))											'Cancelled',
				COUNT(IIF(BSE.[STATUS] LIKE 'COMPLETED%' OR BSE.[STATUS] = 'FAILED', 1, NULL))					'Finished',
				COUNT(IIF(BSE.[STATUS] = 'COMPLETED', 1, NULL))													'Succeed',
				COUNT(IIF(BSE.[STATUS] LIKE '%_WITH_ERRORS', 1, NULL))											'Error',
				COUNT(IIF(BSE.[STATUS] LIKE '%FAILED%', 1, NULL))												'Failed'
			FROM [dbo].[BatchSchedule] BS (NOLOCK)
			LEFT JOIN [dbo].[BatchScheduleExecution] BSE (NOLOCK)
				ON BSE.[VCC] = BS.[VCC]
					AND BSE.[BatchScheduleId] = BS.[Id]
			LEFT JOIN CTE_NEXT_EXECUTIONS CTE_NE 
				ON CTE_NE.[VCC] = BS.[VCC]
					AND CTE_NE.[BatchScheduleId] = BS.[Id]
			WHERE BS.[VCC] = @VCC
				AND BS.[Status] IN ('CREATED', 'RUNNING', 'PAUSED')
				AND BSE.[Status] <> 'PENDING'
			GROUP BY BS.[VCC], BS.[Id], CTE_NE.[BatchId], CTE_NE.[NextExecutionDate], CTE_NE.[LastExecutionDate], CTE_NE.[Status]
	)-- select * from CTE_SUMMARY
		SELECT BS.[VCC]																	'vcc',
				BS.[Id]																	'id',
				BS.[BatchType]															'batchType',
				BS.[Frequency]															'frequency',
				--BS.[Weekday]															'weekday',
				--BS.[Monthday]															'monthday',
				BS.[DaysInterval]														'daysInterval',
				BS.[HoursInterval]														'hoursInterval',
				BS.[StartDate]															'startDate',
				BS.[EndDate]															'endDate',
				BS.[FirstExecutionDate]													'firstExecutionDate',
				BS.[Status]																'status',
				--BS.[LastExecutionDate]													'lastExecutionDate',
				-- BS.[FinalExecutionDate]													'finalExecutionDate', 
				ISNULL(CTE_S.[Total], 0)												'total',
				ISNULL(CTE_S.[Preparing], 0)											'preparing',
				ISNULL(CTE_S.[Running], 0)												'running',
				ISNULL(CTE_S.[Cancelled], 0)											'cancelled',
				ISNULL(CTE_S.[Finished], 0)												'finished',
				ISNULL(CTE_S.[Succeed], 0)												'succeed',
				ISNULL(CTE_S.[Error], 0)												'error',
				ISNULL(CTE_S.[Failed], 0)												'failed',
				CTE_S.[LastExecutionDate]												'lastExecutionDate',
				CTE_S.[Status]															'lastExecutionStatus',
				CTE_S.[NextExecutionDate]												'nextExecutionDate',
				BS.[CreatedDate]														'createdDate',
				BS.[CreatedByUserId]													'createdByUserId',
				BS.[LastModifiedDate]													'lastModifiedDate',
				BS.[LastModifiedByUserId]												'lastModifiedByUserId'
			FROM [dbo].[BatchSchedule] BS (NOLOCK)
			LEFT JOIN CTE_SUMMARY CTE_S
				ON CTE_S.[VCC] = BS.[VCC]
					AND CTE_S.[BatchScheduleId] = BS.[Id]
			LEFT JOIN [dbo].[Process] P (NOLOCK)
				ON BS.[BatchType] = 'TRANSCRIPTION'
					AND P.[VCC] = CTE_S.[VCC]
					AND P.[Name] = CTE_S.[BatchId]
			LEFT JOIN [dbo].[EvaluationPlan] EP (NOLOCK)
				ON BS.[BatchType] = 'EVALUATION_PLAN'
					AND EP.[Instance] = CTE_S.[VCC]
					AND EP.[ID] = CTE_S.[BatchId]
			WHERE BS.[VCC] = @VCC
				AND ISNULL(BS.[Id], '') LIKE CASE WHEN @SearchCriteria = 'NAME' THEN '%' + @SearchExpression + '%' ELSE '%' END
	*/

	SET NOCOUNT OFF
END
GO
PRINT N'Modificando [dbo].[GetBillingInteractions]...';


GO
ALTER PROCEDURE [dbo].[GetBillingInteractions] (
	@VCC					VARCHAR(50) = NULL,
	@SecondsPerRequest		DECIMAL(18, 5) = 0,
	@CharsPerPhrase			DECIMAL(18, 5) = 0,
	@Channel				VARCHAR(25) = NULL
)
AS
BEGIN

	-- SEGUN EL TIPO DE CANAL DEFINIMOS LA FUNCION
	IF @Channel = 'CALL'
	BEGIN
		SELECT SUM(CASE WHEN A.[IsTranscribed] = 1 THEN 1 ELSE 0 END)									'alreadyTranscribedAudio',
				SUM(CASE WHEN A.[IsTranscribed] = 1 THEN IT.[AttentionTime] ELSE 0 END)					'alreadyTranscribedDurationTime',
				SUM(CASE WHEN (A.[IsProcess] = 1 
								AND A.[IsTranscribed] IS NULL 
								AND A.[IsCancel] IS NULL) 
							THEN 1 ELSE 0 END)															'inProcessAudio',
				SUM(CASE WHEN (A.[IsProcess] = 1 
								AND A.[IsTranscribed] IS NULL 
								AND A.[IsCancel] IS NULL) 
							THEN IT.[AttentionTime] ELSE 0 END)											'inProcessDurationTime',
				@Channel																				'interactionType',
				SUM(CASE WHEN (A.[IsProcess] IS NULL 
								OR (A.[IsProcess] = 1 
									AND A.[IsCancel] = 1)) 
							THEN 1 ELSE 0 END)															'notTranscribedAudio',
				SUM(CASE WHEN (A.[IsProcess] IS NULL 
								OR (A.[IsProcess] = 1 
									AND A.[IsCancel] = 1)) 
							THEN IT.[AttentionTime] ELSE 0 END)											'notTranscribedDurationTime',
				SUM(CASE WHEN A.[IsTranscribed] = 1 
								AND A.[TotalPhrases] IS NOT NULL
							THEN A.[TotalPhrases] ELSE 0 END)											'totalPhrases',
				SUM(CASE WHEN (A.[IsProcess] IS NULL 
								OR (A.[IsProcess] = 1 
									AND A.[IsCancel] = 1)
								OR (A.[TotalPhrases] IS NULL)) 
							THEN (IT.[AttentionTime] / @SecondsPerRequest) ELSE 0 END)					'totalRawPhrases',
				SUM(IT.[AttentionTime] / @SecondsPerRequest)											'averageModelRequest' 
			FROM [#InteractionsTemp] IT
			LEFT JOIN [dbo].[Audio] A (NOLOCK) 
				ON A.[ID] = IT.[InteractionId]
					AND A.[Section] = IT.[Section]
					AND A.[Part] = IT.[Part] 
			WHERE A.[VCC] = @VCC
	END
	ELSE
	BEGIN
		-- DECLARAMOS UNA VARIABLE PARA PARA EL TOTALDE RESULTADOS
		DECLARE @TOTAL_INTERACTIONS INT = 0

		-- SETTEAMOS EL NUMERO DE REGISTROS A LA VARIABLE DE TOTAL
		SELECT @TOTAL_INTERACTIONS = COUNT(*) FROM [#InteractionsTemp]

		IF @TOTAL_INTERACTIONS = 0 
		BEGIN
			-- SI NO EXISTEN RESULTADOS EN HD LLENAMOSUN RESULTADOS CON 0
			SELECT @Channel																					'interactionType',
					0																						'totalInteractionDetails',
					0																						'alreadyTranscribedInteraction',
					0																						'inProcessInteraction',
					0																						'notTranscribedInteraction',
					0																						'totalPhrases',
					0																						'totalRawChars',
					0																						'totalRawPhrases'
		END 
		ELSE
		BEGIN
			-- CRUZAMOS LA TABLA TEMPORAL DE INTERACCIONES ASINCRONAS CON LA TABLA LOCAL INTERACTION PARA LAS INTERACCIONES ASINCRONAS YA REGISTRADAS
			SELECT ISNULL(IT.[Channel], @Channel)															'interactionType',
					COUNT(*)																				'totalInteractionDetails',
					SUM(CASE WHEN (AI.[VCC] IS NOT NULL 
						AND AI.[IsTranscribed] = 1) THEN 1 ELSE 0 END)										'alreadyTranscribedInteraction',
					0																						'inProcessInteraction',
					SUM(CASE WHEN (AI.[VCC] IS NULL 
						OR AI.[IsTranscribed] <> 1) THEN 1 ELSE 0 END)										'notTranscribedInteraction',
					SUM(ISNULL(AI.[TotalPhrases], 0))														'totalPhrases',
					-- CUANDO TENEMOS VALIDPHRASES, YA NO CONTAMOS LAS RAWCHAR 
					SUM(
						CASE WHEN (AI.[TotalPhrases] IS NULL 
								OR AI.[TotalPhrases] = 0)
						THEN (
							ISNULL(AI.[RawChar], ISNULL(IT.[rawChar], 0))
						)
						ELSE 0 END
					)																						'totalRawChars',
					SUM(
						CASE WHEN (AI.[TotalPhrases] IS NULL 
								OR AI.[TotalPhrases] = 0)
						THEN (
							-- SI RAWCHAR ES NULL, SE DEBE VALUAR COMO MINIMO 1 FRASE(@CharsPerPhrase)
							-- CEILING(ISNULL(AI.[RawChar], ISNULL(HDI.[rawChar], @CharsPerPhrase)) * 1.00 / @CharsPerPhrase)
							CEILING(ISNULL(AI.[RawChar], ISNULL(IT.[RawChar], 0)) * 1.00 / @CharsPerPhrase)
						)
						ELSE 0 END
					)																						'totalRawPhrases' 
				FROM [#InteractionsTemp] IT
				LEFT JOIN [dbo].[AsyncInteraction] AI 
					ON IT.[VCC] = AI.[VCC]
						AND IT.[Channel] = AI.[Channel]
						AND IT.[Campaign] = AI.[Campaign]
						AND IT.[InteractionId] = AI.[ID]
						AND IT.[EndDate] = AI.[EndDate]
				WHERE AI.[VCC] = @VCC
				GROUP BY IT.[VCC],
							IT.[Channel]

		END
	END

	-- ELIMINAMOS LA TABLA TEMPORAL
	DROP TABLE [#InteractionsTemp] 
END
GO
PRINT N'Modificando [dbo].[GetEvaluations]...';


GO
ALTER PROCEDURE [dbo].[GetEvaluations] (
	@Instance Varchar(50) = NULL,
	@IdAuditor VARCHAR(MAX) = NULL,
	@IdAgent Varchar(MAX) = NULL,
   	@IdCampaign VARCHAR(MAX) = NULL,
	@IdEvaluationPlan VARCHAR(MAX) = NULL,
 	@EvaluationDateFrom VARCHAR(50) = '1980-01-01T00:00:00',
    @EvaluationDateTo VARCHAR(50) = '2050-01-01T23:59:59',
	@EvaluationHourFrom VARCHAR(50) = '00:00:00',
    @EvaluationHourTo VARCHAR(50) = '23:59:59',
	@InteractionMinDuration Int = 0,
    @InteractionMaxDuration Int = 86400,
    @InteractionOrigins Varchar(50) = NULL,
	@InteractionResults Varchar(MAX) = NULL,
	@EvaluationTypes Varchar(MAX) = NULL,
	@InteractionTags Varchar(MAX) = NULL,
	@InteractionFormats Varchar(50) = NULL,
	@InteractionCoached VARCHAR(50) = NULL,
	@InteractionIds     VARCHAR(MAX) = NULL,
	@EvaluationsLimit Int = 0,
	@ContactAddress Varchar(300) = NULL
)
AS
BEGIN
	SET NOCOUNT ON
	IF (@EvaluationHourFrom = '') SET @EvaluationHourFrom = '00:00:00';
	IF (@EvaluationHourTo = '') SET @EvaluationHourTo = '23:59:59';
	
	-- SI ORIGINS TIENE DOS VALORES, IGNORAMOS EL FILTRO
	IF (SELECT COUNT(*) FROM [dbo].[split](@InteractionOrigins, ',')) = 2 SET @InteractionOrigins = ''
	
	DECLARE @SQL_SELECT_1 VARCHAR(MAX) = ''
	DECLARE @SQL_FROM VARCHAR(MAX) = ''
	DECLARE @SQL_FILTER VARCHAR(MAX) = ''
	DECLARE @SQL_EXTRA VARCHAR(MAX) = ''
	DECLARE @FILTERS_OPTIONAL_PART VARCHAR(MAX) = ''
    DECLARE @FILTERS_EXCLUDING_PART VARCHAR(MAX) = ''
    DECLARE @FILTERS_FIXED_PART     VARCHAR(MAX) = ''

	-- EMULAMOS UNA NUEVA TABLA EN BASE A INTERACTIONEVALUATIONPLAN
	SET @SQL_SELECT_1 += '
		;WITH CTE AS (
			SELECT ER.[Instance],
					ER.[IdEvaluationPlan],
					ER.[IdInteraction], 
					ER.[IdAgent],
					IEP.[AgentName],
					RN = ROW_NUMBER() OVER(PARTITION BY IEP.[Instance], IEP.[IdEvaluationPlan], IEP.[IdInteraction] ORDER BY IEP.[CreatedDate] ASC)
				FROM [dbo].[EvaluationResult] ER (NOLOCK) 
				INNER JOIN [dbo].[EvaluationPlan] EP (NOLOCK)
					ON EP.[Instance] = ER.[Instance]
						AND EP.[Id] =  ER.[IdEvaluationPlan]
				INNER JOIN [dbo].[AuditorEvaluationPlan] AEP (NOLOCK) 
					ON (AEP.[Instance] = ER.[Instance] 
						AND AEP.[IdAuditor] = ER.[IdAuditor] 
						AND AEP.[IdInteraction] = ER.[IdInteraction] 
						AND AEP.[InteractionType] = ER.[InteractionType] 
						AND AEP.[IdEvaluationPlan] = ER.[IdEvaluationPlan]) 
				INNER JOIN [dbo].[InteractionEvaluationPlan] IEP (NOLOCK)
					ON IEP.[Instance] = ER.[Instance] 
						AND IEP.[IdEvaluationPlan] = EP.[ID]
						AND IEP.[IdInteraction] = ER.[IdInteraction]
						AND IEP.[IdAgent] = ER.[IdAgent]
				WHERE ER.[Instance] = ''' + @Instance + '''
					AND ER.[EvaluationDate] BETWEEN ''' + @EvaluationDateFrom + '''AND ''' + @EvaluationDateTo + '''
					AND EP.[Status] = CASE EP.[Evaluation_Mode] WHEN ''A'' THEN 7 ELSE EP.[Status] END 
					AND AEP.[Completed] = 1
		) '

	SET @SQL_SELECT_1 += '
		SELECT '

	SET @SQL_SELECT_1 += '
				AEP.Completed						''completed'',
				AEP.[StatusDescription]             ''statusDescription'',
				A.[ErrorMessage]                    ''errorMessage'',
    			AEP.score							''qualification'',
    			AEP.IdAuditor						''idAuditor'',
    			U.FirstName + '' '' + U.LastName	''auditorName'',
    			MAX(ER.EvaluationDate)				''evaluationDate'',
    			AEP.IdEvaluationPlan				''idEvaluationPlan'',
				EP.Description						''evaluationPlan'',
				EP.[Evaluation_Mode]				''evaluationType'',
    			AEP.idAgent							''idAgent'',
    			C.[AgentName]						''agentName'',							-- NOMBRE DEL AGENTE
				AEP.idInteraction					''idInteraction'',
				AEP.InteractionDate					''interactionDate'',
    			AEP.InteractionType					''interactionType'',
    			AEP.IdCampaign						''idCampaign'',
				E.[Type]							''environmentType'',
				IIF (
					ERV.[InteractionId] IS NULL,
					CAST(0 AS BIT),
					CAST(1 AS BIT)
				)									''review'',
				COUNT(ERC.[Id])						''commitments'' '

	SET @SQL_FROM += '
			FROM EvaluationResult ER (NOLOCK) 
			LEFT JOIN [EvaluationPlan] EP (NOLOCK) 
				ON (EP.[Instance] = ER.[Instance] 
					AND EP.[ID] = ER.IdEvaluationPlan) 
			LEFT JOIN [AuditorEvaluationPlan] AEP (NOLOCK) 
				ON (AEP.[Instance] = ER.[Instance] 
					AND AEP.[IdAuditor] = ER.[IdAuditor] 
					AND AEP.[IdInteraction] = ER.[IdInteraction] 
					AND AEP.[InteractionType] = ER.[InteractionType] 
					AND AEP.[IdEvaluationPlan] = ER.[IdEvaluationPlan]) 
			LEFT JOIN [dbo].[EvaluationReview] ERV (NOLOCK)
				ON ERV.[VCC] = AEP.[Instance]
					AND ERV.[EvaluationPlanId] = AEP.[IdEvaluationPlan]
					AND ERV.[InteractionId] = AEP.[IdInteraction]
			LEFT JOIN [dbo].[EvaluationReviewCommitment] ERC (NOLOCK)
				ON ERC.[VCC] = AEP.[Instance] 
					AND ERC.[EvaluationPlanId] = AEP.[IdEvaluationPlan]
					AND ERC.[InteractionId] = AEP.[IdInteraction]
					AND ERC.[SupervisorId] = AEP.[IdAuditor] 
					AND ERC.[AgentId] = AEP.[idAgent]
			LEFT JOIN [dbo].[Audio] A (NOLOCK)
			    ON A.[VCC] = AEP.[Instance]
			        AND A.[ID] = AEP.[IdInteraction]
			LEFT JOIN [dbo].[Environment] E (NOLOCK)
				ON E.[VCC] = ER.[Instance]
					AND E.[Name] = EP.[EnvironmentId]
			LEFT JOIN [User] U (NOLOCK) 
				ON (U.[VCC] = ER.[Instance] 
					AND U.ID = AEP.IdAuditor) 
			LEFT JOIN CTE C (NOLOCK) 
				ON C.[Instance] = ER.[Instance]
					AND C.[IdEvaluationPlan] = ER.[IdEvaluationPlan]
					AND C.[IdInteraction] = ER.[IdInteraction] 
					AND C.[IdAgent] = ER.[IdAgent] 
					AND C.RN = 1 '

	SET @FILTERS_FIXED_PART = '
			WHERE ER.[Instance] = ''' + @Instance + '''
				AND ER.[EvaluationDate] >= ''' + @EvaluationDateFrom + '''
				AND ER.[EvaluationDate] <= ''' + @EvaluationDateTo + '''
				AND EP.[Status] = CASE EP.[Evaluation_Mode] WHEN ''A'' THEN 7 ELSE EP.[Status] END 
				AND AEP.[Completed] = 1 ' -- LINEA PARA FILTRAR EVALUACIONES COMPLETADAS

	IF (@IdAuditor IS NOT NULL AND @IdAuditor != '') SET @FILTERS_OPTIONAL_PART += 'AND AEP.[IdAuditor] IN (SELECT Value FROM [dbo].[split](''' + @IdAuditor + ''','','')) '
	IF (@IdAgent IS NOT NULL AND @IdAgent != '') SET @FILTERS_OPTIONAL_PART += 'AND AEP.[IdAgent] IN (SELECT Value FROM [dbo].[split](''' + @IdAgent + ''','','')) '
	IF (@IdCampaign IS NOT NULL AND @IdCampaign != '') SET @FILTERS_OPTIONAL_PART += 'AND AEP.[IdCampaign] IN (SELECT Value FROM [dbo].[split](''' + @IdCampaign + ''','','')) '
	IF (@IdEvaluationPlan IS NOT NULL AND @IdEvaluationPlan != '') SET @FILTERS_OPTIONAL_PART += 'AND EP.[ID] IN (SELECT Value FROM [dbo].[split](''' + @IdEvaluationPlan + ''','','')) '
	IF (CAST(@EvaluationHourFrom AS TIME) <= CAST(@EvaluationHourTo AS TIME)) SET @FILTERS_OPTIONAL_PART += 'AND CAST(ER.[EvaluationDate] AS TIME) BETWEEN ''' + @EvaluationHourFrom + ''' AND ''' + @EvaluationHourTo + ''' '
	IF (CAST(@EvaluationHourFrom AS TIME) > CAST(@EvaluationHourTo AS TIME)) SET @FILTERS_OPTIONAL_PART += 'AND CAST(ER.[EvaluationDate] AS TIME) NOT BETWEEN ''' + @EvaluationHourTo + ''' AND ''' + @EvaluationHourFrom + ''' '
	IF (@InteractionMinDuration IS NOT NULL) SET @FILTERS_OPTIONAL_PART += 'AND AEP.[InteractionDuration] >= ' + (SELECT CONVERT(varchar(10), @InteractionMinDuration)) + ' '
	IF (@InteractionMaxDuration IS NOT NULL) SET @FILTERS_OPTIONAL_PART += 'AND AEP.[InteractionDuration] <= ' + (SELECT CONVERT(varchar(10), @InteractionMaxDuration))+ ' '
	IF (@InteractionOrigins IS NOT NULL AND @InteractionOrigins != '') SET @FILTERS_OPTIONAL_PART += 'AND AEP.[InteractionOrigin] IN (SELECT Value FROM [dbo].[split](''' + @InteractionOrigins + ''','','')) '
	--IF (@InteractionResults IS NOT NULL AND @InteractionResults != '') SET @FILTERS_OPTIONAL_PART += 'AND CONCAT(AEP.[IdCampaign], ''_'', AEP.[ManagementResult]) IN (SELECT Value FROM [dbo].[split](''' + @InteractionResults + ''','','')) '
	IF (@InteractionResults IS NOT NULL AND @InteractionResults != '') 
		SET @FILTERS_OPTIONAL_PART += 'AND (
								(CONCAT(AEP.[IdCampaign], ISNULL(REPLACE(AEP.[ManagementResult], ''/'', ''_''), ''_'')) IN (SELECT Value FROM [dbo].[split](''' + @InteractionResults + ''','','')))
								OR
								(CONCAT(AEP.[IdCampaign], ''_'', ISNULL(AEP.[ManagementResult], ''_'')) IN (SELECT Value FROM [dbo].[split](''' + @InteractionResults + ''','','')))
								OR
								(AEP.[ManagementResult] IN (SELECT Value FROM [dbo].[split](''' + @InteractionResults + ''','','')))
							)'
	
	IF (@EvaluationTypes IS NOT NULL AND @EvaluationTypes != '') 
	BEGIN
		SET @FILTERS_OPTIONAL_PART += '
				AND EP.[Evaluation_Mode] IN (SELECT Value FROM [dbo].[split](''' + @EvaluationTypes + ''','',''))  '
	END

	IF(@ContactAddress <> '')
		BEGIN
			SET @FILTERS_OPTIONAL_PART += '
				AND AEP.[ContactAddress] LIKE ''%' + @ContactAddress + '%''
			'
	END	
	
	IF (@InteractionTags IS NOT NULL AND @InteractionTags != '') 
	BEGIN
		SET @SQL_FROM += '
			LEFT JOIN [Tag] T (NOLOCK) 
				ON (T.[VCC] = ER.[Instance] 
					AND T.[Tag] IN (SELECT Value FROM [dbo].[split](''' + @InteractionTags + ''','',''))) '
		SET @FILTERS_OPTIONAL_PART += '
				AND T.[AudioId] LIKE CONCAT(AEP.[IdInteraction], ''%'') 
				AND T.[AudioId] IS NOT NULL '
	END
	
	--IF (@InteractionFormats IS NOT NULL AND @InteractionFormats != '') SET @FILTERS_OPTIONAL_PART += 'AND AEP.[InteractionFormat] IN (SELECT Value FROM [dbo].[split](''' + @InteractionFormats + ''','','')) '

	IF (@InteractionIds IS NOT NULL AND @InteractionIds <> '')
    BEGIN
        SET @FILTERS_OPTIONAL_PART = ''
	    SET @FILTERS_EXCLUDING_PART += ' AND AEP.[IdInteraction] IN (SELECT Value FROM [dbo].[split](''' + @InteractionIds + ''','','')) '
	END

	SET @SQL_EXTRA += '
			GROUP BY AEP.Completed,
						AEP.[StatusDescription],
						A.[ErrorMessage],
						AEP.score,
						AEP.IdAuditor,
						U.FirstName + '' '' + U.LastName,
						AEP.IdEvaluationPlan,
						EP.Description,
						EP.[Evaluation_Mode],
						AEP.idAgent,
						C.[AgentName],
						AEP.idInteraction,
						AEP.InteractionDate,
						AEP.InteractionType,
						AEP.IdCampaign, 
						E.[Type],
						ERV.[InteractionId]'

	IF @InteractionCoached IS NOT NULL AND @InteractionCoached != ''
	BEGIN
		IF @InteractionCoached = 'true'
			SET @SQL_EXTRA += '
				HAVING COUNT(ERC.[Id]) >= 1 '
		ELSE 
			SET @SQL_EXTRA += '
				HAVING COUNT(ERC.[Id]) = 0 '
	END

	SET @SQL_EXTRA += '
			ORDER BY MAX(ER.EvaluationDate) DESC '

	SET @SQL_SELECT_1 += @SQL_FROM  + @FILTERS_FIXED_PART + @FILTERS_OPTIONAL_PART + @FILTERS_EXCLUDING_PART + @SQL_EXTRA 

	-- SELECT @SQL_SELECT_1
	EXEC (@SQL_SELECT_1)
	
END
GO
PRINT N'Modificando [dbo].[GetStudies]...';


GO
ALTER PROCEDURE [dbo].[GetStudies]
(
	@VCC Varchar(50) = NULL,
	@SearchCriteria Varchar(50) = NULL,
	@SearchExpression Varchar(50) = NULL,
	@StartDate DATETIME, 
	@EndDate DATETIME,
	@Type VARCHAR(50)
)
AS
BEGIN
	DECLARE @SQL NVARCHAR(MAX)
	SET @SQL = '
	SET NOCOUNT ON

	SELECT
		[VCC]							''vcc'',
		[ProcessId]						''processId'',
		[TemplateId]					''templateId'',
		[Name]							''name'',
		[Description]					''description'',
		[Type]							''type'',
		[Status]						''status'',
		[Error]							''error'',
		[Percentage]					''percentage'',
		[StatusDescription]				''statusDescription'',
		[LastQueryId]					''lastQueryId'',
		[ErrorMessage]					''errorMessage'',
		[BatchStatus]					''batchStatus'',
		[CreatedDate]					''createdDate'',
		[CreatedByUserId]				''createdByUserId'',
		[LastModifiedDate]				''lastModifiedDate'',
		[LastModifiedByUserId]			''lastModifiedByUserId''
	FROM [dbo].[Study] S (NOLOCK)
	WHERE [VCC] = ''' + @VCC + '''
		AND [Type] = ''' + @Type + '''
		AND ISNULL([Name], '''') LIKE CASE WHEN ''' + @SearchCriteria + ''' = ''name'' THEN ''%' + @SearchExpression + '%'' ELSE ''%'' END
		AND ISNULL([Description], '''') LIKE CASE WHEN ''' + @SearchCriteria + ''' = ''description'' THEN ''%' + @SearchExpression + '%'' ELSE ''%'' END
		AND ISNULL([Status], '''') LIKE CASE WHEN ''' + @SearchCriteria + ''' = ''status'' THEN ''%' + @SearchExpression + '%'' ELSE ''%'' END'

	IF(@StartDate IS NOT NULL AND @EndDate IS NOT NULL)
	BEGIN
		SET @SQL += '
			AND [CreatedDate] BETWEEN ''' + CONVERT(VARCHAR(10), @StartDate, 120) + ''' AND ''' + CONVERT(VARCHAR(10), @EndDate, 120) + '''
		'
	END
	SET @SQL += '
	ORDER BY [Status] desc, [CreatedDate] desc 

	SET NOCOUNT OFF
	'
	EXEC(@SQL)
END
GO
PRINT N'Modificando [dbo].[GetTemplate]...';


GO
--exec [GetTemplate] 'inconcert','Template1'
ALTER PROCEDURE [dbo].[GetTemplate] (
	@VCC Varchar(50) = NULL, @Name Varchar(50) = NULL
	)
AS
BEGIN
	SET NOCOUNT ON

	SELECT
		[VCC]							'vcc',
		[Type]							'type',
		[Name]						    'name',
		[Description]					'description',
		[Template]						'template',
		[Category]						'category',
		[CreatedDate]					'createdDate',
		[CreatedByUserId]				'createdByUserId',
		[LastModifiedDate]				'lastModifiedDate',
		[LastModifiedByUserId]			'lastModifiedByUserId'
	FROM [Template] (NOLOCK)
	WHERE [VCC] = CASE WHEN ISNULL(@VCC,'') = '' THEN [VCC] ELSE @VCC END
	AND [Name] = @Name

	EXEC [GetTemplateThemes] @VCC, @Name
	
	SET NOCOUNT OFF
END
GO
PRINT N'Modificando [dbo].[GetTemplates]...';


GO
--exec [GetTemplates] 'system','template','name',''
ALTER PROCEDURE [dbo].[GetTemplates] (
	@VCC Varchar(50) = NULL,	
	@Type Varchar(50) = NULL,	
	@SearchCriteria Varchar(50) = NULL,	
	@SearchExpression Varchar(50) = NULL,
	@Language VARCHAR(5) = 'en'
	)
AS
BEGIN
	SET NOCOUNT ON

	-- CREAMOS LAS CTE QUE USAREMOS PARA RECUPERAR LOS MODELOS DE LAS PLANTILLAS
	;WITH CTE_TEMPLATE_NLUS AS (
		SELECT DISTINCT TTI.[VCC]
						, TTI.[TemplateId]
						--, TTI.[TemplateThemeId]
						--, TTI.[ID]
						, N.[AppID]
						, N.[Name]
						, N.[Culture]
			FROM [TemplateThemeItem] TTI (NOLOCK)
			LEFT JOIN [dbo].[GenericQuery] GQ (NOLOCK) 
				ON GQ.[VCC] = TTI.[VCC]
					AND GQ.[Name] = TTI.[ID] 
					AND GQ.[VCC] = TTI.[VCC]
			INNER JOIN [dbo].[NLU] N (NOLOCK) 
				ON N.[VCC] = TTI.[VCC] 
					AND N.[Name] = SUBSTRING(TTI.[ID], 0, CHARINDEX('|', TTI.[ID]))
			WHERE TTI.[VCC] IN (@VCC, 'system')
				AND TTI.[ID] LIKE '%|%'
				AND GQ.[Query] IS NULL
	),
	TEMP_TEMPLATE AS (
		SELECT T.[Type]																	'type',
				T.[Name]																'name',
				T.[Description]															'description',
				T.[Template]															'template',
				T.[Category]															'category',
				STUFF((
					SELECT ',' + CTN_INNER.[Culture]
						FROM CTE_TEMPLATE_NLUS CTN_INNER (NOLOCK)
						WHERE CTN_INNER.[TemplateId] = T.[Name]
				FOR XML PATH(''), TYPE).value('.', 'NVARCHAR(MAX)'), 1, 1, '')			'modelLanguages',
				T.[CreatedDate]															'createdDate',
				T.[CreatedByUserId]														'createdByUserId',
				T.[LastModifiedDate]													'lastModifiedDate',
				T.[LastModifiedByUserId]												'lastModifiedByUserId'
			FROM [dbo].[Template] T (NOLOCK)
			LEFT JOIN [dbo].[BatchSchedule] BS (NOLOCK)
				ON BS.[VCC] = T.[VCC]
					AND BS.[BatchData] = T.[Name]
			WHERE (
					T.[VCC] = @VCC
					OR
					(
						T.[VCC] = 'system'
						AND 
						T.[Name] LIKE @Language + '%'
					)
				)
				AND ISNULL(T.[Name], '') LIKE CASE WHEN @SearchCriteria = 'name' THEN '%' + @SearchExpression + '%' ELSE '%' END
				AND ISNULL(T.[Category], '') LIKE CASE WHEN @SearchCriteria = 'category' THEN '%' + @SearchExpression + '%' ELSE '%' END
				AND ISNULL(T.[Description], '') LIKE CASE WHEN @SearchCriteria = 'description' THEN '%' + @SearchExpression + '%' ELSE '%' END
				AND ISNULL(T.[Type], '') LIKE CASE WHEN @SearchCriteria = 'type' THEN '%' + @SearchExpression + '%' ELSE '%' END
				AND ( -- BLOQUE PARA OBTENER LAS PLANTILLAS QUE NO TIENEN ASIGNADA UNA AGENDA (PLANTILLA GLOBAL)
					(
						@SearchCriteria = 'schedule'
						AND 
						BS.[Id] IS NULL
					)
					OR
					@SearchCriteria <> 'schedule'
				)
				AND ( -- BLOQUE PARA OBTENER LAS PLANTILLAS QUE TIENEN ASIGNADA UNA AGENDA (PLANTILLA GLOBAL)
					(
						@SearchCriteria = 'scheduled'
						AND 
						BS.[Id] IS NOT NULL
					)
					OR
					@SearchCriteria <> 'scheduled'
				)
				/*
	SELECT
		T.[Type]																'type',
		T.[Name]																'name',
		T.[Description]															'description',
		T.[Template]															'template',
		T.[Category]															'category',
		STUFF((
			SELECT ',' + CTN_INNER.[Culture]
				FROM CTE_TEMPLATE_NLUS CTN_INNER (NOLOCK)
				WHERE CTN_INNER.[TemplateId] = T.[Name]
		FOR XML PATH(''), TYPE).value('.', 'NVARCHAR(MAX)'), 1, 1, '')			'modelLanguages',
		T.[CreatedDate]															'createdDate',
		T.[CreatedByUserId]														'createdByUserId',
		T.[LastModifiedDate]													'lastModifiedDate',
		T.[LastModifiedByUserId]												'lastModifiedByUserId'
	FROM [Template] T (NOLOCK)
	WHERE T.[VCC] IN (@VCC)
		AND T.[Type] = CASE WHEN ISNULL(@Type, '') = '' THEN T.[Type] ELSE @Type END
		AND T.[Type] IN ('custom')
		AND ISNULL(T.[Name], '') LIKE CASE WHEN @SearchCriteria = 'name' THEN '%' + @SearchExpression + '%' ELSE '%' END
		AND ISNULL(T.[Category], '') LIKE CASE WHEN @SearchCriteria = 'category' THEN '%' + @SearchExpression + '%' ELSE '%' END
		AND ISNULL(T.[Description], '') LIKE CASE WHEN @SearchCriteria = 'description' THEN '%' + @SearchExpression + '%' ELSE '%' END
		AND ISNULL(T.[Type], '') LIKE CASE WHEN @SearchCriteria = 'type' THEN '%' + @SearchExpression + '%' ELSE '%' END
		
		UNION 
		
		SELECT
		T.[Type]																'type',
		T.[Name]																'name',
		T.[Description]															'description',
		T.[Template]															'template',
		T.[Category]															'category',
		STUFF((
			SELECT ',' + CTN_INNER.[Culture]
				FROM CTE_TEMPLATE_NLUS CTN_INNER (NOLOCK)
				WHERE CTN_INNER.[TemplateId] = T.[Name]
		FOR XML PATH(''), TYPE).value('.', 'NVARCHAR(MAX)'), 1, 1, '')			'modelLanguages',
		T.[CreatedDate]															'createdDate',
		T.[CreatedByUserId]														'createdByUserId',
		T.[LastModifiedDate]													'lastModifiedDate',
		T.[LastModifiedByUserId]												'lastModifiedByUserId'
	FROM [Template] T (NOLOCK)
	WHERE T.[VCC] IN ('system')
		AND T.[Type] = CASE WHEN ISNULL(@Type, '') = '' THEN T.[Type] ELSE @Type END
		AND T.[Type] IN ('system')
		AND T.[Name] LIKE @Language+'%'
		AND ISNULL(T.[Name], '') LIKE CASE WHEN @SearchCriteria = 'name' THEN '%' + @SearchExpression + '%' ELSE '%' END
		AND ISNULL(T.[Category], '') LIKE CASE WHEN @SearchCriteria = 'category' THEN '%' + @SearchExpression + '%' ELSE '%' END
		AND ISNULL(T.[Description], '') LIKE CASE WHEN @SearchCriteria = 'description' THEN '%' + @SearchExpression + '%' ELSE '%' END
		AND ISNULL(T.[Type], '') LIKE CASE WHEN @SearchCriteria = 'type' THEN '%' + @SearchExpression + '%' ELSE '%' END
		*/
	)


		SELECT * 
			FROM TEMP_TEMPLATE 
			WHERE [NAME] NOT LIKE 'qty_%' 
				AND [type] <> 'global'
		ORDER BY [Name] asc, [CreatedDate] desc 
		
	--ORDER BY T.[Name] asc, T.[CreatedDate] desc 

	SET NOCOUNT OFF
END
GO
PRINT N'Modificando [dbo].[GetTemplateThemeItems]...';


GO
--exec [GetTemplateThemeItems] 'system',''
ALTER PROCEDURE [dbo].[GetTemplateThemeItems] (
	@VCC Varchar(50) = NULL, 
	@TemplateId Varchar(50) = NULL,
	@TemplateThemeId Varchar(50) = NULL
)
AS
BEGIN
	SET NOCOUNT ON
	
	SELECT A.vcc,
			A.[TemplateId]									'templateId',
			A.[TemplateThemeId]								'templateThemeId',
			A.[ID]											'id',
			B.[Query]										'query',
			TT.[AnalysisType]								'analysisType',
			A.[AcceptancePercentage]						'acceptancePercentage',
			ISNULL(A.[AcceptancePercentage],0) * 100        'acceptanceInteger',
			A.[CreatedDate]									'createdDate',
			A.[CreatedByUserId]								'createdByUserId',
			A.[LastModifiedDate]							'lastModifiedDate',
			A.[LastModifiedByUserId]						'lastModifiedByUserId'
		FROM [TemplateThemeItem] A (NOLOCK)
		INNER JOIN [dbo].[TemplateTheme] TT (NOLOCK)
			ON TT.[VCC] = A.[VCC]
				AND TT.[TemplateId] = A.[TemplateId]
				AND TT.[ID] = A.[TemplateThemeId]
		INNER JOIN [dbo].[GenericQuery] B (NOLOCK) 
			ON B.[VCC] = A.[VCC]
				AND B.[Name] = A.[ID]
		WHERE A.[VCC] = @VCC
			AND A.[TemplateId] = CASE WHEN ISNULL(@TemplateId, '') = '' THEN A.[TemplateId] ELSE @TemplateId END
			AND A.[TemplateThemeId] = CASE WHEN ISNULL(@TemplateThemeId, '') = '' THEN A.[TemplateThemeId] ELSE @TemplateThemeId END

	SET NOCOUNT OFF
END
GO
PRINT N'Modificando [dbo].[GetTemplateThemeModels]...';


GO
-- exec [GetTemplateThemeModels] 'allegro','Test1234'
ALTER PROCEDURE [dbo].[GetTemplateThemeModels] (
	@VCC Varchar(50) = NULL, 
	@TemplateId Varchar(50) = NULL,
	@TemplateThemeId Varchar(50) = NULL
)
AS
BEGIN
	SET NOCOUNT ON

	-- DECLARAMOS UNA VARIABLE PARA DETERMINAR SI ES UN FORMATO O PLANTILLA
	DECLARE @TEMPLATE_TYPE VARCHAR(50) = NULL

	-- BUSCAMOS POR EL ID SI SE TRATA DE UNA PLANTILLA O FORMATO
	IF EXISTS (
		SELECT 1 
			FROM [dbo].[Template] T (NOLOCK)
			INNER JOIN [dbo].[EvaluationFormat] EF (NOLOCK)
				ON EF.[Instance] = T.[VCC]
					AND EF.[templateId] = T.[Name]
			WHERE T.[VCC] = @VCC
				AND T.[Name] = @TemplateId
	)
		SET @TEMPLATE_TYPE = 'EVALUATION_FORMAT'
	ELSE 
		SET @TEMPLATE_TYPE = 'TEMPLATE'

	-- 
	SELECT A.[VCC]												'vcc',	
			A.[TemplateId]										'templateId',
			A.[TemplateThemeId]									'templateThemeId',
			A.[ID]												'id',
			-- CASE WHEN ISNULL(B.[Query],'') = ISNULL(NULL,'') THEN A.[ID] ELSE B.[Query] END	'query',
			A.[ID]												'query',
			@TEMPLATE_TYPE										'templateType',
			A.[AcceptancePercentage]							'acceptancePercentage',
			ISNULL(A.[AcceptancePercentage],0) * 100			'acceptanceInteger',
			A.[CreatedDate]										'createdDate',
			A.[CreatedByUserId]									'createdByUserId',
			A.[LastModifiedDate]								'lastModifiedDate',
			A.[LastModifiedByUserId]							'lastModifiedByUserId'
		FROM [TemplateThemeItem] A (NOLOCK)
		INNER JOIN [dbo].[TemplateTheme] TT (NOLOCK)
			ON TT.[VCC] = A.[VCC]
				AND TT.[ID] = A.[TemplateThemeId]
		LEFT JOIN [dbo].[GenericQuery] B (NOLOCK) 
			ON A.[ID] = B.[Name] 
				AND A.[VCC] = B.[VCC]
		WHERE A.[VCC] = @VCC
			AND A.[TemplateId] = CASE WHEN ISNULL(@TemplateId, '') = '' THEN A.[TemplateId] ELSE @TemplateId END
			AND A.[TemplateThemeId] = CASE WHEN ISNULL(@TemplateThemeId, '') = '' THEN A.[TemplateThemeId] ELSE @TemplateThemeId END
			AND B.[Name] IS NULL

	SET NOCOUNT OFF
END
GO
PRINT N'Modificando [dbo].[SaveEvaluationFormat]...';


GO

ALTER PROCEDURE [dbo].[SaveEvaluationFormat] (
	@Instance Varchar(50) = NULL, 						
	@ID Varchar(50) = NULL,
	@Description Varchar(50) = NULL,
	@Type Varchar(50) = NULL,
	@EnvironmentType VARCHAR(50) = NULL,
	@CreatedDate Datetime = NULL,						
	@CreatedByUserId Varchar(50) = NULL,		
	@LastModifiedDate Datetime = NULL,
	@LastModifiedByUserId Varchar(50) = NULL,			
	@MinQualificationAcceptable numeric(5,2),	
	@MinAutomaticQualification NUMERIC(5, 2),
	@ManagementFormURL varchar(1000) = NULL,
	@Enabled bit = NULL, 
	@templateId Varchar(50) = NULL
)
AS
BEGIN
	SET NOCOUNT ON

	-- Danny Jhonston:
	-- Inicio:
	-- Validar si el formato tiene al menos un plan asignado.
	-- Validar si el formato tiene un plan de evaluacion que tiene evaluaciones pendientes.

	-- DECLARE @ID VARCHAR(50)
	-- SET @ID = '183fedb7-9dbf-4b1c-8efd-b1164f33c8ba'

	-- Tabla temporal para almacenar resultado de consulta.
	DECLARE @EvaluationsData TABLE (
		[ID]						VARCHAR(50),
		[totalEvaluations]			INT,
		[completedEvaluations]		INT
	)
	INSERT INTO @EvaluationsData
	SELECT
		EP.[ID]									'id',
		COUNT(AEP.[IdInteraction])				'totalEvaluations',
		SUM(CAST(AEP.[Completed] AS INT))		'completedEvaluations'
	FROM
		[dbo].[EvaluationPlan] EP
		INNER JOIN [dbo].[AuditorEvaluationPlan] AEP ON EP.[ID] = AEP.[IdEvaluationPlan]
	WHERE
		EP.[Instance] = @Instance
		AND EP.[IdEvaluationFormat] = @ID
	GROUP BY EP.[ID]

	-- Contiene las evaluaciones de un formato.
	DECLARE @TotalEvaluations INT
	SET @TotalEvaluations = (SELECT COUNT([ID]) FROM @EvaluationsData WHERE (CAST([completedEvaluations] AS NUMERIC(18, 2)) / CAST([totalEvaluations] AS NUMERIC(18, 2))) * 100 > 0)
	-- SET @TotalEvaluations = (SELECT COUNT([ID]) FROM @EvaluationsData WHERE [totalEvaluations] > [completedEvaluations])

	--PRINT @TotalEvaluations
	IF(@TotalEvaluations > 0)
	BEGIN
		BEGIN
			-- Tiene evaluaciones asociadas que en al menos se esta evaluando un plan de evaluacion.
			SELECT CAST(-1 AS INT) 'idEvaluationFormat'
			PRINT @@ROWCOUNT
		END
	END
	ELSE
	-- Danny Jhonston:
	-- Fin:
	BEGIN
		-- No tiene evaluaciones asociadas.
		-- Debe continuar con el guardado.

		UPDATE [EvaluationFormat] SET
			[Description] = @Description,
			[Type] = @Type,
			[EnvironmentType] = @EnvironmentType,
			[MinQualificationAcceptable] = @MinQualificationAcceptable,
			[MinAutomaticQualification] = @MinAutomaticQualification,
			[ManagementFormURL] = @ManagementFormURL,
			[CreatedDate] = CASE WHEN @CreatedDate IS NULL THEN [CreatedDate] ELSE @CreatedDate END,
			[CreatedByUserId] = CASE WHEN @CreatedByUserId IS NULL THEN [CreatedByUserId] ELSE @CreatedByUserId END,
			[LastModifiedDate] = CASE WHEN @LastModifiedDate IS NULL THEN [LastModifiedDate] ELSE @LastModifiedDate END,
			[LastModifiedByUserId] = CASE WHEN @LastModifiedByUserId IS NULL THEN [LastModifiedByUserId] ELSE @LastModifiedByUserId END,
			[Enabled] = CASE WHEN @Enabled IS NULL THEN 1 ELSE @Enabled END,
			[TimeStamp] = GETUTCDATE(),
			[templateId] = @templateId
		WHERE [Instance] = @Instance
		AND [ID] = @ID

		

		IF @@ROWCOUNT = 0
			INSERT INTO [EvaluationFormat] (
				[Instance],[ID], [Description], [Type], 
				[EnvironmentType], [MinQualificationAcceptable], [MinAutomaticQualification], [ManagementFormURL],
				[CreatedDate], [CreatedByUserId], [LastModifiedDate], [LastModifiedByUserId],
				[Enabled], [TimeStamp], [templateId]
				)
			VALUES (
				@Instance, @ID, @Description, @Type, 
				@EnvironmentType, @MinQualificationAcceptable, @MinAutomaticQualification, @ManagementFormURL,
				@CreatedDate, @CreatedByUserId, @LastModifiedDate, @LastModifiedByUserId,
				@Enabled, GETUTCDATE(), @templateId
			)

		SELECT CAST(Scope_Identity() AS INT) as 'idEvaluationFormat';
	END

	

    SET NOCOUNT OFF
END
GO
PRINT N'Modificando [dbo].[SaveEvaluationFormatCustomField]...';


GO
ALTER PROCEDURE [dbo].[SaveEvaluationFormatCustomField] (
	@VCC VARCHAR(50) = NULL, 
	@ID VARCHAR(50) = NULL,
	@EvaluationFormatId VARCHAR(50) = NULL,
	@CustomFieldId VARCHAR(100) = NULL,
	@Order Int = NULL,
	@CreatedByUserId VARCHAR(50) = NULL,
	@LastModifiedByUserId VARCHAR(50) = NULL
) AS
BEGIN
	SET NOCOUNT ON

	UPDATE [EvaluationFormatCustomField]
		SET [Order] = @Order,
			[LastModifiedDate] = GETUTCDATE(),
			[LastModifiedByUserId] = CASE WHEN @LastModifiedByUserId IS NULL THEN [LastModifiedByUserId] ELSE @LastModifiedByUserId END,
			[TimeStamp] = GETUTCDATE()
		WHERE [VCC] = @VCC
			AND [EvaluationFormatId] = @EvaluationFormatId
			AND [CustomFieldId] = @CustomFieldId

    IF @@ROWCOUNT = 0
		INSERT INTO [EvaluationFormatCustomField] (
			[VCC], 
			[ID],
			[EvaluationFormatId],
			[CustomFieldId],
			[Order], 
			[CreatedDate],
			[CreatedByUserId],
			[TimeStamp]
		)
		VALUES (
			@VCC, 
			@ID,
			@EvaluationFormatId,
			@CustomFieldId, 
			@Order,
			GETUTCDATE(),
			@CreatedByUserId,
			GETUTCDATE()
		)

	SELECT 1 AS 'result'

    SET NOCOUNT OFF
END
GO
PRINT N'Modificando [dbo].[SaveHistoricStudyData]...';


GO

ALTER PROCEDURE [dbo].[SaveHistoricStudyData] (
	@VCC VARCHAR(50) =        NULL,
	@StudyId    VARCHAR(50) = NULL,
	@TemplateId VARCHAR(50) = NULL
) AS
BEGIN
	SET NOCOUNT ON
	  
	-- INSERTAMOS LA DATA DE LA PLANTILLA
	INSERT INTO [dbo].[HistoricTemplate] 
		SELECT T.[VCC],
				T.[Name],
				T.[Type],
				T.[Description],
				T.[Template],
				T.[Category],
				@StudyId
			FROM [dbo].[Template] T (NOLOCK)
			WHERE T.[Name] = @TemplateId 
				AND T.[VCC] = @VCC

	-- INSERTAMOS LA DATA DE LOS TEMAS
	INSERT INTO [dbo].[HistoricTemplateTheme]
		SELECT TT.[VCC],
				TT.[TemplateId],
				TT.[ID],
				TT.[Order],
				TT.[Description],
				TT.[Category1],
				TT.[Category2],
				TT.[AnalysisType],
				TT.[IsNegative],
				@StudyId
			FROM [dbo].[TemplateTheme] TT (NOLOCK)
			WHERE TT.[TemplateId] = @TemplateId 
				AND TT.[VCC] = @VCC

	-- INSERTAMOS LA DATA DE LOS THEMEITEMS
	INSERT INTO [dbo].[HistoricTemplateThemeItem]
		SELECT TTI.[VCC],
				TTI.[TemplateId],
				TTI.[TemplateThemeId],
				TTI.[ID],
				TTI.[AcceptancePercentage],
				@StudyId
			FROM [dbo].[TemplateThemeItem] TTI (NOLOCK)
			WHERE TTI.[TemplateId] = @TemplateId 
				AND TTI.[VCC] = @VCC

	-- INSERTAMOS LA DATA DE THEMEITEMENTITY
	INSERT INTO [dbo].[HistoricTemplateThemeItemEntity]
		SELECT TTIE.[VCC],
				TTIE.[TemplateId],
				TTIE.[TemplateThemeId],
				TTIE.[TemplateThemeItemId],
				TTIE.[EntityId],
				TTIE.[EntityName],
				TTIE.[AcceptancePercentage],
				TTIE.[Order],
				@StudyId
			FROM [dbo].[TemplateThemeItemEntity] TTIE (NOLOCK)
			WHERE TTIE.[TemplateId] = @TemplateId 
				AND TTIE.[VCC] = @VCC

	-- INSERTAMOS LA DATA DE LOS QUERY (SE USA?)
	INSERT INTO [dbo].[HistoricGenericTemplateQuery]
		SELECT GTQ.[VCC],
				GTQ.[TemplateId],
				GTQ.[ID],
				GTQ.[Query],
				@StudyId
			FROM [dbo].[GenericTemplateQuery] GTQ (NOLOCK)
            WHERE GTQ.[TemplateId] = @TemplateId 
				AND GTQ.[VCC] = @VCC

	SET NOCOUNT OFF
END
GO
PRINT N'Creando [dbo].[GetBatchScheduledTemplateResults]...';


GO
CREATE PROCEDURE [dbo].[GetBatchScheduledTemplateResults]
(
	@VCC					VARCHAR(50) = NULL,
	@BatchScheduledIds		VARCHAR(MAX) = NULL,
	@StartDate				DATETIME = NULL, -- FILTRO PARA LOS RESULATDOS RECIENTES
	@EndDate				DATETIME = NULL -- FILTRO PARA LOS RESULATDOS RECIENTES
)
AS
BEGIN
	SET NOCOUNT ON

	--DECLARE @VCC VARCHAR(50) = NULL, @BatchScheduleId VARCHAR(50) = NULL
	--SET @VCC = 'vccocc'
	--SET @BatchScheduleId = '20211230_niveles'

	-- OBTENEMOS LOS RESULTADOS RELACIONADOS CON LA AGENDA
	SELECT SRD.[VCC]								'vcc',
			S.[BatchScheduleId]						'batchScheduleId',
			SRD.[StudyId]							'studyId',
			HTT.[TemplateId]						'templateId',
			SRD.[TemplateThemeId]					'templateThemeId',
			HTT.[Category1]							'category1',
			HTT.[Category2]							'category2',
			HTT.[Description]						'description',
			SRD.[TemplateThemeItemId]				'templateThemeItemId',
			SRD.[TranscriptionId]					'transcriptionId',
			COUNT(*)								'ocurrencies',
			COUNT(
				CASE WHEN SRD.[CreatedDate] >= @StartDate THEN 1 ELSE NULL END
			)										'latestOcurrencies'
		FROM [dbo].[StudyResultSummaryDetail] SRD (NOLOCK)
		INNER JOIN [dbo].[Study] S (nolock)
			ON S.[VCC] = SRD.[VCC]
				AND S.[Name] = SRD.[StudyId]
		INNER JOIN [dbo].[HistoricTemplateTheme] HTT (NOLOCK)
			ON HTT.[VCC] = SRD.[VCC]
				AND HTT.[StudyId] = SRD.[StudyId]
				AND HTT.[ID] = SRD.[TemplateThemeId]
		WHERE S.[VCC] = @VCC
			AND SRD.[CreatedDate] BETWEEN @StartDate AND @EndDate
			AND (
				(
					@BatchScheduledIds <> ''
					AND
					S.[BatchScheduleId] IN (SELECT VALUE FROM [dbo].[split](@BatchScheduledIds, ','))
				)
				OR 
				(
					@BatchScheduledIds = ''
					AND 
					S.[BatchScheduleId] IS NOT NULL
				)
			)
		GROUP BY SRD.[VCC],
					S.[BatchScheduleId],
					SRD.[StudyId],
					HTT.[TemplateId],
					SRD.[TemplateThemeId],
					HTT.[Category1],
					HTT.[Category2],
					HTT.[Description],
					SRD.[TemplateThemeItemId],
					SRD.[TranscriptionId]
	
	/*
	-- OBTENEMOS LOS RESULTADOS RECIENTES
	SELECT SRD.[VCC]								'vcc',
			S.[BatchScheduleId]						'batchScheduleId',
			SRD.[StudyId]							'studyId',
			HTT.[TemplateId]						'templateId',
			SRD.[TemplateThemeId]					'templateThemeId',
			HTT.[Category1]							'category1',
			HTT.[Category2]							'category2',
			HTT.[Description]						'description',
			SRD.[TemplateThemeItemId]				'templateThemeItemId',
			SRD.[TranscriptionId]					'transcriptionId',
			SRD.[CreatedDate]						'createdDate'
		FROM [dbo].[StudyResultSummaryDetail] SRD (NOLOCK)
		INNER JOIN [dbo].[Study] S (nolock)
			ON S.[VCC] = SRD.[VCC]
				AND S.[Name] = SRD.[StudyId]
		INNER JOIN [dbo].[HistoricTemplateTheme] HTT (NOLOCK)
			ON HTT.[VCC] = SRD.[VCC]
				AND HTT.[StudyId] = SRD.[StudyId]
				AND HTT.[ID] = SRD.[TemplateThemeId]
		WHERE S.[VCC] = @VCC
			AND (
				(
					@BatchScheduleId IS NOT NULL
					AND
					S.[BatchScheduleId] = @BatchScheduleId 
				)
				OR 
				(
					@BatchScheduleId IS NULL
					AND 
					S.[BatchScheduleId] IS NOT NULL
				)
			)
			AND SRD.[CreatedDate] >= @StartDate
	*/

	SET NOCOUNT OFF
END
GO
PRINT N'Modificando [dbo].[SaveStudy]...';


GO

ALTER PROCEDURE [dbo].[SaveStudy] (
	@VCC Varchar(50) = NULL,
	@ProcessId Varchar(50) = NULL,
	@TemplateId Varchar(50) = NULL,
	@Name Varchar(200) = NULL,
	@Description Varchar(50) = NULL,
	@Status Float = NULL,
	@Type VARCHAR(50) = NULL,
	@BatchScheduleId VARCHAR(50) = NULL,
	@CreatedDate Datetime = NULL,
	@CreatedByUserId Varchar(50) = NULL,
	@LastModifiedDate Datetime = NULL,
	@LastModifiedByUserId Varchar(50) = NULL
)
AS
BEGIN
	SET NOCOUNT ON
	
	UPDATE [Study]
		SET [Name] = @Name,
			[Description] = @Description,
			[Status] = @Status,
			[Type] = @Type,
			[CreatedDate] = CASE WHEN @CreatedDate IS NULL THEN [CreatedDate] ELSE @CreatedDate END,
			[CreatedByUserId] = CASE WHEN @CreatedByUserId IS NULL THEN [CreatedByUserId] ELSE @CreatedByUserId END,
			[LastModifiedDate] = CASE WHEN @LastModifiedDate IS NULL THEN [LastModifiedDate] ELSE @LastModifiedDate END,
			[LastModifiedByUserId] = CASE WHEN @LastModifiedByUserId IS NULL THEN [LastModifiedByUserId] ELSE @LastModifiedByUserId END,
			[TimeStamp] = GETUTCDATE()
		WHERE [VCC] = @VCC
			AND [ProcessId] = @ProcessId
			AND [TemplateId] =@TemplateId
			AND [Name] = @Name

    IF @@ROWCOUNT = 0
	BEGIN
		INSERT INTO [Study] (
			[VCC], [ProcessId], [TemplateId], 
			[Name], [Description], [Status],
			[Type],	[BatchScheduleId], [CreatedDate], [CreatedByUserId], 
			[LastModifiedDate], [LastModifiedByUserId], [TimeStamp]
			)
		VALUES (
			@VCC, @ProcessId, @TemplateId,
			@Name, @Description, @Status,
			@Type, @BatchScheduleId, @CreatedDate, @CreatedByUserId, 
			@LastModifiedDate, @LastModifiedByUserId, GETUTCDATE()
		)
		EXEC [dbo].[SaveHistoricStudyData] @VCC,@Name,@TemplateId
	END
    SELECT 1 AS 'result'
    
    SET NOCOUNT OFF
END
GO
PRINT N'Actualizando [dbo].[DeleteStudy]...';


GO
EXECUTE sp_refreshsqlmodule N'[dbo].[DeleteStudy]';


GO
PRINT N'Actualizando [dbo].[GetCleanerData]...';


GO
EXECUTE sp_refreshsqlmodule N'[dbo].[GetCleanerData]';


GO
PRINT N'Actualizando [dbo].[GetExecuteTemplateProcess]...';


GO
EXECUTE sp_refreshsqlmodule N'[dbo].[GetExecuteTemplateProcess]';


GO
PRINT N'Actualizando [dbo].[GetInteractionsCognitive]...';


GO
EXECUTE sp_refreshsqlmodule N'[dbo].[GetInteractionsCognitive]';


GO
PRINT N'Actualizando [dbo].[GetProcessUsage]...';


GO
EXECUTE sp_refreshsqlmodule N'[dbo].[GetProcessUsage]';


GO
PRINT N'Actualizando [dbo].[GetStudiesInProcess]...';


GO
EXECUTE sp_refreshsqlmodule N'[dbo].[GetStudiesInProcess]';


GO
PRINT N'Actualizando [dbo].[GetStudyCognitiveInteractionsTask]...';


GO
EXECUTE sp_refreshsqlmodule N'[dbo].[GetStudyCognitiveInteractionsTask]';


GO
PRINT N'Actualizando [dbo].[GetStudyGenericQueryTask]...';


GO
EXECUTE sp_refreshsqlmodule N'[dbo].[GetStudyGenericQueryTask]';


GO
PRINT N'Actualizando [dbo].[GetStudyQuery]...';


GO
EXECUTE sp_refreshsqlmodule N'[dbo].[GetStudyQuery]';


GO
PRINT N'Actualizando [dbo].[GetStudyResultSummary]...';


GO
EXECUTE sp_refreshsqlmodule N'[dbo].[GetStudyResultSummary]';


GO
PRINT N'Actualizando [dbo].[SaveBatchError]...';


GO
EXECUTE sp_refreshsqlmodule N'[dbo].[SaveBatchError]';


GO
PRINT N'Actualizando [dbo].[SaveBatchStatus]...';


GO
EXECUTE sp_refreshsqlmodule N'[dbo].[SaveBatchStatus]';


GO
PRINT N'Actualizando [dbo].[SaveSQLStudyDetail]...';


GO
EXECUTE sp_refreshsqlmodule N'[dbo].[SaveSQLStudyDetail]';


GO
PRINT N'Actualizando [dbo].[SaveStudyBaseResult]...';


GO
EXECUTE sp_refreshsqlmodule N'[dbo].[SaveStudyBaseResult]';


GO
PRINT N'Actualizando [dbo].[BulkInteractionCognitive]...';


GO
EXECUTE sp_refreshsqlmodule N'[dbo].[BulkInteractionCognitive]';


GO
PRINT N'Actualización completada.';


GO
