PRINT N'Altering SqlTable [dbo].[NLU]...';


GO
ALTER TABLE [dbo].[NLU]
    ADD [NeedPublish] BIT NULL;


GO
PRINT N'Altering SqlProcedure [dbo].[SaveNLU]...';


GO
ALTER PROCEDURE [dbo].[SaveNLU] (
    @VCC Varchar(50) = NULL,
    @Name Varchar(50) = NULL,
    @Culture Varchar(50) = NULL,
    @Description Varchar(50) = NULL,
    @AppId Varchar(100) = NULL,
    @SubscriptionKey Varchar(50) = NULL,
    @IsSystemApp BIT = 0,
    @IsPublished BIT = NULL,
    @LastPublishedDate DATETIME = NULL,
    @IsTrained BIT = NULL,
    @NeedTrain BIT = NULL,
    @NeedPublish BIT = NULL,
    @LastTrainedDate DATETIME = NULL,
    @CreatedDate Datetime = NULL,
    @CreatedByUserId Varchar(50) = NULL,
    @LastModifiedDate Datetime = NULL,
    @LastModifiedByUserId Varchar(50) = NULL
)
AS
BEGIN
    SET NOCOUNT ON

    -- SI LA VARIABLE LLEGA NULL, LA SETTEAMOS COMO 0
    IF @IsSystemApp IS NULL
        SET @IsSystemApp = 0

    UPDATE [NLU]
    SET [Culture] = @Culture,
        [Description] = @Description,
        [AppId] = @AppId,
        [IsPublished] = CASE WHEN @IsPublished IS NULL THEN [IsPublished] ELSE @IsPublished END,
        [LastPublishedDate] = CASE WHEN @LastPublishedDate IS NULL THEN [LastPublishedDate] ELSE @LastPublishedDate END,
        [IsSystemApp] = CASE WHEN @IsSystemApp IS NULL THEN [IsSystemApp] ELSE @IsSystemApp END,
        [SubscriptionKey] = CASE WHEN @SubscriptionKey IS NULL THEN [SubscriptionKey] ELSE @SubscriptionKey END,
        [IsTrained] = CASE WHEN @IsTrained IS NULL THEN [IsTrained] ELSE @IsTrained END,
        [NeedTrain] = CASE WHEN @NeedTrain IS NULL THEN [NeedTrain] ELSE @NeedTrain END,
        [NeedPublish] = CASE WHEN @NeedPublish IS NULL THEN [NeedPublish] ELSE @NeedPublish END,
        [LastTrainedDate] = CASE WHEN @LastTrainedDate IS NULL THEN [LastTrainedDate] ELSE @LastTrainedDate END,
        -- [CreatedByUserId] = CASE WHEN @CreatedByUserId IS NULL THEN [CreatedByUserId] ELSE @CreatedByUserId END,
        [LastModifiedDate] = CASE WHEN @LastModifiedDate IS NULL THEN [LastModifiedDate] ELSE @LastModifiedDate END,
        [LastModifiedByUserId] = CASE WHEN @LastModifiedByUserId IS NULL THEN [LastModifiedByUserId] ELSE @LastModifiedByUserId END,
        [TimeStamp] = GETUTCDATE()
    WHERE [VCC] = @VCC
      AND [Name] = @Name

    IF @@ROWCOUNT = 0
        BEGIN
            INSERT INTO [NLU] (
                [VCC], [Name], [Culture],
                [Description], [AppId], [SubscriptionKey],
                [IsSystemApp], [CreatedDate], [CreatedByUserId],
                [LastModifiedDate], [LastModifiedByUserId], [TimeStamp],[CognitiveEngine]
            )
            VALUES (
                       @VCC, @Name, @Culture,
                       @Description, @AppId, @SubscriptionKey,
                       @IsSystemApp, GETUTCDATE(), @CreatedByUserId,
                       @LastModifiedDate, @LastModifiedByUserId, GETUTCDATE(),
                       IIF(@IsSystemApp = 1, 'RASA', (SELECT [CognitiveEngine] FROM [dbo].[VCC] WHERE [VCC] = @VCC))
                   )
        END
    SELECT 1 AS 'result'

    SET NOCOUNT OFF
END
GO
PRINT N'Altering SqlProcedure [dbo].[GetIntents]...';


GO
ALTER PROCEDURE [dbo].[GetIntents] (
    @VCC Varchar(50) = NULL,
    @AppId VARCHAR(100) = NULL,
    @SearchCriteria Varchar(50) = NULL,
    @SearchExpression Varchar(50) = NULL,
    @Intents NVARCHAR(MAX)
)
AS
BEGIN

    DECLARE @COGNITIVE_ENGINE VARCHAR(5) = NULL
    DECLARE @SQL NVARCHAR(MAX)

    -- DETERMINAMOS EL MOTOR COGNITIVO DEL VCC
    SELECT @COGNITIVE_ENGINE = N.[CognitiveEngine]
    FROM [dbo].[NLU] N (NOLOCK)
    WHERE N.[VCC] = @VCC
      AND N.[AppId] = @AppId

    SET @SQL = '
	SET NOCOUNT ON
	SELECT [Name]						    ''name'',
	        [AppId]                         ''appId'',
			[IntentId]						''intentId'',
			[Color]							''color'',
			[CreatedDate]					''createdDate'',
			[CreatedByUserId]				''createdByUserId'',
			[LastModifiedDate]				''lastModifiedDate'',
			[LastModifiedByUserId]			''lastModifiedByUserId'',
			[Status]                        ''status'',
			[StatusCode]                    ''statusCode'',
	        IIF(EXISTS(SELECT 1 FROM [dbo].[Utterance] WHERE [VCC] = [dbo].[Intent].[VCC] and [AppId] = [dbo].[Intent].[AppId] and [IntentId] = [dbo].[Intent].[IntentId]), 1, 0) ''hasUtterances''
		FROM [dbo].[Intent] (NOLOCK)
		WHERE [VCC] = ''' + @VCC + '''
			AND [AppId] = ''' + @AppId + ''' '

    -- PARA NLUS DE LUIS, FILTRAMOS SEGUN EL INPUT
    IF @COGNITIVE_ENGINE = 'LUIS'
        BEGIN
            SET @SQL +=	'
			AND [IntentId] IN (''' + @Intents + ''') '
        END

    IF @SearchCriteria IS NOT NULL AND @SearchExpression IS NOT NULL
        BEGIN
            SET @SQL +=	'
			AND ISNULL([Name], '''') LIKE CASE WHEN ''' + @SearchCriteria + ''' = ''name'' THEN ''%' + @SearchExpression + '%'' ELSE ''%'' END '
        END

    SET @SQL +=	'
		ORDER BY [LastModifiedDate] ASC, [Name] DESC '

    SET @SQL += '
	SET NOCOUNT OFF'

    EXEC(@SQL)
END
GO
PRINT N'Altering SqlProcedure [dbo].[DeleteEntity]...';


GO
ALTER PROCEDURE [dbo].[DeleteEntity] (
    @VCC VARCHAR(50) = NULL,
    @AppId VARCHAR(100) = NULL,
    @ID VARCHAR(50) = NULL
)
AS
BEGIN
    SET NOCOUNT ON

    -- ELIMINAMOS EL ENTITY DE LA TABLA
    DELETE FROM [dbo].[Entity]
    WHERE [VCC] = @VCC
      AND [AppId] = @AppId
      AND [ID] = @ID

    --Marco el NLU como pendiente de entrenamiento
    UPDATE
        [dbo].[NLU]
    SET
        [NeedTrain] = 1
    WHERE
            [VCC] = @VCC AND [AppId] = @AppId

    SELECT 1 AS 'result'

    SET NOCOUNT OFF
END
GO
PRINT N'Altering SqlProcedure [dbo].[DeleteIntent]...';


GO
ALTER PROCEDURE [dbo].[DeleteIntent] (
    @VCC Varchar(50) = NULL,
    @AppId VARCHAR(100) = NULL,
    @IntentId Varchar(50) = NULL
)
AS
BEGIN
    SET NOCOUNT ON

    -- ELIMINAMOS EL INTENT DE LA TABLA INTENT
    DELETE FROM [Intent]
    WHERE [VCC] = @VCC
      AND [AppId] = @AppId
      AND [IntentId] = @IntentId

    -- ELIMINAMOS LOS UTTERANCES REGISTRADOS CON EL APPID E INTENTID
    DELETE FROM [Utterance]
    WHERE [VCC] = @VCC
      AND [AppId] = @AppId
      AND [IntentId] = @IntentId
    --ELIMINAR UNDERLINED
    DELETE UL FROM [dbo].[Intent] I
                       JOIN [dbo].[Utterance] U
                            ON I.[VCC] = U.[VCC]
                                AND I.[AppId] = U.[AppId]
                       JOIN [dbo].[Underlined] UL
                            ON UL.[VCC] = U.[VCC]
                                AND UL.[UtteranceId]= U.[Id]
    WHERE I.[IntentId] = @IntentId AND I.[AppId] = @AppId AND I.[VCC] = @VCC
    --ELIMINAR UtteranceEntity
    DELETE UE
    FROM [dbo].[Intent] I
             JOIN [dbo].[Entity] E
                  ON I.[VCC] = E.[VCC]
                      AND I.[AppId] = E.[AppId]
             JOIN [dbo].[Utterance] U
                  ON I.[VCC] = U.[VCC]
                      AND I.[AppId] = U.[AppId]
             JOIN [dbo].[UtteranceEntity] UE
                  ON UE.[VCC] = U.[VCC]
                      AND UE.[UtteranceId]= U.[Id]
                      AND UE.[EntityName] = E.[Name]
    WHERE I.[IntentId] = @IntentId AND I.[AppId] = @AppId AND I.[VCC] = @VCC

    --Marco el NLU como pendiente de entrenamiento
    UPDATE
        [dbo].[NLU]
    SET
        [NeedTrain] = 1
    WHERE
            [VCC] = @VCC AND [AppId] = @AppId

    SELECT 1 AS 'result'

    SET NOCOUNT OFF
END
GO
PRINT N'Altering SqlProcedure [dbo].[GetNLUs]...';


GO
ALTER PROCEDURE [dbo].[GetNLUs] (
    @VCC Varchar(50) = NULL,
    @SearchCriteria Varchar(50) = NULL,
    @SearchExpression Varchar(50) = NULL,
    @Apps NVARCHAR(MAX),
    @IsSystemApp BIT = NULL,
    @ShowInMigrationProcess BIT = 0
)
AS
BEGIN
    -- EN CASO EL FLAG LLEGUE NULL LO SETTEAMOS COMO 0

    DECLARE  @SQL              NVARCHAR(MAX)
    DECLARE  @FILTER           VARCHAR(MAX) = ''
    DECLARE  @UNION_SQL        VARCHAR(MAX) = ''
    DECLARE  @APPS_FILTER      VARCHAR(MAX) = ''
    DECLARE  @STATUS_FILTER    VARCHAR(MAX) = ''
    DECLARE  @ORDER_BY         VARCHAR(MAX) = ''
    SET NOCOUNT ON
    --Status va ha cambiar a 9 o 10 de acuerdo a LastPublishedDate
    --0 PENDIENTE DE MIGRACION
    --1 ESTA DISPONIBLE EN EL MOTOR
    --2 MIGRANDO
    --3 CON ERROR ( EL ERROR LO INDICA STATUSCODE)
    --4 CANCELADO POR DEMASIADOS INTENTOS ERRONEOS
    --8 MIGRADO EL NLU PERO FALTA LOS INTENT, UTTERANCES,ETC
    --9 ESTA DISPONILBE EL MODELO EN EL MOTOR PERO NO ESTA ENTRENADO(RASA) O LUIS(PUBLICADO)
    --10 ESTA DISPONIBLE EN EL MOTOR Y ENTRENADO
    --11 EN PROCESO DE ENTRENAMIENTO (PROCESO INTERNO DE LUIS)
    --12 EN PROCESO DE PUBLICACION (PROCESO INTERNO DE LUIS)
    --13 ENTRENAMIENTO FALLIDO (LUIS RETORNO ESTADO DE ERROR LUEGO DE VARIAS CONSULTAS)
    --Se establece estos valores porque actualmente Status puede tener valores de 0 a 4, sin embargo puede ampliarse en futuros requerimientos.
    SET @SQL = '
    SELECT [VCC]                  ''vcc'',
       [Name]                 ''name'',
       [CognitiveEngine]      ''cognitiveEngine'',
       [Culture]              ''culture'',
       [Description]          ''description'',
       [AppId]                ''appId'',
       [SubscriptionKey]      ''subscriptionKey'',
       [IsSystemApp]          ''isSystemApp'',
       [NeedTrain]            ''needTrain'',
       [IsTrained]            ''isTrained'',
       [LastTrainedDate]      ''lastTrainedDateTime'',
       [IsPublished]          ''isPublished'',
       [LastPublishedDate]    ''lastPublishedDateTime'',
       [CreatedDate]          ''createdDate'',
       [CreatedByUserId]      ''createdByUserId'',
       [LastModifiedDate]     ''lastModifiedDate'',
       [LastModifiedByUserId] ''lastModifiedByUserId'',
       CASE
           WHEN [Status] = 0 THEN
               ''PENDING''
           WHEN [Status] = 1 THEN
               CASE
                   WHEN [NeedTrain] = 1 OR [LastTrainedDate] IS NULL THEN
                       ''NEED_TRAIN''
                   WHEN [NeedTrain] = 0 AND ([NeedPublish] = 1 OR [LastPublishedDate] IS NULL) THEN
                       IIF([CognitiveEngine] = ''LUIS'', ''NEED_PUBLISH'', ''NEED_TRAIN'')
                   ELSE
                       ''AVAILABLE''
                END
           WHEN [Status] = 2 THEN
                ''MIGRATING''
           WHEN [Status] = 3 THEN
               ''FAILED''
           WHEN [Status] = 4 THEN
               ''CANCELLED''
           WHEN [Status] = 8 THEN
               ''INCOMPLETE''
           WHEN [Status] = 9 THEN
                IIF([CognitiveEngine] = ''LUIS'', ''NEED_PUBLISH'', ''NEED_TRAIN'')
           WHEN [Status] = 10 THEN
                ''AVAILABLE''
           WHEN [Status] = 11 THEN
               ''TRAINING''
           WHEN [Status] = 12 THEN
               ''PUBLISHING''
           WHEN [Status] = 13 THEN
               ''TRAINING_FAILED''
           ELSE
                ''UNKNOWN''
        END ''statusCode''
    FROM [NLU] (NOLOCK)
    WHERE '

    -- EN CASO BUSQUEMOS MODELOS DE TODOS LOS VCC
    IF (@VCC = 'ALL')
        SET @SQL += '
            [VCC] IS NOT NULL '
    ELSE
        SET @SQL += '
        [VCC] = ''' + @VCC + ''' '


    -- EN CASO BUSQUEMOS MODELOS DEL SISTEMA NO FILTRAMOS POR NOMBRES
    IF @IsSystemApp = 0 AND @Apps IS NOT NULL AND @Apps <> ''
        SET @APPS_FILTER  += ' AND [AppId] IN (''' + @Apps + ''') '



    SET @FILTER += ' AND [IsSystemApp] = ' + CASE WHEN @IsSystemApp = 1 THEN '1' ELSE '0' END + ' '

    IF(@SearchCriteria IS NOT NULL AND @SearchCriteria <> '' AND @SearchExpression IS NOT NULL AND @SearchExpression <> '')
        BEGIN
            SET @FILTER += '
        AND ISNULL([Name], '''') LIKE CASE WHEN ''' + @SearchCriteria + ''' = ''name'' THEN ''%' + @SearchExpression + '%'' ELSE ''%'' END
        AND ISNULL([Description], '''') LIKE CASE WHEN ''' + @SearchCriteria + ''' = ''description'' THEN ''%' + @SearchExpression + '%'' ELSE ''%'' END
        AND ISNULL([LastModifiedByUserId], '''') LIKE CASE WHEN ''' + @SearchCriteria + ''' = ''LastModifiedByUserId'' THEN ''%' + @SearchExpression + '%'' ELSE ''%'' END'
        END


    SET @ORDER_BY = ' ORDER BY [LastModifiedDate] ASC, [Name] DESC'
    SET @STATUS_FILTER = ' AND [Status] = 1 '

    IF(@ShowInMigrationProcess IS NOT NULL AND @ShowInMigrationProcess = 1)
        BEGIN
            SET @UNION_SQL = ' UNION ' + @SQL + @FILTER + ' AND [Status] <> 1 '
        END


    SET @SQL += @FILTER + @APPS_FILTER + @STATUS_FILTER + @UNION_SQL +  @ORDER_BY
    SET NOCOUNT OFF

    EXEC(@SQL)
END
GO
PRINT N'Altering SqlProcedure [dbo].[SaveEntity]...';


GO
ALTER PROCEDURE [dbo].[SaveEntity] (
    @VCC					VARCHAR(50) = NULL,
    @AppId					VARCHAR(50) = NULL,
    @ID						VARCHAR(50) = NULL,
    @Name					VARCHAR(50) = NULL,
    @Type					VARCHAR(50) = NULL,
    @CreatedByUserId		VARCHAR(50) = NULL,
    @LastModifiedByUserId	VARCHAR(50) = NULL
) AS
BEGIN
    SET NOCOUNT ON

    UPDATE [Entity]
    SET [Name] = @Name,
        [Type] = @Type,
        [LastModifiedByUserId] = CASE WHEN @LastModifiedByUserId IS NULL THEN [LastModifiedByUserId] ELSE @LastModifiedByUserId END,
        [LastModifiedDate] = GETUTCDATE(),
        [TimeStamp] = GETUTCDATE()
    WHERE [VCC] = @VCC
      AND [AppId] = @AppId
      AND [ID] = @ID
      AND [Name] = @Name

    IF @@ROWCOUNT = 0
        BEGIN
            INSERT INTO [Entity] (
                [VCC], [AppId], [ID], [Name], [Type],
                [CreatedDate], [CreatedByUserId], [LastModifiedDate], [LastModifiedByUserId], [TimeStamp],[Status],
                [StatusCode]
            )
            VALUES (
                       @VCC, @AppId, @ID, @Name, @Type,
                       GETUTCDATE(), @CreatedByUserId, GETUTCDATE(), @LastModifiedByUserId, GETUTCDATE(),1,'AVAILABLE'
                   )
        END

    --Marco el NLU como pendiente de entrenamiento
    UPDATE
        [dbo].[NLU]
    SET
        [NeedTrain] = 1
    WHERE
            [VCC] = @VCC AND [AppId] = @AppId

    SELECT 1 AS 'result'

    SET NOCOUNT OFF
END
GO
PRINT N'Altering SqlProcedure [dbo].[SaveIntent]...';


GO
ALTER PROCEDURE [dbo].[SaveIntent] (
    @VCC					VARCHAR(50) = NULL,
    @Name					VARCHAR(50) = NULL,
    @IntentId				VARCHAR(50) = NULL,
    @AppId					VARCHAR(50) = NULL,
    @Color					VARCHAR(50) = NULL,
    @CreatedDate			DATETIME = NULL,
    @CreatedByUserId		VARCHAR(50) = NULL,
    @LastModifiedDate		DATETIME = NULL,
    @LastModifiedByUserId	VARCHAR(50) = NULL
)
AS
BEGIN
    SET NOCOUNT ON

    UPDATE [Intent]
    SET [Name] = @Name,
        [CreatedDate] = CASE WHEN @CreatedDate IS NULL THEN [CreatedDate] ELSE @CreatedDate END,
        [CreatedByUserId] = CASE WHEN @CreatedByUserId IS NULL THEN [CreatedByUserId] ELSE @CreatedByUserId END,
        [LastModifiedDate] = CASE WHEN @LastModifiedDate IS NULL THEN [LastModifiedDate] ELSE @LastModifiedDate END,
        [LastModifiedByUserId] = CASE WHEN @LastModifiedByUserId IS NULL THEN [LastModifiedByUserId] ELSE @LastModifiedByUserId END,
        [TimeStamp] = GETUTCDATE()
    WHERE [VCC] = @VCC
      AND [Name] = @Name
      AND [AppId] = @AppId

    IF @@ROWCOUNT = 0
        BEGIN
            INSERT INTO [Intent] (
                [VCC], [Name], [IntentId], [AppId],
                [Color], [CreatedDate], [CreatedByUserId],
                [LastModifiedDate], [LastModifiedByUserId], [TimeStamp],[Status],[StatusCode]
            )
            VALUES (
                       @VCC, @Name, @IntentId, @AppId,
                       @Color, @CreatedDate, @CreatedByUserId,
                       @LastModifiedDate, @LastModifiedByUserId, GETUTCDATE(),1,'AVAILABLE'
                   )
        END

    --Marco el NLU como pendiente de entrenamiento
    UPDATE
        [dbo].[NLU]
    SET
        [NeedTrain] = 1
    WHERE
            [VCC] = @VCC AND [AppId] = @AppId

    SELECT 1 AS 'result'

    SET NOCOUNT OFF
END
GO
PRINT N'Creating SqlProcedure [dbo].[UpdateNLUStatus]...';


GO
CREATE PROCEDURE [dbo].[UpdateNLUStatus]
(
    @VCC					VARCHAR(50) = NULL,
    @AppId					VARCHAR(50) = NULL,
    @NewStatus              INT = NULL
)
AS
BEGIN
    SET NOCOUNT ON

    UPDATE [dbo].[NLU] SET [Status] = @NewStatus WHERE [VCC] = @VCC AND [AppId] = @AppId
    SELECT 1 AS result

    SET NOCOUNT OFF
END
GO
