-- ARCHIVO CON LAS ACTUALIZACIONES DE DATA DE SQL PARA MIGRAR AL NUEVO BUILD DEL NOMBRE DE LA CARPETA
-- DECLARAMOS DOS VARIABLES, UNA CON LA VERSION DE LA QUE PARTIMOS Y OTRA CON LA NUEVA VERSION QUE ESTAMOS APUNTANDO
DECLARE @OLD_DATABASE_BUILD_VERSION VARCHAR(50) = '3.2.1'
DECLARE @NEW_DATABASE_BUILD_VERSION VARCHAR(50) = '3.3.0'

-- INICIAMOS UN TRY PARA EL CASO CAIGA EN CATCH HAGAMOS ROLLBACK
BEGIN TRY
    -- VALIDAMOS QUE LA VERSION EXISTENTE COINCIDE CON NUESTRA NEW_DATABASE_BUILD_VERSION
    IF NOT EXISTS (
        SELECT 1 
            FROM [dbo].[Version] V 
            WHERE V.[BuildVersion] = @OLD_DATABASE_BUILD_VERSION
    )	
        -- LANZAMOS UN MENSAJE DE ERROR INDICANDO QUE LA VERSION ACTUAL NO COINCIDE CON LA OLD_DATABASE_BUILD_VERSION
        RAISERROR('DATABASE_ERROR_INCORRECT_TARGET_VERSION', 16, 16)
        
    -- INICIAMOS LA TRANSACCION
    BEGIN TRANSACTION




    -- AQUI EMPIEZA LA SECCION CON LOS INSERT/UPDATE/DELETE PARA LA NUEVA VERSION
    -- REGISTRAR NLU DE SISTEMA
     -- MODELOS POR DEFECTO PARA ANALISIS DE SENTIMENTOS
        INSERT [dbo].[NLU] ([VCC], [Name], [Culture], [Description], [AppId], [IsSystemApp], [CreatedDate], [CreatedByUserId], [TimeStamp]) VALUES ('system', N'sentiment-es', N'es', N'SENTIMENT_LANGUAGE_ES', 'system' + N'::sentiment-es', 1, GETUTCDATE(), N'system', GETUTCDATE())
        INSERT [dbo].[NLU] ([VCC], [Name], [Culture], [Description], [AppId], [IsSystemApp], [CreatedDate], [CreatedByUserId], [TimeStamp]) VALUES ('system', N'sentiment-en', N'en', N'SENTIMENT_LANGUAGE_EN', 'system' + N'::sentiment-en', 1, GETUTCDATE(), N'system', GETUTCDATE())
        INSERT [dbo].[NLU] ([VCC], [Name], [Culture], [Description], [AppId], [IsSystemApp], [CreatedDate], [CreatedByUserId], [TimeStamp]) VALUES ('system', N'sentiment-pt', N'pt', N'SENTIMENT_LANGUAGE_PT', 'system' + N'::sentiment-pt', 1, GETUTCDATE(), N'system', GETUTCDATE())
        INSERT [dbo].[NLU] ([VCC], [Name], [Culture], [Description], [AppId], [IsSystemApp], [CreatedDate], [CreatedByUserId], [TimeStamp]) VALUES ('system', N'sentiment-fr', N'fr', N'SENTIMENT_LANGUAGE_FR', 'system' + N'::sentiment-fr', 1, GETUTCDATE(), N'system', GETUTCDATE())

	-- REGISTRAMOS UTTERANCES POR DEFECTO
	--UTTERANCES DE SENTIMIENTO EN CASTELLANO 
	INSERT [dbo].[Utterance] ([VCC], [AppId], [IntentId], [Id], [Text], [CreatedDate], [CreatedByUserId], [LastModifiedDate],[LastModifiedByUserId], [Status],[StatusCode]) VALUES (N'system',N'system::sentiment-es',N'Positive', NEWID(),N'Me alegra', GETUTCDATE() ,'system', NULL, NULL, 1, 'AVAILABLE')
	INSERT [dbo].[Utterance] ([VCC], [AppId], [IntentId], [Id], [Text], [CreatedDate], [CreatedByUserId], [LastModifiedDate],[LastModifiedByUserId], [Status],[StatusCode]) VALUES (N'system',N'system::sentiment-es',N'Positive', NEWID(),N'Comprendo', GETUTCDATE() ,'system', NULL, NULL, 1, 'AVAILABLE')
	INSERT [dbo].[Utterance] ([VCC], [AppId], [IntentId], [Id], [Text], [CreatedDate], [CreatedByUserId], [LastModifiedDate],[LastModifiedByUserId], [Status],[StatusCode]) VALUES (N'system',N'system::sentiment-es',N'Positive', NEWID(),N'Muy amable', GETUTCDATE() ,'system', NULL, NULL, 1, 'AVAILABLE')
	INSERT [dbo].[Utterance] ([VCC], [AppId], [IntentId], [Id], [Text], [CreatedDate], [CreatedByUserId], [LastModifiedDate],[LastModifiedByUserId], [Status],[StatusCode]) VALUES (N'system',N'system::sentiment-es',N'Positive', NEWID(),N'Muchísimas gracias', GETUTCDATE() ,'system', NULL, NULL, 1, 'AVAILABLE')
	INSERT [dbo].[Utterance] ([VCC], [AppId], [IntentId], [Id], [Text], [CreatedDate], [CreatedByUserId], [LastModifiedDate],[LastModifiedByUserId], [Status],[StatusCode]) VALUES (N'system',N'system::sentiment-es',N'Positive', NEWID(),N'Por supuesto que sí', GETUTCDATE() ,'system', NULL, NULL, 1, 'AVAILABLE')
	INSERT [dbo].[Utterance] ([VCC], [AppId], [IntentId], [Id], [Text], [CreatedDate], [CreatedByUserId], [LastModifiedDate],[LastModifiedByUserId], [Status],[StatusCode]) VALUES (N'system',N'system::sentiment-es',N'Positive', NEWID(),N'Claro que sí', GETUTCDATE() ,'system', NULL, NULL, 1, 'AVAILABLE')
	INSERT [dbo].[Utterance] ([VCC], [AppId], [IntentId], [Id], [Text], [CreatedDate], [CreatedByUserId], [LastModifiedDate],[LastModifiedByUserId], [Status],[StatusCode]) VALUES (N'system',N'system::sentiment-es',N'Positive', NEWID(),N'Qué felicidad', GETUTCDATE() ,'system', NULL, NULL, 1, 'AVAILABLE')
	INSERT [dbo].[Utterance] ([VCC], [AppId], [IntentId], [Id], [Text], [CreatedDate], [CreatedByUserId], [LastModifiedDate],[LastModifiedByUserId], [Status],[StatusCode]) VALUES (N'system',N'system::sentiment-es',N'Positive', NEWID(),N'Entiendo', GETUTCDATE() ,'system', NULL, NULL, 1, 'AVAILABLE')
	INSERT [dbo].[Utterance] ([VCC], [AppId], [IntentId], [Id], [Text], [CreatedDate], [CreatedByUserId], [LastModifiedDate],[LastModifiedByUserId], [Status],[StatusCode]) VALUES (N'system',N'system::sentiment-es',N'Positive', NEWID(),N'Vamos a solucionar', GETUTCDATE() ,'system', NULL, NULL, 1, 'AVAILABLE')
	INSERT [dbo].[Utterance] ([VCC], [AppId], [IntentId], [Id], [Text], [CreatedDate], [CreatedByUserId], [LastModifiedDate],[LastModifiedByUserId], [Status],[StatusCode]) VALUES (N'system',N'system::sentiment-es',N'Positive', NEWID(),N'Cuente conmigo', GETUTCDATE() ,'system', NULL, NULL, 1, 'AVAILABLE')
	INSERT [dbo].[Utterance] ([VCC], [AppId], [IntentId], [Id], [Text], [CreatedDate], [CreatedByUserId], [LastModifiedDate],[LastModifiedByUserId], [Status],[StatusCode]) VALUES (N'system',N'system::sentiment-es',N'Positive', NEWID(),N'Por favor', GETUTCDATE() ,'system', NULL, NULL, 1, 'AVAILABLE')
	INSERT [dbo].[Utterance] ([VCC], [AppId], [IntentId], [Id], [Text], [CreatedDate], [CreatedByUserId], [LastModifiedDate],[LastModifiedByUserId], [Status],[StatusCode]) VALUES (N'system',N'system::sentiment-es',N'Positive', NEWID(),N'Te escucho', GETUTCDATE() ,'system', NULL, NULL, 1, 'AVAILABLE')
	INSERT [dbo].[Utterance] ([VCC], [AppId], [IntentId], [Id], [Text], [CreatedDate], [CreatedByUserId], [LastModifiedDate],[LastModifiedByUserId], [Status],[StatusCode]) VALUES (N'system',N'system::sentiment-es',N'Positive', NEWID(),N'Seguro le puedo ayudar', GETUTCDATE() ,'system', NULL, NULL, 1, 'AVAILABLE')
	INSERT [dbo].[Utterance] ([VCC], [AppId], [IntentId], [Id], [Text], [CreatedDate], [CreatedByUserId], [LastModifiedDate],[LastModifiedByUserId], [Status],[StatusCode]) VALUES (N'system',N'system::sentiment-es',N'Positive', NEWID(),N'Es fácil de solucionar', GETUTCDATE() ,'system', NULL, NULL, 1, 'AVAILABLE')
	INSERT [dbo].[Utterance] ([VCC], [AppId], [IntentId], [Id], [Text], [CreatedDate], [CreatedByUserId], [LastModifiedDate],[LastModifiedByUserId], [Status],[StatusCode]) VALUES (N'system',N'system::sentiment-es',N'Positive', NEWID(),N'Genial', GETUTCDATE() ,'system', NULL, NULL, 1, 'AVAILABLE')
	INSERT [dbo].[Utterance] ([VCC], [AppId], [IntentId], [Id], [Text], [CreatedDate], [CreatedByUserId], [LastModifiedDate],[LastModifiedByUserId], [Status],[StatusCode]) VALUES (N'system',N'system::sentiment-es',N'Positive', NEWID(),N'Cuídese mucho', GETUTCDATE() ,'system', NULL, NULL, 1, 'AVAILABLE')
	INSERT [dbo].[Utterance] ([VCC], [AppId], [IntentId], [Id], [Text], [CreatedDate], [CreatedByUserId], [LastModifiedDate],[LastModifiedByUserId], [Status],[StatusCode]) VALUES (N'system',N'system::sentiment-es',N'Positive', NEWID(),N'No se preocupe', GETUTCDATE() ,'system', NULL, NULL, 1, 'AVAILABLE')
	INSERT [dbo].[Utterance] ([VCC], [AppId], [IntentId], [Id], [Text], [CreatedDate], [CreatedByUserId], [LastModifiedDate],[LastModifiedByUserId], [Status],[StatusCode]) VALUES (N'system',N'system::sentiment-es',N'Positive', NEWID(),N'Buena pregunta', GETUTCDATE() ,'system', NULL, NULL, 1, 'AVAILABLE')
	INSERT [dbo].[Utterance] ([VCC], [AppId], [IntentId], [Id], [Text], [CreatedDate], [CreatedByUserId], [LastModifiedDate],[LastModifiedByUserId], [Status],[StatusCode]) VALUES (N'system',N'system::sentiment-es',N'Positive', NEWID(),N'Encantado (a) de conocerle', GETUTCDATE() ,'system', NULL, NULL, 1, 'AVAILABLE')
	INSERT [dbo].[Utterance] ([VCC], [AppId], [IntentId], [Id], [Text], [CreatedDate], [CreatedByUserId], [LastModifiedDate],[LastModifiedByUserId], [Status],[StatusCode]) VALUES (N'system',N'system::sentiment-es',N'Positive', NEWID(),N'Cuente con nosotros', GETUTCDATE() ,'system', NULL, NULL, 1, 'AVAILABLE')
	INSERT [dbo].[Utterance] ([VCC], [AppId], [IntentId], [Id], [Text], [CreatedDate], [CreatedByUserId], [LastModifiedDate],[LastModifiedByUserId], [Status],[StatusCode]) VALUES (N'system',N'system::sentiment-es',N'Positive', NEWID(),N'Tiene toda la razón', GETUTCDATE() ,'system', NULL, NULL, 1, 'AVAILABLE')
	INSERT [dbo].[Utterance] ([VCC], [AppId], [IntentId], [Id], [Text], [CreatedDate], [CreatedByUserId], [LastModifiedDate],[LastModifiedByUserId], [Status],[StatusCode]) VALUES (N'system',N'system::sentiment-es',N'Positive', NEWID(),N'Está em lo correcto', GETUTCDATE() ,'system', NULL, NULL, 1, 'AVAILABLE')
	INSERT [dbo].[Utterance] ([VCC], [AppId], [IntentId], [Id], [Text], [CreatedDate], [CreatedByUserId], [LastModifiedDate],[LastModifiedByUserId], [Status],[StatusCode]) VALUES (N'system',N'system::sentiment-es',N'Positive', NEWID(),N'Estoy feliz por poder ayudarle', GETUTCDATE() ,'system', NULL, NULL, 1, 'AVAILABLE')
	INSERT [dbo].[Utterance] ([VCC], [AppId], [IntentId], [Id], [Text], [CreatedDate], [CreatedByUserId], [LastModifiedDate],[LastModifiedByUserId], [Status],[StatusCode]) VALUES (N'system',N'system::sentiment-es',N'Positive', NEWID(),N'Me encantaría', GETUTCDATE() ,'system', NULL, NULL, 1, 'AVAILABLE')
	INSERT [dbo].[Utterance] ([VCC], [AppId], [IntentId], [Id], [Text], [CreatedDate], [CreatedByUserId], [LastModifiedDate],[LastModifiedByUserId], [Status],[StatusCode]) VALUES (N'system',N'system::sentiment-es',N'Positive', NEWID(),N'Me encanta', GETUTCDATE() ,'system', NULL, NULL, 1, 'AVAILABLE')
	INSERT [dbo].[Utterance] ([VCC], [AppId], [IntentId], [Id], [Text], [CreatedDate], [CreatedByUserId], [LastModifiedDate],[LastModifiedByUserId], [Status],[StatusCode]) VALUES (N'system',N'system::sentiment-es',N'Neutral', NEWID(),N'Buenos días', GETUTCDATE() ,'system', NULL, NULL, 1, 'AVAILABLE')
	INSERT [dbo].[Utterance] ([VCC], [AppId], [IntentId], [Id], [Text], [CreatedDate], [CreatedByUserId], [LastModifiedDate],[LastModifiedByUserId], [Status],[StatusCode]) VALUES (N'system',N'system::sentiment-es',N'Neutral', NEWID(),N'Buen día', GETUTCDATE() ,'system', NULL, NULL, 1, 'AVAILABLE')
	INSERT [dbo].[Utterance] ([VCC], [AppId], [IntentId], [Id], [Text], [CreatedDate], [CreatedByUserId], [LastModifiedDate],[LastModifiedByUserId], [Status],[StatusCode]) VALUES (N'system',N'system::sentiment-es',N'Neutral', NEWID(),N'Buenas tardes', GETUTCDATE() ,'system', NULL, NULL, 1, 'AVAILABLE')
	INSERT [dbo].[Utterance] ([VCC], [AppId], [IntentId], [Id], [Text], [CreatedDate], [CreatedByUserId], [LastModifiedDate],[LastModifiedByUserId], [Status],[StatusCode]) VALUES (N'system',N'system::sentiment-es',N'Neutral', NEWID(),N'Buenas noches', GETUTCDATE() ,'system', NULL, NULL, 1, 'AVAILABLE')
	INSERT [dbo].[Utterance] ([VCC], [AppId], [IntentId], [Id], [Text], [CreatedDate], [CreatedByUserId], [LastModifiedDate],[LastModifiedByUserId], [Status],[StatusCode]) VALUES (N'system',N'system::sentiment-es',N'Neutral', NEWID(),N'Me presento', GETUTCDATE() ,'system', NULL, NULL, 1, 'AVAILABLE')
	INSERT [dbo].[Utterance] ([VCC], [AppId], [IntentId], [Id], [Text], [CreatedDate], [CreatedByUserId], [LastModifiedDate],[LastModifiedByUserId], [Status],[StatusCode]) VALUES (N'system',N'system::sentiment-es',N'Neutral', NEWID(),N'Estoy llamando de', GETUTCDATE() ,'system', NULL, NULL, 1, 'AVAILABLE')
	INSERT [dbo].[Utterance] ([VCC], [AppId], [IntentId], [Id], [Text], [CreatedDate], [CreatedByUserId], [LastModifiedDate],[LastModifiedByUserId], [Status],[StatusCode]) VALUES (N'system',N'system::sentiment-es',N'Neutral', NEWID(),N'Muchas gracias', GETUTCDATE() ,'system', NULL, NULL, 1, 'AVAILABLE')
	INSERT [dbo].[Utterance] ([VCC], [AppId], [IntentId], [Id], [Text], [CreatedDate], [CreatedByUserId], [LastModifiedDate],[LastModifiedByUserId], [Status],[StatusCode]) VALUES (N'system',N'system::sentiment-es',N'Neutral', NEWID(),N'Gracias llamar', GETUTCDATE() ,'system', NULL, NULL, 1, 'AVAILABLE')
	INSERT [dbo].[Utterance] ([VCC], [AppId], [IntentId], [Id], [Text], [CreatedDate], [CreatedByUserId], [LastModifiedDate],[LastModifiedByUserId], [Status],[StatusCode]) VALUES (N'system',N'system::sentiment-es',N'Neutral', NEWID(),N'Gracias por comunicarse', GETUTCDATE() ,'system', NULL, NULL, 1, 'AVAILABLE')
	INSERT [dbo].[Utterance] ([VCC], [AppId], [IntentId], [Id], [Text], [CreatedDate], [CreatedByUserId], [LastModifiedDate],[LastModifiedByUserId], [Status],[StatusCode]) VALUES (N'system',N'system::sentiment-es',N'Neutral', NEWID(),N'En que puedo ayudar', GETUTCDATE() ,'system', NULL, NULL, 1, 'AVAILABLE')
	INSERT [dbo].[Utterance] ([VCC], [AppId], [IntentId], [Id], [Text], [CreatedDate], [CreatedByUserId], [LastModifiedDate],[LastModifiedByUserId], [Status],[StatusCode]) VALUES (N'system',N'system::sentiment-es',N'Neutral', NEWID(),N'Voy a verificar', GETUTCDATE() ,'system', NULL, NULL, 1, 'AVAILABLE')
	INSERT [dbo].[Utterance] ([VCC], [AppId], [IntentId], [Id], [Text], [CreatedDate], [CreatedByUserId], [LastModifiedDate],[LastModifiedByUserId], [Status],[StatusCode]) VALUES (N'system',N'system::sentiment-es',N'Neutral', NEWID(),N'Un momento por favor', GETUTCDATE() ,'system', NULL, NULL, 1, 'AVAILABLE')
	INSERT [dbo].[Utterance] ([VCC], [AppId], [IntentId], [Id], [Text], [CreatedDate], [CreatedByUserId], [LastModifiedDate],[LastModifiedByUserId], [Status],[StatusCode]) VALUES (N'system',N'system::sentiment-es',N'Neutral', NEWID(),N'Gracias por la espera', GETUTCDATE() ,'system', NULL, NULL, 1, 'AVAILABLE')
	INSERT [dbo].[Utterance] ([VCC], [AppId], [IntentId], [Id], [Text], [CreatedDate], [CreatedByUserId], [LastModifiedDate],[LastModifiedByUserId], [Status],[StatusCode]) VALUES (N'system',N'system::sentiment-es',N'Neutral', NEWID(),N'Le voy a derivar a una encuesta', GETUTCDATE() ,'system', NULL, NULL, 1, 'AVAILABLE')
	INSERT [dbo].[Utterance] ([VCC], [AppId], [IntentId], [Id], [Text], [CreatedDate], [CreatedByUserId], [LastModifiedDate],[LastModifiedByUserId], [Status],[StatusCode]) VALUES (N'system',N'system::sentiment-es',N'Neutral', NEWID(),N'Un momento en línea', GETUTCDATE() ,'system', NULL, NULL, 1, 'AVAILABLE')
	INSERT [dbo].[Utterance] ([VCC], [AppId], [IntentId], [Id], [Text], [CreatedDate], [CreatedByUserId], [LastModifiedDate],[LastModifiedByUserId], [Status],[StatusCode]) VALUES (N'system',N'system::sentiment-es',N'Neutral', NEWID(),N'Le voy a transferir', GETUTCDATE() ,'system', NULL, NULL, 1, 'AVAILABLE')
	INSERT [dbo].[Utterance] ([VCC], [AppId], [IntentId], [Id], [Text], [CreatedDate], [CreatedByUserId], [LastModifiedDate],[LastModifiedByUserId], [Status],[StatusCode]) VALUES (N'system',N'system::sentiment-es',N'Neutral', NEWID(),N'Con mucho gusto', GETUTCDATE() ,'system', NULL, NULL, 1, 'AVAILABLE')
	INSERT [dbo].[Utterance] ([VCC], [AppId], [IntentId], [Id], [Text], [CreatedDate], [CreatedByUserId], [LastModifiedDate],[LastModifiedByUserId], [Status],[StatusCode]) VALUES (N'system',N'system::sentiment-es',N'Neutral', NEWID(),N'Hasta luego', GETUTCDATE() ,'system', NULL, NULL, 1, 'AVAILABLE')
	INSERT [dbo].[Utterance] ([VCC], [AppId], [IntentId], [Id], [Text], [CreatedDate], [CreatedByUserId], [LastModifiedDate],[LastModifiedByUserId], [Status],[StatusCode]) VALUES (N'system',N'system::sentiment-es',N'Neutral', NEWID(),N'Qué puedo hacer por usted', GETUTCDATE() ,'system', NULL, NULL, 1, 'AVAILABLE')
	INSERT [dbo].[Utterance] ([VCC], [AppId], [IntentId], [Id], [Text], [CreatedDate], [CreatedByUserId], [LastModifiedDate],[LastModifiedByUserId], [Status],[StatusCode]) VALUES (N'system',N'system::sentiment-es',N'Neutral', NEWID(),N'Qué tenga una buena semana', GETUTCDATE() ,'system', NULL, NULL, 1, 'AVAILABLE')
	INSERT [dbo].[Utterance] ([VCC], [AppId], [IntentId], [Id], [Text], [CreatedDate], [CreatedByUserId], [LastModifiedDate],[LastModifiedByUserId], [Status],[StatusCode]) VALUES (N'system',N'system::sentiment-es',N'Neutral', NEWID(),N'Qué tenga un buen día', GETUTCDATE() ,'system', NULL, NULL, 1, 'AVAILABLE')
	INSERT [dbo].[Utterance] ([VCC], [AppId], [IntentId], [Id], [Text], [CreatedDate], [CreatedByUserId], [LastModifiedDate],[LastModifiedByUserId], [Status],[StatusCode]) VALUES (N'system',N'system::sentiment-es',N'Neutral', NEWID(),N'Algo más que pueda ayudarle', GETUTCDATE() ,'system', NULL, NULL, 1, 'AVAILABLE')
	INSERT [dbo].[Utterance] ([VCC], [AppId], [IntentId], [Id], [Text], [CreatedDate], [CreatedByUserId], [LastModifiedDate],[LastModifiedByUserId], [Status],[StatusCode]) VALUES (N'system',N'system::sentiment-es',N'Neutral', NEWID(),N'Alguna outra duda', GETUTCDATE() ,'system', NULL, NULL, 1, 'AVAILABLE')
	INSERT [dbo].[Utterance] ([VCC], [AppId], [IntentId], [Id], [Text], [CreatedDate], [CreatedByUserId], [LastModifiedDate],[LastModifiedByUserId], [Status],[StatusCode]) VALUES (N'system',N'system::sentiment-es',N'Neutral', NEWID(),N'Bienvenido (a)', GETUTCDATE() ,'system', NULL, NULL, 1, 'AVAILABLE')
	INSERT [dbo].[Utterance] ([VCC], [AppId], [IntentId], [Id], [Text], [CreatedDate], [CreatedByUserId], [LastModifiedDate],[LastModifiedByUserId], [Status],[StatusCode]) VALUES (N'system',N'system::sentiment-es',N'Neutral', NEWID(),N'Hola, cómo estás', GETUTCDATE() ,'system', NULL, NULL, 1, 'AVAILABLE')
	INSERT [dbo].[Utterance] ([VCC], [AppId], [IntentId], [Id], [Text], [CreatedDate], [CreatedByUserId], [LastModifiedDate],[LastModifiedByUserId], [Status],[StatusCode]) VALUES (N'system',N'system::sentiment-es',N'Negative',NEWID(),N'No tengo idea', GETUTCDATE() ,'system', NULL, NULL, 1, 'AVAILABLE')
	INSERT [dbo].[Utterance] ([VCC], [AppId], [IntentId], [Id], [Text], [CreatedDate], [CreatedByUserId], [LastModifiedDate],[LastModifiedByUserId], [Status],[StatusCode]) VALUES (N'system',N'system::sentiment-es',N'Negative',NEWID(),N'No es posible', GETUTCDATE() ,'system', NULL, NULL, 1, 'AVAILABLE')
	INSERT [dbo].[Utterance] ([VCC], [AppId], [IntentId], [Id], [Text], [CreatedDate], [CreatedByUserId], [LastModifiedDate],[LastModifiedByUserId], [Status],[StatusCode]) VALUES (N'system',N'system::sentiment-es',N'Negative',NEWID(),N'No lo creo', GETUTCDATE() ,'system', NULL, NULL, 1, 'AVAILABLE')
	INSERT [dbo].[Utterance] ([VCC], [AppId], [IntentId], [Id], [Text], [CreatedDate], [CreatedByUserId], [LastModifiedDate],[LastModifiedByUserId], [Status],[StatusCode]) VALUES (N'system',N'system::sentiment-es',N'Negative',NEWID(),N'No podemos solucionar', GETUTCDATE() ,'system', NULL, NULL, 1, 'AVAILABLE')
	INSERT [dbo].[Utterance] ([VCC], [AppId], [IntentId], [Id], [Text], [CreatedDate], [CreatedByUserId], [LastModifiedDate],[LastModifiedByUserId], [Status],[StatusCode]) VALUES (N'system',N'system::sentiment-es',N'Negative',NEWID(),N'Qué pena con usted', GETUTCDATE() ,'system', NULL, NULL, 1, 'AVAILABLE')
	INSERT [dbo].[Utterance] ([VCC], [AppId], [IntentId], [Id], [Text], [CreatedDate], [CreatedByUserId], [LastModifiedDate],[LastModifiedByUserId], [Status],[StatusCode]) VALUES (N'system',N'system::sentiment-es',N'Negative',NEWID(),N'No me ha entendido', GETUTCDATE() ,'system', NULL, NULL, 1, 'AVAILABLE')
	INSERT [dbo].[Utterance] ([VCC], [AppId], [IntentId], [Id], [Text], [CreatedDate], [CreatedByUserId], [LastModifiedDate],[LastModifiedByUserId], [Status],[StatusCode]) VALUES (N'system',N'system::sentiment-es',N'Negative',NEWID(),N'Yo sé lo que estoy haciendo', GETUTCDATE() ,'system', NULL, NULL, 1, 'AVAILABLE')
	INSERT [dbo].[Utterance] ([VCC], [AppId], [IntentId], [Id], [Text], [CreatedDate], [CreatedByUserId], [LastModifiedDate],[LastModifiedByUserId], [Status],[StatusCode]) VALUES (N'system',N'system::sentiment-es',N'Negative',NEWID(),N'No le entiendo', GETUTCDATE() ,'system', NULL, NULL, 1, 'AVAILABLE')
	INSERT [dbo].[Utterance] ([VCC], [AppId], [IntentId], [Id], [Text], [CreatedDate], [CreatedByUserId], [LastModifiedDate],[LastModifiedByUserId], [Status],[StatusCode]) VALUES (N'system',N'system::sentiment-es',N'Negative',NEWID(),N'No puedo hacerlo', GETUTCDATE() ,'system', NULL, NULL, 1, 'AVAILABLE')
	INSERT [dbo].[Utterance] ([VCC], [AppId], [IntentId], [Id], [Text], [CreatedDate], [CreatedByUserId], [LastModifiedDate],[LastModifiedByUserId], [Status],[StatusCode]) VALUES (N'system',N'system::sentiment-es',N'Negative',NEWID(),N'No tengo conocimiento', GETUTCDATE() ,'system', NULL, NULL, 1, 'AVAILABLE')
	INSERT [dbo].[Utterance] ([VCC], [AppId], [IntentId], [Id], [Text], [CreatedDate], [CreatedByUserId], [LastModifiedDate],[LastModifiedByUserId], [Status],[StatusCode]) VALUES (N'system',N'system::sentiment-es',N'Negative',NEWID(),N'Desafortunadamente', GETUTCDATE() ,'system', NULL, NULL, 1, 'AVAILABLE')
	INSERT [dbo].[Utterance] ([VCC], [AppId], [IntentId], [Id], [Text], [CreatedDate], [CreatedByUserId], [LastModifiedDate],[LastModifiedByUserId], [Status],[StatusCode]) VALUES (N'system',N'system::sentiment-es',N'Negative',NEWID(),N'Infelizmente', GETUTCDATE() ,'system', NULL, NULL, 1, 'AVAILABLE')
	INSERT [dbo].[Utterance] ([VCC], [AppId], [IntentId], [Id], [Text], [CreatedDate], [CreatedByUserId], [LastModifiedDate],[LastModifiedByUserId], [Status],[StatusCode]) VALUES (N'system',N'system::sentiment-es',N'Negative',NEWID(),N'Por desgracia', GETUTCDATE() ,'system', NULL, NULL, 1, 'AVAILABLE')
	INSERT [dbo].[Utterance] ([VCC], [AppId], [IntentId], [Id], [Text], [CreatedDate], [CreatedByUserId], [LastModifiedDate],[LastModifiedByUserId], [Status],[StatusCode]) VALUES (N'system',N'system::sentiment-es',N'Negative',NEWID(),N'No hay como', GETUTCDATE() ,'system', NULL, NULL, 1, 'AVAILABLE')
	INSERT [dbo].[Utterance] ([VCC], [AppId], [IntentId], [Id], [Text], [CreatedDate], [CreatedByUserId], [LastModifiedDate],[LastModifiedByUserId], [Status],[StatusCode]) VALUES (N'system',N'system::sentiment-es',N'Negative',NEWID(),N'Tengo limitaciones', GETUTCDATE() ,'system', NULL, NULL, 1, 'AVAILABLE')
	INSERT [dbo].[Utterance] ([VCC], [AppId], [IntentId], [Id], [Text], [CreatedDate], [CreatedByUserId], [LastModifiedDate],[LastModifiedByUserId], [Status],[StatusCode]) VALUES (N'system',N'system::sentiment-es',N'Negative',NEWID(),N'No me permiten', GETUTCDATE() ,'system', NULL, NULL, 1, 'AVAILABLE')
	INSERT [dbo].[Utterance] ([VCC], [AppId], [IntentId], [Id], [Text], [CreatedDate], [CreatedByUserId], [LastModifiedDate],[LastModifiedByUserId], [Status],[StatusCode]) VALUES (N'system',N'system::sentiment-es',N'Negative',NEWID(),N'Eso es terrible', GETUTCDATE() ,'system', NULL, NULL, 1, 'AVAILABLE')
	INSERT [dbo].[Utterance] ([VCC], [AppId], [IntentId], [Id], [Text], [CreatedDate], [CreatedByUserId], [LastModifiedDate],[LastModifiedByUserId], [Status],[StatusCode]) VALUES (N'system',N'system::sentiment-es',N'Negative',NEWID(),N'No hay solución', GETUTCDATE() ,'system', NULL, NULL, 1, 'AVAILABLE')
	INSERT [dbo].[Utterance] ([VCC], [AppId], [IntentId], [Id], [Text], [CreatedDate], [CreatedByUserId], [LastModifiedDate],[LastModifiedByUserId], [Status],[StatusCode]) VALUES (N'system',N'system::sentiment-es',N'Negative',NEWID(),N'Es incorrecto', GETUTCDATE() ,'system', NULL, NULL, 1, 'AVAILABLE')
	INSERT [dbo].[Utterance] ([VCC], [AppId], [IntentId], [Id], [Text], [CreatedDate], [CreatedByUserId], [LastModifiedDate],[LastModifiedByUserId], [Status],[StatusCode]) VALUES (N'system',N'system::sentiment-es',N'Negative',NEWID(),N'Escúchame', GETUTCDATE() ,'system', NULL, NULL, 1, 'AVAILABLE')
	INSERT [dbo].[Utterance] ([VCC], [AppId], [IntentId], [Id], [Text], [CreatedDate], [CreatedByUserId], [LastModifiedDate],[LastModifiedByUserId], [Status],[StatusCode]) VALUES (N'system',N'system::sentiment-es',N'Negative',NEWID(),N'Ajá', GETUTCDATE() ,'system', NULL, NULL, 1, 'AVAILABLE')
	INSERT [dbo].[Utterance] ([VCC], [AppId], [IntentId], [Id], [Text], [CreatedDate], [CreatedByUserId], [LastModifiedDate],[LastModifiedByUserId], [Status],[StatusCode]) VALUES (N'system',N'system::sentiment-es',N'Negative',NEWID(),N'Pues, no sé', GETUTCDATE() ,'system', NULL, NULL, 1, 'AVAILABLE')
	INSERT [dbo].[Utterance] ([VCC], [AppId], [IntentId], [Id], [Text], [CreatedDate], [CreatedByUserId], [LastModifiedDate],[LastModifiedByUserId], [Status],[StatusCode]) VALUES (N'system',N'system::sentiment-es',N'Negative',NEWID(),N'Qué puedo hacer', GETUTCDATE() ,'system', NULL, NULL, 1, 'AVAILABLE')
	INSERT [dbo].[Utterance] ([VCC], [AppId], [IntentId], [Id], [Text], [CreatedDate], [CreatedByUserId], [LastModifiedDate],[LastModifiedByUserId], [Status],[StatusCode]) VALUES (N'system',N'system::sentiment-es',N'Negative',NEWID(),N'No está a mi alcance', GETUTCDATE() ,'system', NULL, NULL, 1, 'AVAILABLE')
	INSERT [dbo].[Utterance] ([VCC], [AppId], [IntentId], [Id], [Text], [CreatedDate], [CreatedByUserId], [LastModifiedDate],[LastModifiedByUserId], [Status],[StatusCode]) VALUES (N'system',N'system::sentiment-es',N'Negative',NEWID(),N'No puedo ayudarle', GETUTCDATE() ,'system', NULL, NULL, 1, 'AVAILABLE')

	--UTTERANCES DE SENTIMIENTO INGLES

	INSERT [dbo].[Utterance] ([VCC], [AppId], [IntentId], [Id], [Text], [CreatedDate], [CreatedByUserId], [LastModifiedDate],[LastModifiedByUserId], [Status],[StatusCode]) VALUES (N'system',N'system::sentiment-en',N'Positive',NEWID(),N'I am glad',GETUTCDATE(),'system',	NULL,	NULL,	1,	'AVAILABLE')
	INSERT [dbo].[Utterance] ([VCC], [AppId], [IntentId], [Id], [Text], [CreatedDate], [CreatedByUserId], [LastModifiedDate],[LastModifiedByUserId], [Status],[StatusCode]) VALUES (N'system',N'system::sentiment-en',N'Positive',NEWID(),N'Good to hear that',GETUTCDATE(),'system',	NULL,	NULL,	1,	'AVAILABLE')
	INSERT [dbo].[Utterance] ([VCC], [AppId], [IntentId], [Id], [Text], [CreatedDate], [CreatedByUserId], [LastModifiedDate],[LastModifiedByUserId], [Status],[StatusCode]) VALUES (N'system',N'system::sentiment-en',N'Positive',NEWID(),N'I understand',GETUTCDATE(),'system',	NULL,	NULL,	1,	'AVAILABLE')
	INSERT [dbo].[Utterance] ([VCC], [AppId], [IntentId], [Id], [Text], [CreatedDate], [CreatedByUserId], [LastModifiedDate],[LastModifiedByUserId], [Status],[StatusCode]) VALUES (N'system',N'system::sentiment-en',N'Positive',NEWID(),N'Count on me',GETUTCDATE(),'system',	NULL,	NULL,	1,	'AVAILABLE')
	INSERT [dbo].[Utterance] ([VCC], [AppId], [IntentId], [Id], [Text], [CreatedDate], [CreatedByUserId], [LastModifiedDate],[LastModifiedByUserId], [Status],[StatusCode]) VALUES (N'system',N'system::sentiment-en',N'Positive',NEWID(),N'Thank you very much',GETUTCDATE(),'system',	NULL,	NULL,	1,	'AVAILABLE')
	INSERT [dbo].[Utterance] ([VCC], [AppId], [IntentId], [Id], [Text], [CreatedDate], [CreatedByUserId], [LastModifiedDate],[LastModifiedByUserId], [Status],[StatusCode]) VALUES (N'system',N'system::sentiment-en',N'Positive',NEWID(),N'Sure I will do it',GETUTCDATE(),'system',	NULL,	NULL,	1,	'AVAILABLE')
	INSERT [dbo].[Utterance] ([VCC], [AppId], [IntentId], [Id], [Text], [CreatedDate], [CreatedByUserId], [LastModifiedDate],[LastModifiedByUserId], [Status],[StatusCode]) VALUES (N'system',N'system::sentiment-en',N'Positive',NEWID(),N'Of course I will ',GETUTCDATE(),'system',	NULL,	NULL,	1,	'AVAILABLE')
	INSERT [dbo].[Utterance] ([VCC], [AppId], [IntentId], [Id], [Text], [CreatedDate], [CreatedByUserId], [LastModifiedDate],[LastModifiedByUserId], [Status],[StatusCode]) VALUES (N'system',N'system::sentiment-en',N'Positive',NEWID(),N'I am happy',GETUTCDATE(),'system',	NULL,	NULL,	1,	'AVAILABLE')
	INSERT [dbo].[Utterance] ([VCC], [AppId], [IntentId], [Id], [Text], [CreatedDate], [CreatedByUserId], [LastModifiedDate],[LastModifiedByUserId], [Status],[StatusCode]) VALUES (N'system',N'system::sentiment-en',N'Positive',NEWID(),N'Ok I got it',GETUTCDATE(),'system',	NULL,	NULL,	1,	'AVAILABLE')
	INSERT [dbo].[Utterance] ([VCC], [AppId], [IntentId], [Id], [Text], [CreatedDate], [CreatedByUserId], [LastModifiedDate],[LastModifiedByUserId], [Status],[StatusCode]) VALUES (N'system',N'system::sentiment-en',N'Positive',NEWID(),N'We will solve it',GETUTCDATE(),'system',	NULL,	NULL,	1,	'AVAILABLE')
	INSERT [dbo].[Utterance] ([VCC], [AppId], [IntentId], [Id], [Text], [CreatedDate], [CreatedByUserId], [LastModifiedDate],[LastModifiedByUserId], [Status],[StatusCode]) VALUES (N'system',N'system::sentiment-en',N'Positive',NEWID(),N'We will fix it',GETUTCDATE(),'system',	NULL,	NULL,	1,	'AVAILABLE')
	INSERT [dbo].[Utterance] ([VCC], [AppId], [IntentId], [Id], [Text], [CreatedDate], [CreatedByUserId], [LastModifiedDate],[LastModifiedByUserId], [Status],[StatusCode]) VALUES (N'system',N'system::sentiment-en',N'Positive',NEWID(),N'Please',GETUTCDATE(),'system',	NULL,	NULL,	1,	'AVAILABLE')
	INSERT [dbo].[Utterance] ([VCC], [AppId], [IntentId], [Id], [Text], [CreatedDate], [CreatedByUserId], [LastModifiedDate],[LastModifiedByUserId], [Status],[StatusCode]) VALUES (N'system',N'system::sentiment-en',N'Positive',NEWID(),N'Please tell me',GETUTCDATE(),'system',	NULL,	NULL,	1,	'AVAILABLE')
	INSERT [dbo].[Utterance] ([VCC], [AppId], [IntentId], [Id], [Text], [CreatedDate], [CreatedByUserId], [LastModifiedDate],[LastModifiedByUserId], [Status],[StatusCode]) VALUES (N'system',N'system::sentiment-en',N'Positive',NEWID(),N'I am sure I can help you',GETUTCDATE(),'system',	NULL,	NULL,	1,	'AVAILABLE')
	INSERT [dbo].[Utterance] ([VCC], [AppId], [IntentId], [Id], [Text], [CreatedDate], [CreatedByUserId], [LastModifiedDate],[LastModifiedByUserId], [Status],[StatusCode]) VALUES (N'system',N'system::sentiment-en',N'Positive',NEWID(),N'It is easy to solve',GETUTCDATE(),'system',	NULL,	NULL,	1,	'AVAILABLE')
	INSERT [dbo].[Utterance] ([VCC], [AppId], [IntentId], [Id], [Text], [CreatedDate], [CreatedByUserId], [LastModifiedDate],[LastModifiedByUserId], [Status],[StatusCode]) VALUES (N'system',N'system::sentiment-en',N'Positive',NEWID(),N'Great',GETUTCDATE(),'system',	NULL,	NULL,	1,	'AVAILABLE')
	INSERT [dbo].[Utterance] ([VCC], [AppId], [IntentId], [Id], [Text], [CreatedDate], [CreatedByUserId], [LastModifiedDate],[LastModifiedByUserId], [Status],[StatusCode]) VALUES (N'system',N'system::sentiment-en',N'Positive',NEWID(),N'Take care',GETUTCDATE(),'system',	NULL,	NULL,	1,	'AVAILABLE')
	INSERT [dbo].[Utterance] ([VCC], [AppId], [IntentId], [Id], [Text], [CreatedDate], [CreatedByUserId], [LastModifiedDate],[LastModifiedByUserId], [Status],[StatusCode]) VALUES (N'system',N'system::sentiment-en',N'Positive',NEWID(),N'Do not worry',GETUTCDATE(),'system',	NULL,	NULL,	1,	'AVAILABLE')
	INSERT [dbo].[Utterance] ([VCC], [AppId], [IntentId], [Id], [Text], [CreatedDate], [CreatedByUserId], [LastModifiedDate],[LastModifiedByUserId], [Status],[StatusCode]) VALUES (N'system',N'system::sentiment-en',N'Positive',NEWID(),N'Good question',GETUTCDATE(),'system',	NULL,	NULL,	1,	'AVAILABLE')
	INSERT [dbo].[Utterance] ([VCC], [AppId], [IntentId], [Id], [Text], [CreatedDate], [CreatedByUserId], [LastModifiedDate],[LastModifiedByUserId], [Status],[StatusCode]) VALUES (N'system',N'system::sentiment-en',N'Positive',NEWID(),N'Pleased to talk to you',GETUTCDATE(),'system',	NULL,	NULL,	1,	'AVAILABLE')
	INSERT [dbo].[Utterance] ([VCC], [AppId], [IntentId], [Id], [Text], [CreatedDate], [CreatedByUserId], [LastModifiedDate],[LastModifiedByUserId], [Status],[StatusCode]) VALUES (N'system',N'system::sentiment-en',N'Positive',NEWID(),N'Count on us',GETUTCDATE(),'system',	NULL,	NULL,	1,	'AVAILABLE')
	INSERT [dbo].[Utterance] ([VCC], [AppId], [IntentId], [Id], [Text], [CreatedDate], [CreatedByUserId], [LastModifiedDate],[LastModifiedByUserId], [Status],[StatusCode]) VALUES (N'system',N'system::sentiment-en',N'Positive',NEWID(),N'You are right',GETUTCDATE(),'system',	NULL,	NULL,	1,	'AVAILABLE')
	INSERT [dbo].[Utterance] ([VCC], [AppId], [IntentId], [Id], [Text], [CreatedDate], [CreatedByUserId], [LastModifiedDate],[LastModifiedByUserId], [Status],[StatusCode]) VALUES (N'system',N'system::sentiment-en',N'Positive',NEWID(),N'It is correct',GETUTCDATE(),'system',	NULL,	NULL,	1,	'AVAILABLE')
	INSERT [dbo].[Utterance] ([VCC], [AppId], [IntentId], [Id], [Text], [CreatedDate], [CreatedByUserId], [LastModifiedDate],[LastModifiedByUserId], [Status],[StatusCode]) VALUES (N'system',N'system::sentiment-en',N'Positive',NEWID(),N'I am glad to help you',GETUTCDATE(),'system',	NULL,	NULL,	1,	'AVAILABLE')
	INSERT [dbo].[Utterance] ([VCC], [AppId], [IntentId], [Id], [Text], [CreatedDate], [CreatedByUserId], [LastModifiedDate],[LastModifiedByUserId], [Status],[StatusCode]) VALUES (N'system',N'system::sentiment-en',N'Positive',NEWID(),N'I am glad to hear that',GETUTCDATE(),'system',	NULL,	NULL,	1,	'AVAILABLE')
	INSERT [dbo].[Utterance] ([VCC], [AppId], [IntentId], [Id], [Text], [CreatedDate], [CreatedByUserId], [LastModifiedDate],[LastModifiedByUserId], [Status],[StatusCode]) VALUES (N'system',N'system::sentiment-en',N'Neutral',NEWID(),N'Goodbye',GETUTCDATE(),'system',	NULL,	NULL,	1,	'AVAILABLE')
	INSERT [dbo].[Utterance] ([VCC], [AppId], [IntentId], [Id], [Text], [CreatedDate], [CreatedByUserId], [LastModifiedDate],[LastModifiedByUserId], [Status],[StatusCode]) VALUES (N'system',N'system::sentiment-en',N'Neutral',NEWID(),N'Good morning',GETUTCDATE(),'system',	NULL,	NULL,	1,	'AVAILABLE')
	INSERT [dbo].[Utterance] ([VCC], [AppId], [IntentId], [Id], [Text], [CreatedDate], [CreatedByUserId], [LastModifiedDate],[LastModifiedByUserId], [Status],[StatusCode]) VALUES (N'system',N'system::sentiment-en',N'Neutral',NEWID(),N'Good afternoon',GETUTCDATE(),'system',	NULL,	NULL,	1,	'AVAILABLE')
	INSERT [dbo].[Utterance] ([VCC], [AppId], [IntentId], [Id], [Text], [CreatedDate], [CreatedByUserId], [LastModifiedDate],[LastModifiedByUserId], [Status],[StatusCode]) VALUES (N'system',N'system::sentiment-en',N'Neutral',NEWID(),N'Good evening',GETUTCDATE(),'system',	NULL,	NULL,	1,	'AVAILABLE')
	INSERT [dbo].[Utterance] ([VCC], [AppId], [IntentId], [Id], [Text], [CreatedDate], [CreatedByUserId], [LastModifiedDate],[LastModifiedByUserId], [Status],[StatusCode]) VALUES (N'system',N'system::sentiment-en',N'Neutral',NEWID(),N'I am work for',GETUTCDATE(),'system',	NULL,	NULL,	1,	'AVAILABLE')
	INSERT [dbo].[Utterance] ([VCC], [AppId], [IntentId], [Id], [Text], [CreatedDate], [CreatedByUserId], [LastModifiedDate],[LastModifiedByUserId], [Status],[StatusCode]) VALUES (N'system',N'system::sentiment-en',N'Neutral',NEWID(),N'My name is',GETUTCDATE(),'system',	NULL,	NULL,	1,	'AVAILABLE')
	INSERT [dbo].[Utterance] ([VCC], [AppId], [IntentId], [Id], [Text], [CreatedDate], [CreatedByUserId], [LastModifiedDate],[LastModifiedByUserId], [Status],[StatusCode]) VALUES (N'system',N'system::sentiment-en',N'Neutral',NEWID(),N'I am from',GETUTCDATE(),'system',	NULL,	NULL,	1,	'AVAILABLE')
	INSERT [dbo].[Utterance] ([VCC], [AppId], [IntentId], [Id], [Text], [CreatedDate], [CreatedByUserId], [LastModifiedDate],[LastModifiedByUserId], [Status],[StatusCode]) VALUES (N'system',N'system::sentiment-en',N'Neutral',NEWID(),N'Thank you',GETUTCDATE(),'system',	NULL,	NULL,	1,	'AVAILABLE')
	INSERT [dbo].[Utterance] ([VCC], [AppId], [IntentId], [Id], [Text], [CreatedDate], [CreatedByUserId], [LastModifiedDate],[LastModifiedByUserId], [Status],[StatusCode]) VALUES (N'system',N'system::sentiment-en',N'Neutral',NEWID(),N'Thank you for calling',GETUTCDATE(),'system',	NULL,	NULL,	1,	'AVAILABLE')
	INSERT [dbo].[Utterance] ([VCC], [AppId], [IntentId], [Id], [Text], [CreatedDate], [CreatedByUserId], [LastModifiedDate],[LastModifiedByUserId], [Status],[StatusCode]) VALUES (N'system',N'system::sentiment-en',N'Neutral',NEWID(),N'I will check',GETUTCDATE(),'system',	NULL,	NULL,	1,	'AVAILABLE')
	INSERT [dbo].[Utterance] ([VCC], [AppId], [IntentId], [Id], [Text], [CreatedDate], [CreatedByUserId], [LastModifiedDate],[LastModifiedByUserId], [Status],[StatusCode]) VALUES (N'system',N'system::sentiment-en',N'Neutral',NEWID(),N'How can I help you',GETUTCDATE(),'system',	NULL,	NULL,	1,	'AVAILABLE')
	INSERT [dbo].[Utterance] ([VCC], [AppId], [IntentId], [Id], [Text], [CreatedDate], [CreatedByUserId], [LastModifiedDate],[LastModifiedByUserId], [Status],[StatusCode]) VALUES (N'system',N'system::sentiment-en',N'Neutral',NEWID(),N'I will verify',GETUTCDATE(),'system',	NULL,	NULL,	1,	'AVAILABLE')
	INSERT [dbo].[Utterance] ([VCC], [AppId], [IntentId], [Id], [Text], [CreatedDate], [CreatedByUserId], [LastModifiedDate],[LastModifiedByUserId], [Status],[StatusCode]) VALUES (N'system',N'system::sentiment-en',N'Neutral',NEWID(),N'A moment please',GETUTCDATE(),'system',	NULL,	NULL,	1,	'AVAILABLE')
	INSERT [dbo].[Utterance] ([VCC], [AppId], [IntentId], [Id], [Text], [CreatedDate], [CreatedByUserId], [LastModifiedDate],[LastModifiedByUserId], [Status],[StatusCode]) VALUES (N'system',N'system::sentiment-en',N'Neutral',NEWID(),N'thank you for waiting',GETUTCDATE(),'system',	NULL,	NULL,	1,	'AVAILABLE')
	INSERT [dbo].[Utterance] ([VCC], [AppId], [IntentId], [Id], [Text], [CreatedDate], [CreatedByUserId], [LastModifiedDate],[LastModifiedByUserId], [Status],[StatusCode]) VALUES (N'system',N'system::sentiment-en',N'Neutral',NEWID(),N'I will send you to a service evaluation',GETUTCDATE(),'system',	NULL,	NULL,	1,	'AVAILABLE')
	INSERT [dbo].[Utterance] ([VCC], [AppId], [IntentId], [Id], [Text], [CreatedDate], [CreatedByUserId], [LastModifiedDate],[LastModifiedByUserId], [Status],[StatusCode]) VALUES (N'system',N'system::sentiment-en',N'Neutral',NEWID(),N'Hold a moment ',GETUTCDATE(),'system',	NULL,	NULL,	1,	'AVAILABLE')
	INSERT [dbo].[Utterance] ([VCC], [AppId], [IntentId], [Id], [Text], [CreatedDate], [CreatedByUserId], [LastModifiedDate],[LastModifiedByUserId], [Status],[StatusCode]) VALUES (N'system',N'system::sentiment-en',N'Neutral',NEWID(),N'I will transfer you',GETUTCDATE(),'system',	NULL,	NULL,	1,	'AVAILABLE')
	INSERT [dbo].[Utterance] ([VCC], [AppId], [IntentId], [Id], [Text], [CreatedDate], [CreatedByUserId], [LastModifiedDate],[LastModifiedByUserId], [Status],[StatusCode]) VALUES (N'system',N'system::sentiment-en',N'Neutral',NEWID(),N'You are welcome',GETUTCDATE(),'system',	NULL,	NULL,	1,	'AVAILABLE')
	INSERT [dbo].[Utterance] ([VCC], [AppId], [IntentId], [Id], [Text], [CreatedDate], [CreatedByUserId], [LastModifiedDate],[LastModifiedByUserId], [Status],[StatusCode]) VALUES (N'system',N'system::sentiment-en',N'Neutral',NEWID(),N'Bye',GETUTCDATE(),'system',	NULL,	NULL,	1,	'AVAILABLE')
	INSERT [dbo].[Utterance] ([VCC], [AppId], [IntentId], [Id], [Text], [CreatedDate], [CreatedByUserId], [LastModifiedDate],[LastModifiedByUserId], [Status],[StatusCode]) VALUES (N'system',N'system::sentiment-en',N'Neutral',NEWID(),N'What can I do for you',GETUTCDATE(),'system',	NULL,	NULL,	1,	'AVAILABLE')
	INSERT [dbo].[Utterance] ([VCC], [AppId], [IntentId], [Id], [Text], [CreatedDate], [CreatedByUserId], [LastModifiedDate],[LastModifiedByUserId], [Status],[StatusCode]) VALUES (N'system',N'system::sentiment-en',N'Neutral',NEWID(),N'Anything else',GETUTCDATE(),'system',	NULL,	NULL,	1,	'AVAILABLE')
	INSERT [dbo].[Utterance] ([VCC], [AppId], [IntentId], [Id], [Text], [CreatedDate], [CreatedByUserId], [LastModifiedDate],[LastModifiedByUserId], [Status],[StatusCode]) VALUES (N'system',N'system::sentiment-en',N'Neutral',NEWID(),N'Do you have any question',GETUTCDATE(),'system',	NULL,	NULL,	1,	'AVAILABLE')
	INSERT [dbo].[Utterance] ([VCC], [AppId], [IntentId], [Id], [Text], [CreatedDate], [CreatedByUserId], [LastModifiedDate],[LastModifiedByUserId], [Status],[StatusCode]) VALUES (N'system',N'system::sentiment-en',N'Neutral',NEWID(),N'Do you need something else',GETUTCDATE(),'system',	NULL,	NULL,	1,	'AVAILABLE')
	INSERT [dbo].[Utterance] ([VCC], [AppId], [IntentId], [Id], [Text], [CreatedDate], [CreatedByUserId], [LastModifiedDate],[LastModifiedByUserId], [Status],[StatusCode]) VALUES (N'system',N'system::sentiment-en',N'Neutral',NEWID(),N'Welcome',GETUTCDATE(),'system',	NULL,	NULL,	1,	'AVAILABLE')
	INSERT [dbo].[Utterance] ([VCC], [AppId], [IntentId], [Id], [Text], [CreatedDate], [CreatedByUserId], [LastModifiedDate],[LastModifiedByUserId], [Status],[StatusCode]) VALUES (N'system',N'system::sentiment-en',N'Neutral',NEWID(),N'How are you',GETUTCDATE(),'system',	NULL,	NULL,	1,	'AVAILABLE')
	INSERT [dbo].[Utterance] ([VCC], [AppId], [IntentId], [Id], [Text], [CreatedDate], [CreatedByUserId], [LastModifiedDate],[LastModifiedByUserId], [Status],[StatusCode]) VALUES (N'system',N'system::sentiment-en',N'Negative',NEWID(),N'No Idea',GETUTCDATE(),'system',	NULL,	NULL,	1,	'AVAILABLE')
	INSERT [dbo].[Utterance] ([VCC], [AppId], [IntentId], [Id], [Text], [CreatedDate], [CreatedByUserId], [LastModifiedDate],[LastModifiedByUserId], [Status],[StatusCode]) VALUES (N'system',N'system::sentiment-en',N'Negative',NEWID(),N'Not possible',GETUTCDATE(),'system',	NULL,	NULL,	1,	'AVAILABLE')
	INSERT [dbo].[Utterance] ([VCC], [AppId], [IntentId], [Id], [Text], [CreatedDate], [CreatedByUserId], [LastModifiedDate],[LastModifiedByUserId], [Status],[StatusCode]) VALUES (N'system',N'system::sentiment-en',N'Negative',NEWID(),N'I do not think so',GETUTCDATE(),'system',	NULL,	NULL,	1,	'AVAILABLE')
	INSERT [dbo].[Utterance] ([VCC], [AppId], [IntentId], [Id], [Text], [CreatedDate], [CreatedByUserId], [LastModifiedDate],[LastModifiedByUserId], [Status],[StatusCode]) VALUES (N'system',N'system::sentiment-en',N'Negative',NEWID(),N'We can not solve it',GETUTCDATE(),'system',	NULL,	NULL,	1,	'AVAILABLE')
	INSERT [dbo].[Utterance] ([VCC], [AppId], [IntentId], [Id], [Text], [CreatedDate], [CreatedByUserId], [LastModifiedDate],[LastModifiedByUserId], [Status],[StatusCode]) VALUES (N'system',N'system::sentiment-en',N'Negative',NEWID(),N'there is nothing to do',GETUTCDATE(),'system',	NULL,	NULL,	1,	'AVAILABLE')
	INSERT [dbo].[Utterance] ([VCC], [AppId], [IntentId], [Id], [Text], [CreatedDate], [CreatedByUserId], [LastModifiedDate],[LastModifiedByUserId], [Status],[StatusCode]) VALUES (N'system',N'system::sentiment-en',N'Negative',NEWID(),N'Are you not understanding',GETUTCDATE(),'system',	NULL,	NULL,	1,	'AVAILABLE')
	INSERT [dbo].[Utterance] ([VCC], [AppId], [IntentId], [Id], [Text], [CreatedDate], [CreatedByUserId], [LastModifiedDate],[LastModifiedByUserId], [Status],[StatusCode]) VALUES (N'system',N'system::sentiment-en',N'Negative',NEWID(),N'I know what I am doing',GETUTCDATE(),'system',	NULL,	NULL,	1,	'AVAILABLE')
	INSERT [dbo].[Utterance] ([VCC], [AppId], [IntentId], [Id], [Text], [CreatedDate], [CreatedByUserId], [LastModifiedDate],[LastModifiedByUserId], [Status],[StatusCode]) VALUES (N'system',N'system::sentiment-en',N'Negative',NEWID(),N'I do not understand',GETUTCDATE(),'system',	NULL,	NULL,	1,	'AVAILABLE')
	INSERT [dbo].[Utterance] ([VCC], [AppId], [IntentId], [Id], [Text], [CreatedDate], [CreatedByUserId], [LastModifiedDate],[LastModifiedByUserId], [Status],[StatusCode]) VALUES (N'system',N'system::sentiment-en',N'Negative',NEWID(),N'I can not do it',GETUTCDATE(),'system',	NULL,	NULL,	1,	'AVAILABLE')
	INSERT [dbo].[Utterance] ([VCC], [AppId], [IntentId], [Id], [Text], [CreatedDate], [CreatedByUserId], [LastModifiedDate],[LastModifiedByUserId], [Status],[StatusCode]) VALUES (N'system',N'system::sentiment-en',N'Negative',NEWID(),N'I do not know',GETUTCDATE(),'system',	NULL,	NULL,	1,	'AVAILABLE')
	INSERT [dbo].[Utterance] ([VCC], [AppId], [IntentId], [Id], [Text], [CreatedDate], [CreatedByUserId], [LastModifiedDate],[LastModifiedByUserId], [Status],[StatusCode]) VALUES (N'system',N'system::sentiment-en',N'Negative',NEWID(),N'unfortunately',GETUTCDATE(),'system',	NULL,	NULL,	1,	'AVAILABLE')
	INSERT [dbo].[Utterance] ([VCC], [AppId], [IntentId], [Id], [Text], [CreatedDate], [CreatedByUserId], [LastModifiedDate],[LastModifiedByUserId], [Status],[StatusCode]) VALUES (N'system',N'system::sentiment-en',N'Negative',NEWID(),N'regrettably',GETUTCDATE(),'system',	NULL,	NULL,	1,	'AVAILABLE')
	INSERT [dbo].[Utterance] ([VCC], [AppId], [IntentId], [Id], [Text], [CreatedDate], [CreatedByUserId], [LastModifiedDate],[LastModifiedByUserId], [Status],[StatusCode]) VALUES (N'system',N'system::sentiment-en',N'Negative',NEWID(),N'lamentably',GETUTCDATE(),'system',	NULL,	NULL,	1,	'AVAILABLE')
	INSERT [dbo].[Utterance] ([VCC], [AppId], [IntentId], [Id], [Text], [CreatedDate], [CreatedByUserId], [LastModifiedDate],[LastModifiedByUserId], [Status],[StatusCode]) VALUES (N'system',N'system::sentiment-en',N'Negative',NEWID(),N'there is no way',GETUTCDATE(),'system',	NULL,	NULL,	1,	'AVAILABLE')
	INSERT [dbo].[Utterance] ([VCC], [AppId], [IntentId], [Id], [Text], [CreatedDate], [CreatedByUserId], [LastModifiedDate],[LastModifiedByUserId], [Status],[StatusCode]) VALUES (N'system',N'system::sentiment-en',N'Negative',NEWID(),N'I have limits',GETUTCDATE(),'system',	NULL,	NULL,	1,	'AVAILABLE')
	INSERT [dbo].[Utterance] ([VCC], [AppId], [IntentId], [Id], [Text], [CreatedDate], [CreatedByUserId], [LastModifiedDate],[LastModifiedByUserId], [Status],[StatusCode]) VALUES (N'system',N'system::sentiment-en',N'Negative',NEWID(),N'I am not allowed',GETUTCDATE(),'system',	NULL,	NULL,	1,	'AVAILABLE')
	INSERT [dbo].[Utterance] ([VCC], [AppId], [IntentId], [Id], [Text], [CreatedDate], [CreatedByUserId], [LastModifiedDate],[LastModifiedByUserId], [Status],[StatusCode]) VALUES (N'system',N'system::sentiment-en',N'Negative',NEWID(),N'It is terrible',GETUTCDATE(),'system',	NULL,	NULL,	1,	'AVAILABLE')
	INSERT [dbo].[Utterance] ([VCC], [AppId], [IntentId], [Id], [Text], [CreatedDate], [CreatedByUserId], [LastModifiedDate],[LastModifiedByUserId], [Status],[StatusCode]) VALUES (N'system',N'system::sentiment-en',N'Negative',NEWID(),N'There is no solution',GETUTCDATE(),'system',	NULL,	NULL,	1,	'AVAILABLE')
	INSERT [dbo].[Utterance] ([VCC], [AppId], [IntentId], [Id], [Text], [CreatedDate], [CreatedByUserId], [LastModifiedDate],[LastModifiedByUserId], [Status],[StatusCode]) VALUES (N'system',N'system::sentiment-en',N'Negative',NEWID(),N'It is incorrect',GETUTCDATE(),'system',	NULL,	NULL,	1,	'AVAILABLE')
	INSERT [dbo].[Utterance] ([VCC], [AppId], [IntentId], [Id], [Text], [CreatedDate], [CreatedByUserId], [LastModifiedDate],[LastModifiedByUserId], [Status],[StatusCode]) VALUES (N'system',N'system::sentiment-en',N'Negative',NEWID(),N'Listen to me',GETUTCDATE(),'system',	NULL,	NULL,	1,	'AVAILABLE')
	INSERT [dbo].[Utterance] ([VCC], [AppId], [IntentId], [Id], [Text], [CreatedDate], [CreatedByUserId], [LastModifiedDate],[LastModifiedByUserId], [Status],[StatusCode]) VALUES (N'system',N'system::sentiment-en',N'Negative',NEWID(),N'What',GETUTCDATE(),'system',	NULL,	NULL,	1,	'AVAILABLE')
	INSERT [dbo].[Utterance] ([VCC], [AppId], [IntentId], [Id], [Text], [CreatedDate], [CreatedByUserId], [LastModifiedDate],[LastModifiedByUserId], [Status],[StatusCode]) VALUES (N'system',N'system::sentiment-en',N'Negative',NEWID(),N'I am sorry to say',GETUTCDATE(),'system',	NULL,	NULL,	1,	'AVAILABLE')
	INSERT [dbo].[Utterance] ([VCC], [AppId], [IntentId], [Id], [Text], [CreatedDate], [CreatedByUserId], [LastModifiedDate],[LastModifiedByUserId], [Status],[StatusCode]) VALUES (N'system',N'system::sentiment-en',N'Negative',NEWID(),N'What can I do',GETUTCDATE(),'system',	NULL,	NULL,	1,	'AVAILABLE')
	INSERT [dbo].[Utterance] ([VCC], [AppId], [IntentId], [Id], [Text], [CreatedDate], [CreatedByUserId], [LastModifiedDate],[LastModifiedByUserId], [Status],[StatusCode]) VALUES (N'system',N'system::sentiment-en',N'Negative',NEWID(),N'It is out of my reach',GETUTCDATE(),'system',	NULL,	NULL,	1,	'AVAILABLE')
	INSERT [dbo].[Utterance] ([VCC], [AppId], [IntentId], [Id], [Text], [CreatedDate], [CreatedByUserId], [LastModifiedDate],[LastModifiedByUserId], [Status],[StatusCode]) VALUES (N'system',N'system::sentiment-en',N'Negative',NEWID(),N'I can not help you',GETUTCDATE(),'system',	NULL,	NULL,	1,	'AVAILABLE')



    DECLARE RECURRENT_CURSOR CURSOR 
    LOCAL STATIC READ_ONLY FORWARD_ONLY
    FOR 
    -- SELECCIONAMOS LOS VCC EXISTENTES
    SELECT [VCC]
        FROM [dbo].[VCC] (NOLOCK) WHERE VCC <> 'system'
	

    -- DECLARARAMOS UNA VARIABLE PARA INDICAR EL CAMPO ACTUAL QUE ESTAMOS ACTUALIZANDO
    DECLARE @CURRENT_VCC_TO_UPDATE VARCHAR(50) = ''

    -- ABRIMOS Y RECORREMOS EL ARRAY DE CAMPOS A ACTUALIZAR
    OPEN RECURRENT_CURSOR

    FETCH NEXT FROM RECURRENT_CURSOR INTO @CURRENT_VCC_TO_UPDATE
    WHILE @@FETCH_STATUS = 0
    BEGIN 

        -- EJECUTAMOS EL SCRIPT DE INSERT/UPDATE/DELETE PARA CADA VCC EN LA VARIABLE @CURRENT_VCC_TO_UPDATE`
		 -- MODELOS POR DEFECTO PARA ANALISIS DE SENTIMENTOS
        INSERT INTO [dbo].[NLU] (
					[VCC], 
					[Name], 
					[Culture],
					[Description], 
					[AppId],
					[NeedTrain], 
					[SubscriptionKey],
					[IsSystemApp], 
					[CreatedDate], 
					[CreatedByUserId], 
					[LastModifiedDate], 
					[LastModifiedByUserId], 
					[TimeStamp],
					[CognitiveEngine]
					)
					SELECT
					@CURRENT_VCC_TO_UPDATE,
					[Name], 
					[Culture],
					[Description], 
					CONCAT(@CURRENT_VCC_TO_UPDATE,'::',[Name]), 
					1,
					[SubscriptionKey],
					[IsSystemApp], 
					GETUTCDATE(), 
					[CreatedByUserId], 
					GETUTCDATE(), 
					[LastModifiedByUserId], 
					GETUTCDATE(),
					'RASA'
					FROM [dbo].[NLU]
					WHERE [IsSystemApp]=1 AND [VCC] = 'system' AND AppId LIKE '%::sentiment-%'
		
        -- INSERTAR INTENCIONES POR DEFECTOS PARA EL MODEL
        INSERT INTO [dbo].[Intent](
			[VCC], 
			[Name],
			[IntentId],
			[AppId],
			[Color],
			[CreatedDate],
			[CreatedByUserId],
			[LastModifiedDate], 
			[LastModifiedByUserId], 
			[TimeStamp],
			[Status],
			[StatusCode]
			)
			SELECT
			@CURRENT_VCC_TO_UPDATE,
			'Positive',
			'Positive',
			CONCAT(@CURRENT_VCC_TO_UPDATE,'::',[Name]),
			'far fa-smile',
			GETUTCDATE(),
			'admin',
			GETUTCDATE(),
			'admin',
			GETUTCDATE(),
			1,
			'AVAILABLE'
			FROM [dbo].[NLU]
					WHERE [IsSystemApp]=1 AND [VCC] = 'system' AND [Name] LIKE 'sentiment-%'

		   
		   	INSERT INTO [dbo].[Intent](
			[VCC], 
			[Name],
			[IntentId],
			[AppId],
			[Color],
			[CreatedDate],
			[CreatedByUserId],
			[LastModifiedDate], 
			[LastModifiedByUserId], 
			[TimeStamp],
			[Status],
			[StatusCode]
			)
			SELECT
			@CURRENT_VCC_TO_UPDATE,
			'Negative',
			'Negative',
			CONCAT(@CURRENT_VCC_TO_UPDATE,'::',[Name]),
			'far fa-frown',
			GETUTCDATE(),
			'admin',
			GETUTCDATE(),
			'admin',
			GETUTCDATE(),
			1,
			'AVAILABLE'
			FROM [dbo].[NLU]
					WHERE [IsSystemApp]=1 AND [VCC] = 'system' AND [Name] LIKE 'sentiment-%'

			INSERT INTO [dbo].[Intent](
			[VCC], 
			[Name],
			[IntentId],
			[AppId],
			[Color],
			[CreatedDate],
			[CreatedByUserId],
			[LastModifiedDate], 
			[LastModifiedByUserId], 
			[TimeStamp],
			[Status],
			[StatusCode]
			)
			SELECT
			@CURRENT_VCC_TO_UPDATE,
			'Neutral',
			'Neutral',
			CONCAT(@CURRENT_VCC_TO_UPDATE,'::',[Name]),
			'far fa-meh',
			GETUTCDATE(),
			'admin',
			GETUTCDATE(),
			'admin',
			GETUTCDATE(),
			1,
			'AVAILABLE'
			FROM [dbo].[NLU]
					WHERE [IsSystemApp]=1 AND [VCC] = 'system' AND [Name] LIKE 'sentiment-%'  

			INSERT INTO [dbo].[Utterance] ([VCC], [AppId], [IntentId], [Id], [Text], [CreatedDate], [CreatedByUserId], [LastModifiedDate],[LastModifiedByUserId], [Status],[StatusCode]) 
			SELECT @CURRENT_VCC_TO_UPDATE,REPLACE(appId,'system',@CURRENT_VCC_TO_UPDATE),[IntentId],NEWID(),[Text],GETUTCDATE(),'system',null,null,[Status],[StatusCode] FROM [dbo].[Utterance]
			WHERE [VCC] = 'system' AND AppId LIKE '%::sentiment-%'

           

        FETCH NEXT FROM RECURRENT_CURSOR INTO @CURRENT_VCC_TO_UPDATE
    END
    CLOSE RECURRENT_CURSOR
    DEALLOCATE RECURRENT_CURSOR

    -- AQUI TERMINA LA SECCION CON LOS INSERT/UPDATE/DELETE PARA LA NUEVA VERSION


    

    -- TERMINAMOS LA ACTUALIZACION DE DATA ACTUALIZANDO EL BUILDVERSION
    UPDATE [dbo].[Version] 
        SET [BuildVersion] = @NEW_DATABASE_BUILD_VERSION, 
            [IsRegistered] = 0,
            [TimeStamp] = GETUTCDATE() 
        WHERE [BuildVersion] = @OLD_DATABASE_BUILD_VERSION
    PRINT 'UPDATED_DATABASE_BUILD_VERSION'

    -- COMPLETAMOS LA TRANSACCION
    COMMIT TRANSACTION
END TRY
BEGIN CATCH
    IF @@TRANCOUNT > 0 ROLLBACK TRANSACTION

    DECLARE @Message nvarchar(2048) = ERROR_MESSAGE()
    DECLARE @Severity integer = ERROR_SEVERITY()
    DECLARE @State integer = ERROR_STATE()

    RAISERROR(@Message, @Severity, @State)
    --RETURN -1
END CATCH
