PRINT N'Modificando [dbo].[CreateVcc]...';


GO
ALTER PROCEDURE [dbo].[CreateVcc] (
	@VCC Varchar(50) = NULL, 
	@ID Varchar(50) = NULL,
	@Description Varchar(50) = NULL,
	@Type VARCHAR(50) = NULL,
	@TranscriptionDefaultLanguage VARCHAR(25) = NULL,
	@CognitiveEngine VARCHAR(25) = NULL,
	@Country Varchar(50) = NULL,
	@Language Varchar(50) = NULL,
	@TimeZone Varchar(50) = NULL,
	@CreatedDate Datetime = NULL,
	@CreatedByUserId Varchar(50) = NULL,
	@LastModifiedDate Datetime = NULL,
	@LastModifiedByUserId   VARCHAR(50) = NULL,
	@DeleteDataDays         INT = 360
	)
AS
BEGIN
	SET NOCOUNT ON
	BEGIN TRY
    BEGIN TRANSACTION


	INSERT INTO [dbo].[VCC] (
			[VCC], 
			[ID], 
			[Description], 
			[Type], 
			[Country], 
			[TranscriptionDefaultLanguage], 
			[CognitiveEngine], 
			[Language],
			[TimeZone], 
			[CreatedDate], 
			[CreatedByUserId], 
			[LastModifiedDate], 
			[LastModifiedByUserId], 
			[DeleteDataDays], 
			[TimeStamp]
			)
	VALUES (
			@VCC, 
			@ID, 
			@Description, 
			@Type, 
			@Country, 
			@TranscriptionDefaultLanguage, 
			@CognitiveEngine, 
			@Language, 
			@TimeZone, 
			@CreatedDate,  
			@CreatedByUserId, 
			@LastModifiedDate, 
			@LastModifiedByUserId, 
			@DeleteDataDays,
			GETUTCDATE()
		)
	
	DECLARE @VCC_SYSTEM       VARCHAR(50) = 'system'

    --INSERTAR ROLES
	
	DECLARE @ROLES TABLE(
    [ID]            VARCHAR(50),
    [Description]   VARCHAR(50),
	[CreatedDate]   DATETIME,
    [CreatedByUserId] VARCHAR(50),
    [LastModifiedDate] DATETIME,
    [LastModifiedByUserId] VARCHAR(50),
	[SystemRole]    BIT,
    [Type]                 VARCHAR(50)
	)
	INSERT INTO @ROLES EXEC [dbo].[GetRoles] @VCC_SYSTEM,'name',''

	IF(EXISTS(SELECT [ID] FROM @ROLES))
	BEGIN
			INSERT INTO [dbo].[Role] (
					[VCC],
					[ID], 
					[Description],
					[CreatedDate], 
					[CreatedByUserId], 
					[LastModifiedDate],
					[LastModifiedByUserId],
					[SystemRole],
					[Type],
					[TimeStamp]
					)
			SELECT @VCC,
				   [ID],
				   [Description],
				   GETUTCDATE(), 
				   [CreatedByUserId],
				   GETUTCDATE(),
				   [LastModifiedByUserId],
				   [SystemRole],
				   [Type],
				   GETUTCDATE()
			FROM @ROLES
     END
	 ELSE
	 BEGIN
	       RAISERROR('SERVER_ERROR_ROLES_NOT_FOUND', 16, 16)
	 END

	--INSERTAR PERMISOS PARA LOS ROLES

	DECLARE @CountLicense INT = 0
	DECLARE @License      VARCHAR(50)
	
	DECLARE @ROLE_PERMISSIONS TABLE(
	 [ID]      VARCHAR(50),
	 [GroupId] VARCHAR(200)
	)
	DECLARE @ROUTE_PERMISSIONS TABLE(
	 [ID]      VARCHAR(50),
	 [Route]   VARCHAR(250),
	 [Level]   VARCHAR(50),
	 [GroupId] VARCHAR(200)
	)

	SET @CountLicense = (SELECT COUNT(*) FROM [dbo].[VCCLicense] (NOLOCK) WHERE [VCC] = @VCC AND [Status] = 1)
	
	IF(@CountLicense>1)
	BEGIN
	    INSERT INTO @ROLE_PERMISSIONS EXEC [dbo].[GetRolePermission] @VCC_SYSTEM,''
		INSERT INTO @ROUTE_PERMISSIONS EXEC [dbo].[GetRoleRoutePermission] @VCC_SYSTEM
	END

	IF(@CountLicense=1)
	BEGIN
	    SET @License = (SELECT Product FROM [dbo].[VCCLicense] (NOLOCK) WHERE [VCC] = @VCC AND [Status] = 1)
	    INSERT INTO @ROLE_PERMISSIONS EXEC [dbo].[GetRolePermission] @VCC_SYSTEM,'', @License
		INSERT INTO @ROUTE_PERMISSIONS EXEC [dbo].[GetRoleRoutePermission] @VCC_SYSTEM,'', @License
	END
	
	INSERT INTO [dbo].[RolePermission] (
			    [VCC], 
				[RoleId], 
				[GroupId],
			    [TimeStamp]
			    ) 
				SELECT 
				@VCC,
				[ID],
				[GroupId],
			    GETUTCDATE()
				FROM @ROLE_PERMISSIONS

	INSERT INTO [dbo].[RoutePermission] (
			[VCC], 
			[ID], 
			[GroupId],
			[Route], 
			[Level], 
			[TimeStamp]
			)
			SELECT 
			@VCC,
			[ID],
			[GroupId],
			[Route],
			[Level],
			GETUTCDATE()
			FROM @ROUTE_PERMISSIONS


    --INSERTAR GRUPOS DE PERMISOS PARA LOS ROLES
	DECLARE @ROLE_PERMISSIONS_GROUP TABLE(
	 [Category] VARCHAR(50),
	 [GroupId]  VARCHAR(200),
	 [Type]     VARCHAR(50)
	)

	INSERT INTO @ROLE_PERMISSIONS_GROUP EXEC [dbo].[GetRolePermissionsGroups] @VCC_SYSTEM

	INSERT INTO [dbo].[RolePermissionsGroup] (
			                              [VCC], 
										  [GroupId], 
										  [Category], 
										  [Type], 
										  [TimeStamp]
										  )
		                                 SELECT 
										 @VCC, 
										 GroupId,
										 Category,
										 [Type], 
										 GETUTCDATE()	
										 FROM @ROLE_PERMISSIONS_GROUP

    --INSERTAR FEELINGS
	INSERT INTO [dbo].[Feeling] (
			                   [VCC], 
							   [Name], 
							   [Description],
							   [CreatedDate], 
							   [CreatedByUserId], 
							   [LastModifiedDate], 
							   [LastModifiedByUserId], 
							   [TimeStamp]
							   )
							   SELECT
							   @VCC,
							   [Name],
							   [Description],
							   GETUTCDATE(),
							   [CreatedByUserId],
							   GETUTCDATE(),
							   [LastModifiedByUserId],
							   GETUTCDATE()	
							   FROM [dbo].[Feeling] (NOLOCK)
							   WHERE [VCC] = @VCC_SYSTEM

    --INSERTAR PROGRAMACION NEUROLINGUISTICA
	INSERT INTO [dbo].[NeuroLinguisticProgramming] (
								[VCC],
								[Name],
								[Description],
								[CreatedDate],
								[CreatedByUserId],
								[LastModifiedDate], 
								[LastModifiedByUserId],
								[TimeStamp]
								)
								SELECT 
								@VCC,
								[Name],
								[Description],
								GETUTCDATE(),
								[CreatedByUserId],
								GETUTCDATE(),
								[LastModifiedByUserId],
								GETUTCDATE()
								FROM [dbo].[NeuroLinguisticProgramming] (NOLOCK)
								WHERE [VCC] = @VCC_SYSTEM
		
   --INSERTAR PALABRAS
   IF(EXISTS(SELECT [Name] FROM [dbo].[Word] (NOLOCK) WHERE [VCC] = @VCC_SYSTEM))
   BEGIN
		   INSERT INTO [dbo].[Word](
					[VCC],
					[NeuroLinguisticProgrammingId],
					[Name],
					[ProcessId],
					[Language],
					[Type],
					[CreatedDate],
					[CreatedByUserId],
					[LastModifiedDate],
					[LastModifiedByUserId],
					[TimeStamp]
					)
				SELECT
				@VCC,
				[NeuroLinguisticProgrammingId],
				[Name],
				[ProcessId],
				[Language],
				[Type],
				GETUTCDATE(),
				[CreatedByUserId],
				GETUTCDATE(),
				[LastModifiedByUserId],
				GETUTCDATE()
			   FROM [dbo].[Word] (NOLOCK)
			   WHERE [VCC] = @VCC_SYSTEM
   END
   ELSE
   BEGIN
	       RAISERROR('SERVER_ERROR_WORD_NOT_FOUND', 16, 16)
   END

   --INSERTAR CATEGORIAS
   INSERT INTO [dbo].[Category] (
			[VCC], 
			[Name], 
			[Description],
			[CreatedDate], 
			[CreatedByUserId], 
			[LastModifiedDate], 
			[LastModifiedByUserId], 
			[TimeStamp]
			)
		SELECT 
		@VCC,
		[Name],
		[Description],
		GETUTCDATE(),
		[CreatedByUserId],
		GETUTCDATE(),
		[LastModifiedByUserId],
		GETUTCDATE()
	FROM [dbo].[Category] (NOLOCK)
	WHERE [VCC] = @VCC_SYSTEM

	--INSERTAR AMBIENTES
	IF(@Type <> 'OTHER')
	BEGIN
		DECLARE @NAME VARCHAR(100)
		SELECT @NAME = [Word] FROM [dbo].[WordsByLanguage] (NOLOCK) WHERE [Language] = @Language AND [Label] = 'ENVIRONMENT' 
		
		-- DECLARAMOS UNA VARIABLE PARA SETTEAR EL TIPO DE AMBIENTE INTEGRADO PARA EL VCC
		DECLARE @VCC_TYPE VARCHAR(25) = NULL
		IF (@Type = 'ALLEGRO' OR @Type = 'OCC') SET @VCC_TYPE = 'allegro'
		ELSE IF @Type = 'I6' SET @VCC_TYPE = 'i6'
		
		INSERT INTO [dbo].[Environment] (
			[VCC], 
			[Name], 
			[Type],
			[Description],
			[FTPDirectory],
			[ApiHost],
			[ApiPort],
			[ApiUser],
			[DbDisabled],
			[DbServer],
			[DbPort],
			[DbUser], 
			[PbxDisabled],
			[PbxServer],
			[PbxPort],
			[PbxUser],
			[ApiPassword],
			[DbPassword],
			[PbxPassword],
			[CreatedDate],
			[CreatedByUserId],
			[TimeStamp]
		)
			SELECT @VCC,
					@NAME,
					[Type],
					@NAME,
					[FTPDirectory],
					[ApiHost],
					[ApiPort],
					[ApiUser],
					[DbDisabled],
					[DbServer],
					[DbPort],
					[DbUser],
					[PbxDisabled],
					[PbxServer]	,
					[PbxPort],
					[PbxUser],
					[ApiPassword],
					[DbPassword],
					[PbxPassword],
					GETUTCDATE(),
					[CreatedByUserId],
					GETUTCDATE()
				FROM [dbo].[Environment] (NOLOCK)
				WHERE [VCC] = @VCC_SYSTEM
					AND [Type] = @VCC_TYPE

	END


	--INSERTAR PERMISOS PARA CATEGORIAS
	INSERT INTO [dbo].[CategoryPermissions](
			[VCC], 
			[Category], 
			[Position], 
			[TimeStamp]
			)
			SELECT
			@VCC,
		    [Category],
			[Position],
			GETUTCDATE()
			FROM [dbo].[CategoryPermissions] (NOLOCK) 
			WHERE [VCC] = @VCC_SYSTEM
			GROUP BY [Category],[Position]
		  

   --INSERTAR TENANT
   DECLARE @TENANT TABLE(
    [TenantId]     VARCHAR(50),
    [ClientId]     VARCHAR(50),
    [ClientSecret] VARCHAR(50),
    [Resource]     VARCHAR(50)
	)
	
	INSERT INTO @TENANT EXEC [dbo].[GetTenantVCCByVCC] @VCC_SYSTEM
	IF(EXISTS(SELECT [TenantId] FROM @TENANT))
	BEGIN

		INSERT INTO [dbo].[TenantVCC](
		[VCC], 
		[TenantId], 
		[ClientId], 
		[ClientSecret], 
		[Resource], 
		[CreatedDate], 
		[CreatedByUserId], 
		[TimeStamp])
		SELECT 
		@VCC,
		[TenantId],
		[ClientId],
		[ClientSecret],
		[Resource],
		GETUTCDATE(),
		@CreatedByUserId,
		GETUTCDATE()
		FROM @TENANT

	END
	ELSE
	BEGIN
	   RAISERROR('SERVER_ERROR_TENANT_NOT_FOUND', 16, 16)
	END

	--INSERTAR NLU
	IF(EXISTS(SELECT [Name] FROM [dbo].[NLU] WHERE [IsSystemApp]=1 AND [VCC] = @VCC_SYSTEM))
	BEGIN
		INSERT INTO [dbo].[NLU] (
					[VCC], 
					[Name], 
					[Culture],
					[Description], 
					[AppId], 
					[SubscriptionKey],
					[IsSystemApp], 
					[CreatedDate], 
					[CreatedByUserId], 
					[LastModifiedDate], 
					[LastModifiedByUserId], 
					[TimeStamp],
					[CognitiveEngine]
					)
					SELECT
					@VCC,
					[Name], 
					[Culture],
					[Description], 
					CONCAT(@VCC,'::',[Name]), 
					[SubscriptionKey],
					[IsSystemApp], 
					GETUTCDATE(), 
					[CreatedByUserId], 
					GETUTCDATE(), 
					[LastModifiedByUserId], 
					GETUTCDATE(),
					'RASA'
					FROM [dbo].[NLU]
					WHERE [IsSystemApp]=1 AND [VCC] = @VCC_SYSTEM

		-- INSERTAMOS LOS REGISTROS DE MODELOS DE DIARIZACION
        INSERT INTO [dbo].[Intent](
			[VCC], 
			[Name],
			[IntentId],
			[AppId],
			[CreatedDate],
			[CreatedByUserId],
			[LastModifiedDate], 
			[LastModifiedByUserId], 
			[TimeStamp],
			[Status],
			[StatusCode]
		)
			SELECT @VCC,
					'Agent',
					'Agent',
					CONCAT(@VCC,'::',[Name]),
					GETUTCDATE(),
					@CreatedByUserId,
					GETUTCDATE(),
					@CreatedByUserId,
					GETUTCDATE(),
					1,
					'AVAILABLE'
			FROM [dbo].[NLU]
			WHERE [IsSystemApp]=1 
				AND [VCC] = @VCC_SYSTEM
				AND [Name] LIKE 'diarization-%'


		-- TODO: CORREGIR PARA REDUCIR 3 INSERT REEMPLAZANDO POR 1 SOLO --
		INSERT INTO [dbo].[Intent](
			[VCC], 
			[Name],
			[IntentId],
			[AppId],
			[Color],
			[CreatedDate],
			[CreatedByUserId],
			[LastModifiedDate], 
			[LastModifiedByUserId], 
			[TimeStamp],
			[Status],
			[StatusCode]
		)
			SELECT @VCC,
					'Positive',
					'Positive',
					CONCAT(@VCC,'::',[Name]),
					'far fa-smile',
					GETUTCDATE(),
					@CreatedByUserId,
					GETUTCDATE(),
					@CreatedByUserId,
					GETUTCDATE(),
					1,
					'AVAILABLE'
			FROM [dbo].[NLU]
			WHERE [IsSystemApp]=1 
				AND [VCC] = @VCC_SYSTEM 
				AND [Name] LIKE 'sentiment-%'
		 
		INSERT INTO [dbo].[Intent](
			[VCC], 
			[Name],
			[IntentId],
			[AppId],
			[Color],
			[CreatedDate],
			[CreatedByUserId],
			[LastModifiedDate], 
			[LastModifiedByUserId], 
			[TimeStamp],
			[Status],
			[StatusCode]
		)
			SELECT @VCC,
					'Negative',
					'Negative',
					CONCAT(@VCC,'::',[Name]),
					'far fa-frown',
					GETUTCDATE(),
					@CreatedByUserId,
					GETUTCDATE(),
					@CreatedByUserId,
					GETUTCDATE(),
					1,
					'AVAILABLE'
				FROM [dbo].[NLU]
				WHERE [IsSystemApp]=1 
					AND [VCC] = @VCC_SYSTEM 
					AND [Name] LIKE 'sentiment-%'
		
		 INSERT INTO [dbo].[Intent] (
			[VCC], 
			[Name],
			[IntentId],
			[AppId],
			[Color],
			[CreatedDate],
			[CreatedByUserId],
			[LastModifiedDate], 
			[LastModifiedByUserId], 
			[TimeStamp],
			[Status],
			[StatusCode]
		)
			SELECT @VCC,
					'Neutral',
					'Neutral',
					CONCAT(@VCC,'::',[Name]),
					'far fa-meh',
					GETUTCDATE(),
					@CreatedByUserId,
					GETUTCDATE(),
					@CreatedByUserId,
					GETUTCDATE(),
					1,
					'AVAILABLE'
				FROM [dbo].[NLU]
				WHERE [IsSystemApp]=1 
					AND [VCC] = @VCC_SYSTEM 
					AND [Name] LIKE 'sentiment-%'

		-- TODO: CORREGIR PARA REDUCIR 3 INSERT REEMPLAZANDO POR 1 SOLO --
	END
	ELSE
	BEGIN
	   RAISERROR('SERVER_ERROR_SYSTEM_APPS_SAVING_FAILED', 16, 16)
	END

	--INSERTAR DICCIONARIOS
	IF(EXISTS(SELECT [Name] FROM [dbo].[Dictionary] (NOLOCK) WHERE [VCC] = @VCC_SYSTEM))
	BEGIN 
	INSERT INTO [dbo].[Dictionary] (
			[VCC], 
			[Name], 
			[Description], 
			[Language], 
			[IsSystemDictionary], 
			[CreatedDate], 
			[CreatedByUserId], 
			[TimeStamp]
		)
		SELECT
		    @VCC,
		    [Name],
			[Description],
			[Language],
			[IsSystemDictionary],
			GETUTCDATE(),
			[CreatedByUserId],
			GETUTCDATE()
		FROM [dbo].[Dictionary] (NOLOCK)
		WHERE [VCC] = @VCC_SYSTEM
	END
	ELSE
	BEGIN
	    RAISERROR('SERVER_ERROR_SYSTEM_DICTIONARIES_SAVING_FAILED',16,16)
	END

	--INSERTAR TIPOS DE INTERACCIONES
	IF(EXISTS(SELECT [ID] FROM [dbo].[InteractionType] WHERE [Instance] = @VCC_SYSTEM ))
	BEGIN
	INSERT INTO [dbo].[InteractionType] (
			[Instance],
			[ID],
			[Description]
			)
			SELECT
			@VCC,
			[ID],
		    [Description]
			FROM InteractionType  (NOLOCK)
			WHERE [Instance] = @VCC_SYSTEM
	END
	ELSE
	BEGIN
	   RAISERROR('SERVER_ERROR_INTERACTION_TYPE_NOT_FOUND',16,16) 
	END

	--INSERTAR GENERIC QUERY
	IF(EXISTS(SELECT [Name] FROM [dbo].[GenericQuery] (NOLOCK) WHERE [VCC] = @VCC_SYSTEM))
	BEGIN
	INSERT INTO [dbo].[GenericQuery]
		(
			[VCC],
			[Name],
			[Description],
			[Query],
			[RawData],
			[CreatedDate],
			[CreatedByUserId],
			[LastModifiedDate], 
			[LastModifiedByUserId],
			[Version],
			[TimeStamp]
		)
		SELECT
		@VCC,
		[Name],--REPLACE([Name], @Language+'_', ''),
		[Description],
		[Query],
		[RawData],
		GETUTCDATE(),
		[CreatedByUserId],
		GETUTCDATE(),
		[LastModifiedByUserId],
		[Version],
		GETUTCDATE()
		FROM [dbo].[GenericQuery] (NOLOCK)
		WHERE [VCC] = @VCC_SYSTEM --AND [Name] LIKE @Language + '%'
	END
	ELSE
	BEGIN
	   RAISERROR('SERVER_ERROR_GENERIC_QUERY_NOT_FOUND',16,16) 
	END

	--INSERTAR  USUARIO AUDITOR SPEECH
	EXEC [dbo].[SaveSpeechAnalyticAuditorUser] @VCC

	--INSERTAR REPORTES
	IF(EXISTS(SELECT [ID] FROM  [dbo].[Report] (NOLOCK) WHERE [VCC] = @VCC_SYSTEM))
	BEGIN
	INSERT INTO [Report] (
			[VCC], 
			[ID], 
			[Description],
			[Type],
            [Procedure], 
			[StartDate],
			[EndDate],
            [Frecuency],
			[HourSpace],
			[ExactTime],
            [Weekday],
			[DayMonth],
			[Summary],
            [Filter], 
			[Email], 
			[CreatedDate],
            [CreatedByUserId],
			[LastModifiedDate],
			[LastModifiedByUserId],
            [TimeStamp]
        )
		SELECT
		        @VCC,
				[ID],
				[Description],
				[Type],
				[Procedure],
				[StartDate],
				[EndDate],
				[Frecuency],
				[HourSpace],
				[ExactTime],
				[Weekday],
				[DayMonth],
				[Summary],
				[Filter],
				[Email],
				GETUTCDATE(),
				@CreatedByUserId,
				GETUTCDATE(),
				@CreatedByUserId,
				GETUTCDATE()
			FROM [dbo].[Report] (NOLOCK)
			WHERE [VCC] = @VCC_SYSTEM

	END
	ELSE
	BEGIN
	   RAISERROR('SERVER_ERROR_REPORT_NOT_FOUND',16,16) 
	END

		-- INSERTAMOS LOS GRUPOS POR DEFECTO PARA COPC
		INSERT INTO [dbo].[Group] ([Instance], [ID], [Description], [CreatedDate], [CreatedByUserId], [TimeStamp], [Enabled])
			SELECT @VCC,
					G.[Description],
					WBL.[Word],
					GETUTCDATE(),
					'system',
					GETUTCDATE(),
					1
				FROM [dbo].[Group] G (NOLOCK)
				INNER JOIN [dbo].[WordsByLanguage] WBL (NOLOCK)
					ON WBL.[Label] = G.[Description]
				WHERE G.[Instance] = @VCC_SYSTEM
					AND WBL.[Language] = @Language

		-- INSERTAMOS LOS SUBGRUPOS POR DEFECTO PARA COPC
		INSERT INTO [dbo].[SubGroup] ([Instance], [ID], [Description], [CreatedDate], [CreatedByUserId], [TimeStamp], [Enabled])
			SELECT @VCC,
					SG.[Description],
					WBL.[Word],
					GETUTCDATE(),
					'system',
					GETUTCDATE(),
					1
				FROM [dbo].[SubGroup] SG (NOLOCK)
				INNER JOIN [dbo].[WordsByLanguage] WBL (NOLOCK)
					ON WBL.[Label] = SG.[Description]
				WHERE SG.[Instance] = @VCC_SYSTEM
					AND WBL.[Language] = @Language

	COMMIT TRANSACTION

    END TRY

    BEGIN CATCH

    IF @@TRANCOUNT > 0 
	BEGIN
		ROLLBACK TRANSACTION
		--ELIMINAR LOS REGISTROS SI HA FALLADO
		EXEC [dbo].[RollbackVcc] @VCC
	END

    DECLARE @Message nvarchar(2048) = ERROR_MESSAGE()
    DECLARE @Severity integer = ERROR_SEVERITY()
    DECLARE @State integer = ERROR_STATE()

    RAISERROR(@Message, @Severity, @State)
  
    END CATCH
    SET NOCOUNT OFF
END
GO
PRINT N'Modificando [dbo].[DeleteEvaluationFormatContent]...';


GO

ALTER PROCEDURE [dbo].[DeleteEvaluationFormatContent] (
	@VCC VARCHAR(50) = NULL,
	@EvaluationFormatId VARCHAR(50) = NULL,
	@TemplateId VARCHAR(50) = NULL
)
AS
BEGIN
	SET NOCOUNT ON

	-- INICIAMOS UN TRY PARA EL CASO CAIGA EN CATCH HAGAMOS ROLLBACK
    BEGIN TRY

		-- INICIAMOS LA TRANSACCION
		BEGIN TRANSACTION
			-- VERIFICAMOS SI TIENE CONTENIDO EL NOMBRE DE FORMATO
			IF @TemplateId IS NOT NULL AND @TemplateId <> ''
			BEGIN
				-- ELIMINAMOS EL TEMPLATE (SP DeleteTemplate)
				EXEC [dbo].[DeleteTemplate] @VCC, @TemplateId
			END

			-- ELIMINAMOS LAS CAMPAIGNS (REEMPLAZA SP DeleteCampainEvaluationFormat)
			DELETE [dbo].[CampaignEvaluationFormat]
				WHERE [Instance] = @VCC
					AND [IdEvaluationFormat] = @EvaluationFormatId
			
			-- ELIMINAMOS LOS ABILITYEVALUATIONFORMAT (REEMPLAZA SP DeleteAbilityEvaluationFormat)
			DELETE [AbilityEvaluationFormat] 
				WHERE [Instance] = @VCC
					AND [IdEvaluationFormat] = @EvaluationFormatId

			-- ELIMINAMOS LOS SCORETIPIFICATION
			DELETE [dbo].[EvaluationFormatAbilityScoreTipification]
				WHERE [VCC] = @VCC 
					AND [EvaluationFormatId] = @EvaluationFormatId

			-- ELIMINAMOS LOS SCORETIPIFICATIONITEM
			DELETE [dbo].[EvaluationFormatAbilityScoreTipificationItem]
				WHERE [VCC] = @VCC 
					AND [EvaluationFormatId] = @EvaluationFormatId

			-- ELIMINAMOS LOS SCORETIPIFICATIONQUERY
			DELETE [dbo].[EvaluationFormatAbilityScoreTipificationQuery]
				WHERE [VCC] = @VCC 
					AND [EvaluationFormatId] = @EvaluationFormatId

			-- ELIMINAMOS LOS CAMPOS PERSONALIZADOS DEL FORMATO (REEMPLAZA SP DeleteEvaluationFormatCustomFields)
			DELETE FROM [dbo].[EvaluationFormatCustomField] 
				WHERE [VCC] = @VCC 
					AND [EvaluationFormatId] = @EvaluationFormatId

			-- ELIMINAMOS LAS FIRMAS ADJUNTAS DEL FORMATO (REEMPLAZA SP DeleteEvaluationFormatAttachedSignatures)
			DELETE FROM [dbo].[EvaluationFormatAttachedSignature] 
				WHERE [VCC] = @VCC 
					AND [EvaluationFormatId] = @EvaluationFormatId
    
			SELECT 1 AS 'result'

		-- COMPLETAMOS LA TRANSACCION
		COMMIT TRANSACTION

    END TRY
    BEGIN CATCH
        IF @@TRANCOUNT > 0 ROLLBACK TRANSACTION

        DECLARE @Message nvarchar(2048) = ERROR_MESSAGE()
        DECLARE @Severity integer = ERROR_SEVERITY()
        DECLARE @State integer = ERROR_STATE()

        RAISERROR(@Message, @Severity, @State)
        RETURN -1
    END CATCH
    

    SELECT 1 AS 'result'

    SET NOCOUNT OFF
END
GO
PRINT N'Modificando [dbo].[GetEvaluationResultsFromAuditorEvaluationPlan]...';


GO

ALTER PROCEDURE [dbo].[GetEvaluationResultsFromAuditorEvaluationPlan] (
	@Instance Varchar(50) = NULL,
    @EvaluationPlanId Varchar(50) = NULL,
    @InteractionId varchar(250) = NULL,
    @InteractionType varchar(50) = NULL,
    @AuditorId varchar(50) = NULL,
    @AgentId varchar(50) = NULL
)
AS
BEGIN
    SET NOCOUNT ON
	-- TODO: ESTE SP ES USADO PARA GENERAR EL PDF DE EXPORTACION, HAY QUE INTEGRARLO CON LA FUNCIONALIDAD FACTORIZADA Y DESAPARECER ESTE SP

	-- EMULAMOS UNA NUEVA TABLA VARIABLE PARA OBTENER LOS REGISTROS UNICOS QUE INSERTAREMOS EN LA TABLA EVALUATION_RESULT
	--  ORDENANDO POR SECTION Y PART Y OBTENER EL NOMBRE DEL AGENTE
	;WITH CTE AS (
		SELECT TOP 1 IEP.[Instance],
						IEP.[IdEvaluationPlan],
						IEP.[IdInteraction],
						IEP.[IdAgent],
						IEP.[AgentName]
			FROM [dbo].[InteractionEvaluationPlan] IEP (NOLOCK)
			WHERE IEP.[Instance] = @Instance
				AND IEP.[IdEvaluationPlan] = @EvaluationPlanId
				AND IEP.[IdInteraction] = @InteractionId 
				AND IEP.[InteractionType] = @InteractionType
				AND IEP.[IdAgent] = @AgentId
	)

    SELECT DISTINCT
         EF.Id										'EvaluationFormatId'				-- Id
        ,EF.Description								'EvaluationFormatDescription'		-- Titulo del reporte
        ,ER.Instance								'Instance'							-- Subtitulo del reporte
        ,ER.IdAgent									'AgentId'							-- Agente
        ,ER.IdAgent									'AgentDescription'					-- Agente
		,C.[AgentName]								'agentName'							-- NOMBRE DEL AGENTE
        ,CONCAT(U.Firstname, ' ', U.Lastname)		'CoordinatorFullName'				-- Coordinador
        ,AEP.IdAuditor								'AuditorId'							-- Auditor
        ,CONCAT(UA.Firstname, ' ',UA.Lastname)		'AuditorDescription'				-- Auditor
		,AEP.IdAuditor
        ,ER.IdCampaign								'CampaignDescription'				-- Campana
        ,ER.IdInteraction							'InteractionId'						-- Grabacion
        ,ER.InteractionType							'InteractionType'					-- Tipo interaccion
        ,ER.InteractionDateini						'InteractionDateIni'				-- Fecha inicio de la interaccion
		,ER.[InteractionDatefin]					'InteractionDateFin'				-- Fecha fin de la interaccion
        ,ER.InteractionAddress						'Contacto'							-- Telefono
        ,ER.EvaluationDate							'EvaluationDate'					-- Fecha monitoreo
        ,AEP.Score									'TotalScore'						-- Puntaje total
        ,G.Id										'GroupId'							-- Grupo
        ,G.Description								'Group'								-- Grupo
        ,SG.Id										'SubGroupId'						-- Subgrupo
        ,SG.Description								'SubGroup'							-- Subgrupo
        ,AB.Id										'idAbility'							-- Habilidad
		,AB.Id										'AbilityId'							-- Habilidad
        ,AB.Title									'Ability'							-- Habilidad
		,AB.[Detail]								'AbilityDetail'						-- Habilidad
        ,ER.[Comment]								'Observacion'						-- Observacion de la habilidad
        ,ER.MaxAbilityScore							'Puntaje'							-- Puntaje
        ,ER.ScoreDescription						'Eval'								-- Eval
        ,ER.Qualification							'Nota'								-- Nota
		,ER.[OwnScore]								'ownScore'
		,ER.[InheritedScore]						'inheritedScore'
		,ER.[AbilityInnerScore]						'abilityInnerScore'
        ,ER.NotApplies								'NotApplies'
		,AB.[Distribute]							'distribute'
        ,ER.AbilityOrder							'Order'
        ,ER.Conditional                             'conditionalSelected'
    FROM [dbo].[EvaluationResult] ER (NOLOCK)
    INNER JOIN [dbo].[EvaluationPlan] EP (NOLOCK) 
         ON (EP.[Instance] = ER.[Instance]
			AND EP.ID = ER.IdEvaluationPlan)
	INNER JOIN	[dbo].[HistoricEvaluationFormat] EF (NOLOCK)
	--LEFT JOIN [EvaluationFormat] EF (NOLOCK)
		ON (ER.Instance = EF.VCC AND EP.ID = EF.EvaluationPlanId
			AND	ER.IdEvaluationFormat = EF.ID)
	LEFT JOIN [dbo].[User] U (NOLOCK)
		ON (EP.Instance = U.VCC
			AND EP.CreatedByUserId = U.ID)
    --INNER JOIN [User] UA (NOLOCK)
	LEFT JOIN [dbo].[User] UA (NOLOCK)
		ON (ER.Instance = UA.VCC 
			AND ER.IdEvaluator = UA.ID)
    --INNER JOIN [AuditorEvaluationPlan] AEP (NOLOCK)
	LEFT JOIN [dbo].[AuditorEvaluationPlan] AEP (NOLOCK)
		ON (ER.IdEvaluationPlan	= AEP.IdEvaluationPlan
			AND ER.IdEvaluator = AEP.IdAuditor
			AND ER.IdInteraction = AEP.IdInteraction
			AND ER.InteractionType = AEP.InteractionType
			AND ER.IdAgent = AEP.IdAgent)
    LEFT JOIN [dbo].[HistoricGroup] G (NOLOCK)
		ON (ER.Instance = G.VCC AND EP.ID = G.EvaluationPlanId
			AND ER.IdGroup = G.ID)
    LEFT JOIN [HistoricSubGroup] SG (NOLOCK)
		ON (ER.Instance = SG.VCC AND EP.ID = SG.EvaluationPlanId
			AND ER.IdSubGroup = SG.ID)
    LEFT JOIN [HistoricAbility] AB (NOLOCK)
		ON (ER.Instance = AB.VCC AND EP.ID = AB.EvaluationPlanId
			AND ER.IdAbility = AB.ID)
	LEFT JOIN CTE C (NOLOCK) -- LA TABLA AGENT NO ES DETERMINANTE POR ESO SE AGREGA POR LEFT JOIN
		ON C.[Instance] = ER.[Instance]
			AND C.[IdInteraction] = ER.IdInteraction
			AND C.[IdAgent] = ER.[IdAgent]
    WHERE ER.Instance = @Instance
		AND ER.IdEvaluationPlan	= @EvaluationPlanId
		AND ER.IdInteraction = @InteractionId
		AND ER.InteractionType = @InteractionType
		--AND ER.IdEvaluator = @AuditorId
		AND ER.[IdAuditor] = @AuditorId
		AND ER.IdAgent = @AgentId
		AND AEP.[StatusDescription] NOT IN ('INVALID')
    ORDER BY ER.AbilityOrder ASC

	-- BUSCAMOS LOS RESULTADOS DE LAS TIPIFICACIONES DE 1ER NIVEL
	SELECT ET.[AbilityId]							'abilityId',
			ET.[ScoreId]							'scoreId',
			ET.[ID]									'id',
			HEFAST.[Description]					'tipificationDescription',
			ET.[IsChecked]							'isChecked'
		FROM [dbo].[EvaluationTipification] ET (NOLOCK)
		INNER JOIN [dbo].[HistoricEvaluationFormatAbilityScoreTipification] HEFAST (NOLOCK)
			ON HEFAST.[VCC] = ET.[VCC]
				AND HEFAST.[EvaluationPlanId] = ET.[EvaluationPlanId]
				AND HEFAST.[ScoreId] = ET.[ScoreId]
				AND HEFAST.[ID] = ET.[ID]
		WHERE ET.[VCC] = @Instance 
			AND ET.[EvaluationPlanId] = @EvaluationPlanId
			AND ET.[InteractionId] = @InteractionId
			AND ET.[AuditorId] = @AuditorId
			AND ET.[IsChecked] = 1
		ORDER BY HEFAST.[Order] ASC

	-- BUSCAMOS LOS RESULTADOS DE LAS TIPIFICACIONES DE 2DO Y 3ER NIVEL
	SELECT ETI.[ScoreId]								'scoreId',
			ETI.[TipificationId]						'tipificationId',
			HEFASTI.[SecondLevelItemId]					'secondLevelItemId',
			ETI.[ID]									'id',
			HEFASTI.[Description]						'tipificationItemDescription',
			ETI.[IsChecked]								'isChecked' 
		FROM [dbo].[EvaluationTipificationItem] ETI (NOLOCK)
		INNER JOIN [dbo].[HistoricEvaluationFormatAbilityScoreTipificationItem] HEFASTI (NOLOCK)
			ON HEFASTI.[VCC] = ETI.[VCC]
				AND HEFASTI.[EvaluationPlanId] = ETI.[EvaluationPlanId]
				AND HEFASTI.[ScoreId] = ETI.[ScoreId]
				AND HEFASTI.[ID] = ETI.[ID]
		WHERE ETI.[VCC] = @Instance 
			AND ETI.[EvaluationPlanId] = @EvaluationPlanId
			AND ETI.[InteractionId] = @InteractionId
			AND ETI.[AuditorId] = @AuditorId
			AND ETI.[IsChecked] = 1
		ORDER BY HEFASTI.[Order] ASC

    SET NOCOUNT OFF
END
GO
PRINT N'Modificando [dbo].[GetEvaluations]...';


GO
ALTER PROCEDURE [dbo].[GetEvaluations] (
	@Instance Varchar(50) = NULL,
	@IdAuditor VARCHAR(MAX) = NULL,
	@IdAgent Varchar(MAX) = NULL,
   	@IdCampaign VARCHAR(MAX) = NULL,
	@IdEvaluationPlan VARCHAR(MAX) = NULL,
 	@EvaluationDateFrom VARCHAR(50) = '1980-01-01T00:00:00',
    @EvaluationDateTo VARCHAR(50) = '2050-01-01T23:59:59',
	@EvaluationHourFrom VARCHAR(50) = '00:00:00',
    @EvaluationHourTo VARCHAR(50) = '23:59:59',
	@InteractionMinDuration Int = 0,
    @InteractionMaxDuration Int = 86400,
    @InteractionOrigins Varchar(50) = NULL,
	@InteractionResults Varchar(MAX) = NULL,
	@EvaluationTypes Varchar(MAX) = NULL,
	@InteractionTags Varchar(MAX) = NULL,
	@InteractionFormats Varchar(50) = NULL,
	@InteractionCoached VARCHAR(50) = NULL,
	@InteractionIds     VARCHAR(MAX) = NULL,
	@EvaluationsLimit Int = 0,
	@ContactAddress Varchar(300) = NULL,
	@SentimentIds varchar(max) = NULL
)
AS
BEGIN
	SET NOCOUNT ON
	--RESULTADOS DE ANALYSIS DE SENTIMIENTOS	
	CREATE TABLE #SentimentAnalysisResult
   (
   VCC VARCHAR(50),
   InteractionId VARCHAR(250),
   InteractionSection NUMERIC(5,0),
   InteractionPart NUMERIC(5,0), 
   SentimentId VARCHAR(50),
   EvaluationPlanId VARCHAR(50),
   MaxScore NUMERIC(10,5)
   )
	;WITH SentimentInteractionTemp AS(
	SELECT VCC,InteractionId,InteractionSection, InteractionPart,InteractionInterval,max(Score) as MaxScore 
	FROM SentimentAnalysisResult 
	GROUP BY VCC,InteractionId,InteractionSection, InteractionPart, InteractionInterval, AnalysisType),
	SentimentAnalysisSummary as(
	SELECT SAR.VCC,SAR.InteractionId,SAR.InteractionSection,SAR.InteractionPart,SAR.SentimentId,IEP.IdEvaluationPlan, MaxScore 
	FROM SentimentInteractionTemp SIT
	INNER JOIN SentimentAnalysisResult SAR ON 
	SIT.VCC = SAR.VCC AND
	SIT.InteractionId = SAR.InteractionId AND
	SIT.InteractionSection = SAR.InteractionSection AND
	SIT.InteractionPart = SAR.InteractionPart AND
	SIT.InteractionInterval = SAR.InteractionInterval AND	
	SIT.MaxScore = SAR.Score AND
	SAR.AnalysisType = CASE WHEN @InteractionOrigins = NULL OR @InteractionOrigins ='' OR @InteractionOrigins ='IN,OUT' THEN 'general'
							WHEN @InteractionOrigins = 'OUT' THEN 'agent'
							WHEN @InteractionOrigins = 'IN' THEN 'client'  END

	INNER JOIN InteractionEvaluationPlan IEP ON 
	SIT.VCC = IEP.Instance AND
	SIT.InteractionId = IEP.IdInteraction AND	
	SIT.InteractionSection = IEP.InteractionSection AND
	SIT.InteractionPart = IEP.InteractionPart AND
	IEP.Instance = @Instance 	
	)
	INSERT INTO  #SentimentAnalysisResult
	SELECT * FROM SentimentAnalysisSummary
	--FIN ANALISIS DE SENTIMIENTOS

	IF (@EvaluationHourFrom = '') SET @EvaluationHourFrom = '00:00:00';
	IF (@EvaluationHourTo = '') SET @EvaluationHourTo = '23:59:59';
	
	-- SI ORIGINS TIENE DOS VALORES, IGNORAMOS EL FILTRO
	IF (SELECT COUNT(*) FROM [dbo].[split](@InteractionOrigins, ',')) = 2 SET @InteractionOrigins = ''
	
	DECLARE @SQL_SELECT_1 VARCHAR(MAX) = ''
	DECLARE @SQL_FROM VARCHAR(MAX) = ''
	DECLARE @SQL_FILTER VARCHAR(MAX) = ''
	DECLARE @SQL_EXTRA VARCHAR(MAX) = ''
	DECLARE @FILTERS_OPTIONAL_PART VARCHAR(MAX) = ''
    DECLARE @FILTERS_EXCLUDING_PART VARCHAR(MAX) = ''
    DECLARE @FILTERS_FIXED_PART     VARCHAR(MAX) = ''

	-- EMULAMOS UNA NUEVA TABLA EN BASE A INTERACTIONEVALUATIONPLAN
	SET @SQL_SELECT_1 += '
		;WITH CTE AS (
			SELECT ER.[Instance],
					ER.[IdEvaluationPlan],
					ER.[IdInteraction], 
					ER.[IdAgent],
					IEP.[AgentName],
					SAR.[SentimentId],
					RN = ROW_NUMBER() OVER(PARTITION BY IEP.[Instance], IEP.[IdEvaluationPlan], IEP.[IdInteraction] ORDER BY IEP.[CreatedDate] ASC)
				FROM [dbo].[EvaluationResult] ER (NOLOCK) 
				INNER JOIN [dbo].[EvaluationPlan] EP (NOLOCK)
					ON EP.[Instance] = ER.[Instance]
						AND EP.[Id] =  ER.[IdEvaluationPlan]
				INNER JOIN [dbo].[AuditorEvaluationPlan] AEP (NOLOCK) 
					ON (AEP.[Instance] = ER.[Instance] 
						AND AEP.[IdAuditor] = ER.[IdAuditor] 
						AND AEP.[IdInteraction] = ER.[IdInteraction] 
						AND AEP.[InteractionType] = ER.[InteractionType] 
						AND AEP.[IdEvaluationPlan] = ER.[IdEvaluationPlan]) 
				INNER JOIN [dbo].[InteractionEvaluationPlan] IEP (NOLOCK)
					ON IEP.[Instance] = ER.[Instance] 
						AND IEP.[IdEvaluationPlan] = EP.[ID]
						AND IEP.[IdInteraction] = ER.[IdInteraction]
						AND IEP.[IdAgent] = ER.[IdAgent]
				LEFT JOIN #SentimentAnalysisResult SAR
				ON IEP.[Instance] = SAR.[VCC] 
						AND IEP.[IdEvaluationPlan] = SAR.[EvaluationPlanId]
						AND IEP.[IdInteraction] = SAR.[InteractionId]
						AND IEP.[InteractionSection] = SAR.[InteractionSection]
						AND IEP.[InteractionPart] = SAR.[InteractionPart]
				WHERE ER.[Instance] = ''' + @Instance + '''
					AND ER.[EvaluationDate] BETWEEN ''' + @EvaluationDateFrom + '''AND ''' + @EvaluationDateTo + '''
					AND EP.[Status] = CASE EP.[Evaluation_Mode] WHEN ''A'' THEN 7 ELSE EP.[Status] END 
					AND AEP.[Completed] = 1
		),
		SUMMARIZED_CTE AS (
			SELECT [Instance],
					[IdEvaluationPlan],
					[IdInteraction], 
					[IdAgent],
					[AgentName],
					[SentimentId]
				FROM CTE
				WHERE RN = 1
		) '

	SET @SQL_SELECT_1 += '
		SELECT '

	SET @SQL_SELECT_1 += '
				AEP.Completed						''completed'',
				AEP.[StatusDescription]             ''statusDescription'',
				A.[ErrorMessage]                    ''errorMessage'',
    			AEP.score							''qualification'',
    			AEP.IdAuditor						''idAuditor'',
    			U.FirstName + '' '' + U.LastName	''auditorName'',
    			MAX(ER.EvaluationDate)				''evaluationDate'',
    			AEP.IdEvaluationPlan				''idEvaluationPlan'',
				EP.Description						''evaluationPlan'',
				EP.[Evaluation_Mode]				''evaluationType'',
    			AEP.idAgent							''idAgent'',
    			C.[AgentName]						''agentName'',							-- NOMBRE DEL AGENTE
				AEP.idInteraction					''idInteraction'',
				AEP.InteractionDate					''interactionDate'',
    			AEP.InteractionType					''interactionType'',
    			AEP.IdCampaign						''idCampaign'',
				E.[Type]							''environmentType'',
				IIF (
					ERV.[InteractionId] IS NULL,
					CAST(0 AS BIT),
					CAST(1 AS BIT)
				)									''review'',
				COUNT(ERC.[Id])						''commitments'',
				C.SentimentId						''sentimentResult '' '

	SET @SQL_FROM += '
			FROM EvaluationResult ER (NOLOCK) 
			INNER JOIN SUMMARIZED_CTE C (NOLOCK) 
				ON C.[Instance] = ER.[Instance]
					AND C.[IdEvaluationPlan] = ER.[IdEvaluationPlan]
					AND C.[IdInteraction] = ER.[IdInteraction] 
					AND C.[IdAgent] = ER.[IdAgent] 
			INNER JOIN [EvaluationPlan] EP (NOLOCK) 
				ON (EP.[Instance] = ER.[Instance] 
					AND EP.[ID] = ER.IdEvaluationPlan) 
			LEFT JOIN [AuditorEvaluationPlan] AEP (NOLOCK) 
				ON (AEP.[Instance] = ER.[Instance] 
					AND AEP.[IdAuditor] = ER.[IdAuditor] 
					AND AEP.[IdInteraction] = ER.[IdInteraction] 
					AND AEP.[InteractionType] = ER.[InteractionType] 
					AND AEP.[IdEvaluationPlan] = ER.[IdEvaluationPlan]) 
			LEFT JOIN [dbo].[EvaluationReview] ERV (NOLOCK)
				ON ERV.[VCC] = AEP.[Instance]
					AND ERV.[EvaluationPlanId] = AEP.[IdEvaluationPlan]
					AND ERV.[InteractionId] = AEP.[IdInteraction]
			LEFT JOIN [dbo].[EvaluationReviewCommitment] ERC (NOLOCK)
				ON ERC.[VCC] = AEP.[Instance] 
					AND ERC.[EvaluationPlanId] = AEP.[IdEvaluationPlan]
					AND ERC.[InteractionId] = AEP.[IdInteraction]
					-- AND ERC.[SupervisorId] = AEP.[IdAuditor] 
					AND ERC.[AgentId] = AEP.[idAgent]
			LEFT JOIN [dbo].[Audio] A (NOLOCK)
			    ON A.[VCC] = AEP.[Instance]
			        AND A.[ID] = AEP.[IdInteraction]			
			LEFT JOIN [dbo].[Environment] E (NOLOCK)
				ON E.[VCC] = ER.[Instance]
					AND E.[Name] = EP.[EnvironmentId]
			LEFT JOIN [User] U (NOLOCK) 
				ON (U.[VCC] = ER.[Instance] 
					AND U.ID = AEP.IdAuditor) '

	SET @FILTERS_FIXED_PART = '
			WHERE ER.[Instance] = ''' + @Instance + '''
				AND ER.[EvaluationDate] >= ''' + @EvaluationDateFrom + '''
				AND ER.[EvaluationDate] <= ''' + @EvaluationDateTo + '''
				AND EP.[Status] = CASE EP.[Evaluation_Mode] WHEN ''A'' THEN 7 ELSE EP.[Status] END 
				AND AEP.[Completed] = 1 ' -- LINEA PARA FILTRAR EVALUACIONES COMPLETADAS

	IF (@IdAuditor IS NOT NULL AND @IdAuditor != '') SET @FILTERS_OPTIONAL_PART += 'AND AEP.[IdAuditor] IN (SELECT Value FROM [dbo].[split](''' + @IdAuditor + ''','','')) '
	IF (@IdAgent IS NOT NULL AND @IdAgent != '') SET @FILTERS_OPTIONAL_PART += 'AND AEP.[IdAgent] IN (SELECT Value FROM [dbo].[split](''' + @IdAgent + ''','','')) '
	IF (@IdCampaign IS NOT NULL AND @IdCampaign != '') SET @FILTERS_OPTIONAL_PART += 'AND AEP.[IdCampaign] IN (SELECT Value FROM [dbo].[split](''' + @IdCampaign + ''','','')) '
	IF (@IdEvaluationPlan IS NOT NULL AND @IdEvaluationPlan != '') SET @FILTERS_OPTIONAL_PART += 'AND EP.[ID] IN (SELECT Value FROM [dbo].[split](''' + @IdEvaluationPlan + ''','','')) '
	IF (CAST(@EvaluationHourFrom AS TIME) <= CAST(@EvaluationHourTo AS TIME)) SET @FILTERS_OPTIONAL_PART += 'AND CAST(ER.[EvaluationDate] AS TIME) BETWEEN ''' + @EvaluationHourFrom + ''' AND ''' + @EvaluationHourTo + ''' '
	IF (CAST(@EvaluationHourFrom AS TIME) > CAST(@EvaluationHourTo AS TIME)) SET @FILTERS_OPTIONAL_PART += 'AND CAST(ER.[EvaluationDate] AS TIME) NOT BETWEEN ''' + @EvaluationHourTo + ''' AND ''' + @EvaluationHourFrom + ''' '
	IF (@InteractionMinDuration IS NOT NULL) SET @FILTERS_OPTIONAL_PART += 'AND AEP.[InteractionDuration] >= ' + (SELECT CONVERT(varchar(10), @InteractionMinDuration)) + ' '
	IF (@InteractionMaxDuration IS NOT NULL) SET @FILTERS_OPTIONAL_PART += 'AND AEP.[InteractionDuration] <= ' + (SELECT CONVERT(varchar(10), @InteractionMaxDuration))+ ' '
	IF (@InteractionOrigins IS NOT NULL AND @InteractionOrigins != '') SET @FILTERS_OPTIONAL_PART += 'AND AEP.[InteractionOrigin] IN (SELECT Value FROM [dbo].[split](''' + @InteractionOrigins + ''','','')) '
	--IF (@InteractionResults IS NOT NULL AND @InteractionResults != '') SET @FILTERS_OPTIONAL_PART += 'AND CONCAT(AEP.[IdCampaign], ''_'', AEP.[ManagementResult]) IN (SELECT Value FROM [dbo].[split](''' + @InteractionResults + ''','','')) '
	IF (@InteractionResults IS NOT NULL AND @InteractionResults != '') 
		SET @FILTERS_OPTIONAL_PART += 'AND (
								(CONCAT(AEP.[IdCampaign], ISNULL(REPLACE(AEP.[ManagementResult], ''/'', ''_''), ''_'')) IN (SELECT Value FROM [dbo].[split](''' + @InteractionResults + ''','','')))
								OR
								(CONCAT(AEP.[IdCampaign], ''_'', ISNULL(AEP.[ManagementResult], ''_'')) IN (SELECT Value FROM [dbo].[split](''' + @InteractionResults + ''','','')))
								OR
								(AEP.[ManagementResult] IN (SELECT Value FROM [dbo].[split](''' + @InteractionResults + ''','','')))
							)'
	
	IF (@EvaluationTypes IS NOT NULL AND @EvaluationTypes != '') 
	BEGIN
		SET @FILTERS_OPTIONAL_PART += '
				AND EP.[Evaluation_Mode] IN (SELECT Value FROM [dbo].[split](''' + @EvaluationTypes + ''','',''))  '
	END

	IF(@ContactAddress <> '')
		BEGIN
			SET @FILTERS_OPTIONAL_PART += '
				AND AEP.[ContactAddress] LIKE ''%' + @ContactAddress + '%''
			'
	END	
	
	IF (@SentimentIds IS NOT NULL AND @SentimentIds <> '')
        BEGIN            
	        SET @FILTERS_OPTIONAL_PART=' AND C.[SentimentId] IN (SELECT Value FROM [dbo].[split](''' + @SentimentIds + ''','','')) '
        END
	
	IF (@InteractionTags IS NOT NULL AND @InteractionTags != '') 
	BEGIN
		SET @SQL_FROM += '
			LEFT JOIN [Tag] T (NOLOCK) 
				ON (T.[VCC] = ER.[Instance] 
					AND T.[Tag] IN (SELECT Value FROM [dbo].[split](''' + @InteractionTags + ''','',''))) '
		SET @FILTERS_OPTIONAL_PART += '
				AND T.[AudioId] LIKE CONCAT(AEP.[IdInteraction], ''%'') 
				AND T.[AudioId] IS NOT NULL '
	END
	
	--IF (@InteractionFormats IS NOT NULL AND @InteractionFormats != '') SET @FILTERS_OPTIONAL_PART += 'AND AEP.[InteractionFormat] IN (SELECT Value FROM [dbo].[split](''' + @InteractionFormats + ''','','')) '

	
	IF (@InteractionIds IS NOT NULL AND @InteractionIds <> '')
    BEGIN
        SET @FILTERS_OPTIONAL_PART = ''
	    SET @FILTERS_EXCLUDING_PART += ' AND AEP.[IdInteraction] IN (SELECT Value FROM [dbo].[split](''' + @InteractionIds + ''','','')) '
	END

	SET @SQL_EXTRA += '
			GROUP BY AEP.Completed,
						AEP.[StatusDescription],
						A.[ErrorMessage],
						AEP.score,
						AEP.IdAuditor,
						U.FirstName + '' '' + U.LastName,
						AEP.IdEvaluationPlan,
						EP.Description,
						EP.[Evaluation_Mode],
						AEP.idAgent,
						C.[AgentName],
						AEP.idInteraction,
						AEP.InteractionDate,
						AEP.InteractionType,
						AEP.IdCampaign, 
						E.[Type],
						ERV.[InteractionId],
						C.SentimentId'

	IF @InteractionCoached IS NOT NULL AND @InteractionCoached != ''
	BEGIN
		IF @InteractionCoached = 'true'
			SET @SQL_EXTRA += '
				HAVING COUNT(ERC.[Id]) >= 1 '
		ELSE 
			SET @SQL_EXTRA += '
				HAVING COUNT(ERC.[Id]) = 0 '
	END

	SET @SQL_EXTRA += '
			ORDER BY MAX(ER.EvaluationDate) DESC '

	SET @SQL_SELECT_1 += @SQL_FROM  + @FILTERS_FIXED_PART + @FILTERS_OPTIONAL_PART + @FILTERS_EXCLUDING_PART + @SQL_EXTRA 
	--print(@SQL_SELECT_1)
	--SELECT @SQL_SELECT_1
	EXEC (@SQL_SELECT_1)
	
END
GO
PRINT N'Actualizando [dbo].[SaveVcc]...';


GO
EXECUTE sp_refreshsqlmodule N'[dbo].[SaveVcc]';


GO
PRINT N'Actualizando [dbo].[DeleteEvaluationFormat]...';


GO
EXECUTE sp_refreshsqlmodule N'[dbo].[DeleteEvaluationFormat]';


GO
PRINT N'Actualización completada.';


GO
