PRINT N'Altering Function [dbo].[SplitString]...';


GO
ALTER FUNCTION [dbo].[SplitString] (
    @String Varchar(MAX) = '', @Delimiter Char(1) = 'Ã‚Â§'
)
RETURNS @Parts TABLE (value Varchar(500))
AS
BEGIN

    IF @String IS NULL RETURN
    
    DECLARE	@Start INT,
    		@Pos INT
    		
    if SUBSTRING(@String, 1, 1) = @Delimiter 
		BEGIN
    	SET	@Start = 2
    	INSERT INTO @Parts
    	VALUES (NULL)
		END
    ELSE 
    	SET	@Start = 1
    	
    WHILE 1=1
		BEGIN
		
    	SET	@Pos = CHARINDEX(@Delimiter, @String, @Start)
    	
    	IF @Pos = 0
    		SET	@Pos = LEN(@String) + 1
    		
    	IF @Pos - @Start > 0			
    		INSERT INTO @Parts
    		VALUES (LTRIM(RTRIM(SUBSTRING(@String, @Start, @Pos - @Start))))
    		
    	ELSE
    		INSERT INTO @Parts
    		VALUES (NULL)
    		
    	SET	@Start = @Pos + 1
    	
    	IF @Start > LEN( @String ) 
    		BREAK
    		
		END
		
    RETURN

END
GO
PRINT N'Altering Function [dbo].[SplitStringXML]...';


GO
ALTER FUNCTION [dbo].[SplitStringXML] (
    @String Varchar(MAX) = '', @Delimiter Char(1) = 'Ã‚Â§'
)
RETURNS @Parts TABLE (value Varchar(500))
AS
BEGIN
	DECLARE @X xml
	SELECT @X = CONVERT(xml,'<root><s>'+ REPLACE(@String,@Delimiter,'</s> <s>')+ '</s></root>')
	
	insert into @Parts (value)
	SELECT T.c.value('.','varchar(500)')
	FROM @X.nodes('/root/s') T(c)
		
    RETURN

END
GO
PRINT N'Altering Procedure [dbo].[DeleteAbility]...';


GO
ALTER PROCEDURE [dbo].[DeleteAbility] (
	@Instance Varchar(50) = NULL, @ID Varchar(50) = NULL
	)
AS
BEGIN
	SET NOCOUNT ON

	-- INICIAMOS UN TRY PARA EL CASO CAIGA EN CATCH HAGAMOS ROLLBACK
    BEGIN TRY

		-- INICIAMOS LA TRANSACCION
		BEGIN TRANSACTION
			-- VERIFICAMOS SI LA HABILIDAD ESTA RELACIONADO A ALGUN FORMATO EN USO
			IF EXISTS (
				SELECT * FROM [dbo].[AbilityEvaluationFormat] 
					WHERE IdAbility = @ID
			)	
				RAISERROR('DATABABASE_ERROR_ABILITY_FIELD_ON_USE', 16, 16)

			-- ELIMINAMOS LO ITEMS ASOCIADOS A LOS SCORES
			DECLARE RECURRENT_CURSOR CURSOR 
			LOCAL STATIC READ_ONLY FORWARD_ONLY
			FOR 
			-- SELECCIONAMOS LOS VCC EXISTENTES
			SELECT [ID]
				FROM [Score]
				WHERE [Instance] = @Instance
					AND [IdAbility] = @ID 
			
			-- DECLARARAMOS UNA VARIABLE PARA INDICAR EL SCORE ACTUAL QUE ESTAMOS ELIMINANDO
			DECLARE @CURRENT_SCORE_TO_REMOVE VARCHAR(50) = ''

			-- ABRIMOS Y RECORREMOS EL ARRAY DE CAMPOS A ACTUALIZAR
			OPEN RECURRENT_CURSOR

			FETCH NEXT FROM RECURRENT_CURSOR INTO @CURRENT_SCORE_TO_REMOVE
			WHILE @@FETCH_STATUS = 0
			BEGIN
				-- ELIMINAMOS LOS REGISTROS DE SCORETIPIFICATION
				DELETE [ScoreTipificationItem] 
					WHERE [VCC] = @Instance
						AND [ScoreId] = @CURRENT_SCORE_TO_REMOVE

				-- ELIMINAMOS LOS REGISTROS DE SCORETIPIFICATION
				DELETE [ScoreTipification] 
					WHERE [VCC] = @Instance
						AND [ScoreId] = @CURRENT_SCORE_TO_REMOVE

				-- ELIMINAMOS LOS REGISTROS DE SCORE
				DELETE [Score]
					WHERE [Instance] = @Instance
						AND [IdAbility] = @ID 
						
				FETCH NEXT FROM RECURRENT_CURSOR INTO @CURRENT_SCORE_TO_REMOVE
			END
			CLOSE RECURRENT_CURSOR
			DEALLOCATE RECURRENT_CURSOR

			-- ELIMINAMOS LOS REGISTROS ABILITYQUERY
			DELETE [AbilityQuery] 
				WHERE [VCC] = @Instance 
					AND [AbilityId] = @ID

			-- ELIMINAMOS EL REGISTRO ABILITY
			DELETE [Ability] 
				WHERE [Instance] = @Instance
					AND [ID] = @ID

			DELETE [AbilityScoreCard] 
				WHERE [VCC] = @Instance
					AND [ID] = @ID

			SELECT 1 AS 'result'

		-- COMPLETAMOS LA TRANSACCION
		COMMIT TRANSACTION

    END TRY
    BEGIN CATCH
        IF @@TRANCOUNT > 0 ROLLBACK TRANSACTION

        DECLARE @Message nvarchar(2048) = ERROR_MESSAGE()
        DECLARE @Severity integer = ERROR_SEVERITY()
        DECLARE @State integer = ERROR_STATE()

        RAISERROR(@Message, @Severity, @State)
        RETURN -1
    END CATCH
    
    SET NOCOUNT OFF
END
GO
PRINT N'Altering Procedure [dbo].[DeleteCustomField]...';


GO
ALTER PROCEDURE [dbo].[DeleteCustomField] (
	@VCC VARCHAR(50) = NULL, 				
	@CustomFieldId VARCHAR(100) = NULL
) AS
BEGIN
	SET XACT_ABORT, NOCOUNT ON;

	-- INICIAMOS UN TRY PARA EL CASO CAIGA EN CATCH HAGAMOS ROLLBACK
    BEGIN TRY
        
		-- INICIAMOS LA TRANSACCION
		BEGIN TRANSACTION

		-- VERIFICAMOS SI EL CUSTOMFIELD ESTA RELACIONADO A ALGUN FORMATO EN USO
		IF EXISTS (
			SELECT DISTINCT EFCF.[CustomFieldId] 'customFieldId'
				FROM [dbo].[EvaluationFormatCustomField] EFCF (NOLOCK)
				WHERE EFCF.[VCC] = @VCC 
					AND EFCF.[CustomFieldId] = @CustomFieldId
		)	
			RAISERROR('DATABABASE_ERROR_CUSTOM_FIELD_ON_USE', 16, 16)

		-- ELIMINAMOS LOS RESULTS DEL CUSTOM FIELD
		DELETE FROM [dbo].[CustomFieldResult] 
			WHERE [VCC] = @VCC 
				AND [CustomFieldId] = @CustomFieldId

		-- ELIMINAMOS EL CUSTOM FIELD
		DELETE FROM [dbo].[CustomField]
			WHERE [VCC] = @VCC 
				AND [ID] = @CustomFieldId
		
		-- RETORNAMOS RESULTADO 1
		SELECT 1 'result'

		-- COMPLETAMOS LA TRANSACCION
		COMMIT TRANSACTION

    END TRY
    BEGIN CATCH
        IF @@TRANCOUNT > 0 ROLLBACK TRANSACTION

        DECLARE @Message nvarchar(2048) = ERROR_MESSAGE()
        DECLARE @Severity integer = ERROR_SEVERITY()
        DECLARE @State integer = ERROR_STATE()

        RAISERROR(@Message, @Severity, @State)
        RETURN -1
    END CATCH
	
	SET NOCOUNT OFF
END
GO
PRINT N'Altering Procedure [dbo].[DeleteGroup]...';


GO
ALTER PROCEDURE [dbo].[DeleteGroup] (
	@Instance Varchar(50) = NULL, @ID Varchar(50) = NULL
	)
AS
BEGIN
	SET NOCOUNT ON
	
	-- INICIAMOS UN TRY PARA EL CASO CAIGA EN CATCH HAGAMOS ROLLBACK
    BEGIN TRY
        
		-- INICIAMOS LA TRANSACCION
		BEGIN TRANSACTION

		-- VERIFICAMOS SI EL CUSTOMFIELD ESTA RELACIONADO A ALGUN FORMATO EN USO
		IF EXISTS (
			SELECT * FROM [dbo].[AbilityEvaluationFormat] 
				WHERE IdGroup = @ID
		)	
			RAISERROR('DATABABASE_ERROR_GROUP_FIELD_ON_USE', 16, 16)

		DELETE FROM [Group]
		WHERE [Instance] = @Instance
		AND [ID] = @ID

		SELECT 1 AS 'result'

		COMMIT TRANSACTION

	END TRY
	BEGIN CATCH
        IF @@TRANCOUNT > 0 ROLLBACK TRANSACTION

        DECLARE @Message nvarchar(2048) = ERROR_MESSAGE()
        DECLARE @Severity integer = ERROR_SEVERITY()
        DECLARE @State integer = ERROR_STATE()

        RAISERROR(@Message, @Severity, @State)
        RETURN -1
    END CATCH
	
	SET NOCOUNT OFF
END
GO
PRINT N'Altering Procedure [dbo].[DeleteSubGroup]...';


GO
ALTER PROCEDURE [dbo].[DeleteSubGroup] (
	@Instance Varchar(50) = NULL, @ID Varchar(50) = NULL
	)
AS
BEGIN
	SET NOCOUNT ON
	
	-- INICIAMOS UN TRY PARA EL CASO CAIGA EN CATCH HAGAMOS ROLLBACK
    BEGIN TRY
        
		-- INICIAMOS LA TRANSACCION
		BEGIN TRANSACTION

		-- VERIFICAMOS SI EL CUSTOMFIELD ESTA RELACIONADO A ALGUN FORMATO EN USO
		IF EXISTS (
			SELECT * FROM [dbo].[AbilityEvaluationFormat] 
				WHERE IdSubGroup = @ID
		)	
			RAISERROR('DATABABASE_ERROR_SUBGROUP_FIELD_ON_USE', 16, 16)

		DELETE FROM [SubGroup]
		WHERE [Instance] = @Instance
		AND [ID] = @ID

		SELECT 1 AS 'result'

		COMMIT TRANSACTION

	END TRY
	BEGIN CATCH
        IF @@TRANCOUNT > 0 ROLLBACK TRANSACTION

        DECLARE @Message nvarchar(2048) = ERROR_MESSAGE()
        DECLARE @Severity integer = ERROR_SEVERITY()
        DECLARE @State integer = ERROR_STATE()

        RAISERROR(@Message, @Severity, @State)
        RETURN -1
    END CATCH
	
	SET NOCOUNT OFF
END
GO
PRINT N'Altering Procedure [dbo].[GetIntents]...';


GO
ALTER PROCEDURE [dbo].[GetIntents] (
	@VCC Varchar(50) = NULL, 
	@AppId VARCHAR(100) = NULL,
	@SearchCriteria Varchar(50) = NULL, 
	@SearchExpression Varchar(50) = NULL,
	@Intents NVARCHAR(MAX)
	)
AS
BEGIN
	
	DECLARE @COGNITIVE_ENGINE VARCHAR(5) = NULL
	DECLARE @SQL NVARCHAR(MAX)

	-- DETERMINAMOS EL MOTOR COGNITIVO DEL VCC
	SELECT @COGNITIVE_ENGINE = N.[CognitiveEngine]
		FROM [dbo].[NLU] N (NOLOCK)
		WHERE N.[VCC] = @VCC
			AND N.[AppId] = @AppId
	
	SET @SQL = '
	SET NOCOUNT ON
	SELECT  IT.[Name]						    ''name'',
	        IT.[AppId]                          ''appId'',
			IT.[IntentId]						''intentId'',
			IT.[Color]							''color'',
			IT.[CreatedDate]					''createdDate'',
			IT.[CreatedByUserId]				''createdByUserId'',
			IT.[LastModifiedDate]				''lastModifiedDate'',
			IT.[LastModifiedByUserId]			''lastModifiedByUserId'',
			IT.[Status]                         ''status'',
			IT.[StatusCode]                     ''statusCode'',
			COUNT(U.[IntentId])				    ''totalUtterances''
		FROM [dbo].[Intent] IT (NOLOCK) 
		LEFT JOIN [dbo].[Utterance] U (NOLOCK) 
			ON IT.[VCC] = U.[VCC]
				AND IT.[IntentId] = U.[IntentId]
		WHERE IT.[VCC] = ''' + @VCC + '''
			AND IT.[AppId] = ''' + @AppId + ''' '

	-- PARA NLUS DE LUIS, FILTRAMOS SEGUN EL INPUT
	IF @COGNITIVE_ENGINE = 'LUIS'
	BEGIN
		SET @SQL +=	'
			AND IT.[IntentId] IN (''' + @Intents + ''') '
	END

	IF @SearchCriteria IS NOT NULL AND @SearchExpression IS NOT NULL
	BEGIN
		SET @SQL +=	'
			AND ISNULL(IT.[Name], '''') LIKE CASE WHEN ''' + @SearchCriteria + ''' = ''name'' THEN ''%' + @SearchExpression + '%'' ELSE ''%'' END '
	END

	SET @SQL +=	'
		GROUP BY IT.[IntentId]
				,IT.[Name]
				,IT.[AppId]
				,IT.[Color]
				,IT.[CreatedDate]
				,IT.[CreatedByUserId]
				,IT.[LastModifiedDate]
				,IT.[LastModifiedByUserId]
				,IT.[Status]  
				,IT.[StatusCode] 
		ORDER BY IT.[LastModifiedDate] ASC, IT.[Name] DESC '

	SET @SQL += ' 
	SET NOCOUNT OFF'

	EXEC(@SQL)
END
GO
PRINT N'Altering Procedure [dbo].[GetProcessFiltersData]...';


GO
ALTER PROCEDURE [dbo].[GetProcessFiltersData] ( 
	@VCC VARCHAR(50) = NULL, 
	@ProcessId VARCHAR(50) = NULL
)
AS
BEGIN
	-- ELIMINAMOS LA TABLA TEMPORAL EN CASO EXISTA
	DROP TABLE IF EXISTS  #ProcessFiltersData 

	-- CREAMOS LA TABLA TEMPORAL PARA LOS RESUMENES
	CREATE TABLE #ProcessFiltersData (
		[Channel] VARCHAR(50),
		[Campaign] VARCHAR (50),
		[AgentId] VARCHAR(50),
		[AgentName] VARCHAR(100),
		[DispositionCode] VARCHAR(50),
		[Category1] VARCHAR(100),
		[Category2] VARCHAR(100),
		[Category3] VARCHAR(100),
		[Description] VARCHAR(100),
	)
	
	-- CONSULTAMOS DATA DE LA TABLA
	--SELECT * FROM INFORMATION_SCHEMA.COLUMNS WHERE TABLE_NAME = 'AsyncInteraction' AND COLUMN_NAME IN ('Agent', 'AgentName', 'FirstTakedAgent', 'FirstTakedAgentName', 'LastTakedAgent', 'LastTakedAgentName')
	--SELECT * FROM INFORMATION_SCHEMA.COLUMNS WHERE TABLE_NAME = 'Audio' AND COLUMN_NAME IN ('Category1', 'Category2', 'Category3', 'Description', 'DispositionCode')

	-- INSERTAMOS LA DATA DE AUDIOS
	INSERT INTO #ProcessFiltersData
		SELECT 'CALL',
				A.[Campaign],
				A.[Agent],
				A.[AgentName],
				A.[DispositionCode],
				A.[Category1],
				A.[Category2],
				A.[Category3],
				A.[Description]
			FROM [dbo].[ProcessAudio] PA (NOLOCK) 
			INNER JOIN [Audio] A (NOLOCK)
				ON A.[VCC] = PA.[VCC]
					AND A.[ID] = PA.[AudioId]
					AND A.[Section] = PA.[Section]
					AND A.[Part] = PA.[Part]
			WHERE PA.[VCC] = @VCC
				AND PA.[ProcessId] = @ProcessId

	-- INSERTAMOS LA DATA DE TEXTOS
	INSERT INTO #ProcessFiltersData
		SELECT AI.[Channel],
				AI.[Campaign],
				ISNULL(AI.[LastTakedAgent], AI.[FirstTakedAgent]),
				ISNULL(AI.[LastTakedAgentName], AI.[FirstTakedAgentName]),
				AI.[DispositionCode],
				NULL,--AI.[Category1],
				NULL,--AI.[Category2],
				NULL,--AI.[Category3],
				NULL--AI.[Description]
			FROM [dbo].[ProcessAsyncInteraction] PAI (NOLOCK) 
			INNER JOIN [AsyncInteraction] AI (NOLOCK)
				ON AI.[VCC] = PAI.[VCC] 
					AND AI.[ID] = PAI.[InteractionId]
					AND AI.[Folder] = PAI.[FormattedEndDate]
					AND AI.[Campaign] = PAI.[Campaign]
			WHERE PAI.[VCC] = @VCC
				AND PAI.[ProcessId] = @ProcessId

	-- SELECCIONAMOS AGRUPADO POR FILTRO
	SELECT [Channel] 'channel' FROM #ProcessFiltersData GROUP BY [Channel] ORDER BY [Channel] ASC
	SELECT [Campaign] 'campaignId' FROM #ProcessFiltersData GROUP BY [Campaign] ORDER BY [Campaign] ASC
	SELECT [AgentId] 'agentId', 
			[AgentName] 'agentName'
		FROM #ProcessFiltersData 
		GROUP BY [AgentId], [AgentName] 
		ORDER BY [AgentId], [AgentName] ASC
	SELECT [DispositionCode]	'dispositionCode',
			[Category1]			'description',
			[Category2]			'description2',
			[Category3]			'description3',
			[Description]		'description4'
		FROM #ProcessFiltersData 
		GROUP BY [DispositionCode], [Category1], [Category2], [Category3], [Description] 
		ORDER BY [DispositionCode], [Category1], [Category2], [Category3], [Description]

	-- ELIMINAMOS LA TABLA TEMPORAL
	DROP TABLE #ProcessFiltersData 

END
GO
PRINT N'Creating Procedure [dbo].[DeleteAbilities]...';


GO
CREATE PROCEDURE [dbo].[DeleteAbilities] (
	@Instance Varchar(50) = NULL,
	@AbilityIDs Varchar(MAX) = NULL
	)
AS
BEGIN
	SET NOCOUNT ON
		
    DECLARE @_IDS TABLE(ID VARCHAR(50))

    INSERT INTO @_IDS SELECT [Value] FROM [dbo].[Split](@AbilityIDs,',')

    -- ELIMINAMOS LO ITEMS ASOCIADOS A LOS SCORES
    DECLARE RECURRENT_CURSOR CURSOR 
    LOCAL STATIC READ_ONLY FORWARD_ONLY
    FOR 
    -- SELECCIONAMOS LOS VCC EXISTENTES
    SELECT [ID]
        FROM [Score]
        WHERE [Instance] = @Instance
            AND  [IdAbility] IN (SELECT [ID] FROM @_IDS)
    
    -- DECLARARAMOS UNA VARIABLE PARA INDICAR EL SCORE ACTUAL QUE ESTAMOS ELIMINANDO
    DECLARE @CURRENT_SCORE_TO_REMOVE VARCHAR(50) = ''

    -- ABRIMOS Y RECORREMOS EL ARRAY DE CAMPOS A ACTUALIZAR
    OPEN RECURRENT_CURSOR

    FETCH NEXT FROM RECURRENT_CURSOR INTO @CURRENT_SCORE_TO_REMOVE
    WHILE @@FETCH_STATUS = 0
    BEGIN
        -- ELIMINAMOS LOS REGISTROS DE SCORETIPIFICATION
        DELETE [ScoreTipificationItem] 
            WHERE [VCC] = @Instance
                AND [ScoreId] = @CURRENT_SCORE_TO_REMOVE

        -- ELIMINAMOS LOS REGISTROS DE SCORETIPIFICATION
        DELETE [ScoreTipification] 
            WHERE [VCC] = @Instance
                AND [ScoreId] = @CURRENT_SCORE_TO_REMOVE

        -- ELIMINAMOS LOS REGISTROS DE SCORE
        DELETE [Score]
            WHERE [Instance] = @Instance
                AND  [IdAbility] IN (SELECT [ID] FROM @_IDS)
                
        FETCH NEXT FROM RECURRENT_CURSOR INTO @CURRENT_SCORE_TO_REMOVE
    END
    CLOSE RECURRENT_CURSOR
    DEALLOCATE RECURRENT_CURSOR

    -- ELIMINAMOS LOS REGISTROS ABILITYQUERY
    DELETE [AbilityQuery] 
        WHERE [VCC] = @Instance 
            AND  [AbilityId] IN (SELECT [ID] FROM @_IDS)

    -- ELIMINAMOS EL REGISTRO ABILITY
    DELETE [Ability] 
        WHERE [Instance] = @Instance
            AND [ID] IN (SELECT [ID] FROM @_IDS)

    DELETE [AbilityScoreCard] 
        WHERE [VCC] = @Instance
            AND [ID] IN (SELECT [ID] FROM @_IDS)

    SELECT 1 AS 'result'
       
    SET NOCOUNT OFF
END
GO
PRINT N'Creating Procedure [dbo].[DeleteCustomFields]...';


GO
CREATE PROCEDURE DeleteCustomFields 
	@VCC VARCHAR(50) = NULL, 				
	@CustomFieldIds VARCHAR(MAX) = NULL
AS
BEGIN
	SET NOCOUNT ON;

    DECLARE @_IDS TABLE(
	 ID VARCHAR(50)
	)

    INSERT INTO @_IDS SELECT [Value] FROM [dbo].[Split](@CustomFieldIds,',')

	-- ELIMINAMOS LOS RESULTS DEL CUSTOM FIELD
	DELETE FROM [dbo].[CustomFieldResult] 
		WHERE [VCC] = @VCC 
			AND [CustomFieldId] IN (SELECT [ID] FROM @_IDS)

	-- ELIMINAMOS EL CUSTOM FIELD
	DELETE FROM [dbo].[CustomField]
		WHERE [VCC] = @VCC 
			AND [ID]  IN (SELECT [ID] FROM @_IDS)
		
	-- RETORNAMOS RESULTADO 1
	SELECT 1 'result'
END
GO
PRINT N'Creating Procedure [dbo].[DeleteGroups]...';


GO

CREATE PROCEDURE [dbo].[DeleteGroups] 
	@Instance VARCHAR(50) = NULL,
	@GroupIDs VARCHAR(MAX) = NULL
AS
BEGIN
	-- SET NOCOUNT ON added to prevent extra result sets from
	-- interfering with SELECT statements.
	SET NOCOUNT ON;

    DECLARE @_IDS TABLE(
	 ID VARCHAR(50)
	)

    INSERT INTO @_IDS SELECT [Value] FROM [dbo].[Split](@GroupIDs,',')

	DELETE FROM [Group]
		WHERE [Instance] = @Instance
		AND [ID] IN (SELECT [ID] FROM @_IDS)   
	SELECT 1 AS 'result'	
END
GO
PRINT N'Creating Procedure [dbo].[DeleteSubGroups]...';


GO

CREATE PROCEDURE [dbo].[DeleteSubGroups] 
	@Instance VARCHAR(50) = NULL,
	@SubGroupIDs VARCHAR(MAX) = NULL
AS
BEGIN
	-- SET NOCOUNT ON added to prevent extra result sets from
	-- interfering with SELECT statements.
	SET NOCOUNT ON;

    DECLARE @_IDS TABLE(
	 ID VARCHAR(50)
	)

    INSERT INTO @_IDS SELECT [Value] FROM [dbo].[Split](@SubGroupIDs,',')

	DELETE FROM [SubGroup]
		WHERE [Instance] = @Instance
		AND [ID] IN (SELECT [ID] FROM @_IDS)
	SELECT 1 AS 'result'	           
END
GO
PRINT N'Creating Procedure [dbo].[GetAbilitiesUsage]...';


GO

CREATE PROCEDURE [dbo].[GetAbilitiesUsage] 
	@Instance VARCHAR(50) = NULL,
	@AbilityIDs VARCHAR(MAX) = NULL
AS
BEGIN
	-- SET NOCOUNT ON added to prevent extra result sets from
	-- interfering with SELECT statements.
	SET NOCOUNT ON;

    DECLARE @_IDS TABLE(
	 ID VARCHAR(50)
	)

    INSERT INTO @_IDS SELECT [Value] FROM [dbo].[Split](@AbilityIDs,',')

	SELECT [IdAbility] 'idAbility'
        FROM [dbo].[AbilityEvaluationFormat] 
		WHERE Instance = @Instance 
			AND IdAbility  IN (SELECT [ID] FROM @_IDS)
    
           
END
GO
PRINT N'Creating Procedure [dbo].[GetCustomFieldsUsage]...';


GO

CREATE PROCEDURE [dbo].[GetCustomFieldsUsage] 
	@VCC VARCHAR(50) = NULL, 				
	@CustomFieldIds VARCHAR(MAX) = NULL
AS
BEGIN
	-- SET NOCOUNT ON added to prevent extra result sets from
	-- interfering with SELECT statements.
	SET NOCOUNT ON;

    DECLARE @_IDS TABLE(
	 ID VARCHAR(50)
	)

    INSERT INTO @_IDS SELECT [Value] FROM [dbo].[Split](@CustomFieldIds,',')

    SELECT  DISTINCT EFCF.[CustomFieldId] 'customFieldId'
        FROM [dbo].[EvaluationFormatCustomField] EFCF (NOLOCK)
        WHERE EFCF.[VCC] = @VCC 
            AND EFCF.[CustomFieldId]  IN (SELECT [ID] FROM @_IDS)
           
END
GO
PRINT N'Creating Procedure [dbo].[GetExistDictionaryWordsSoundLike]...';


GO

CREATE PROCEDURE[dbo].[GetExistDictionaryWordsSoundLike] 
	@VCC					VARCHAR(50) = NULL,
	@DictionaryWordId		VARCHAR(50) = NULL,
	@SoundLikes             VARCHAR(MAX) = NULL
AS
BEGIN
	SET NOCOUNT ON;
	SELECT SoundLike FROM [dbo].[DictionaryWordSoundLike] (NOLOCK)
		WHERE [VCC] = @VCC 
			AND [DictionaryWordId] != @DictionaryWordId
			AND [SoundLike] in (SELECT VALUE FROM STRING_SPLIT(@SoundLikes, ','))
   
END
GO
PRINT N'Creating Procedure [dbo].[GetGroupsUsage]...';


GO

CREATE PROCEDURE [dbo].[GetGroupsUsage] 
	@Instance      VARCHAR(50) = NULL,
	@GroupIDs VARCHAR(MAX) = NULL
AS
BEGIN
	-- SET NOCOUNT ON added to prevent extra result sets from
	-- interfering with SELECT statements.
	SET NOCOUNT ON;

    DECLARE @_IDS TABLE(
	 ID VARCHAR(50)
	)

    INSERT INTO @_IDS SELECT [Value] FROM [dbo].[Split](@GroupIDs,',')

	SELECT [IdGroup] 'idGroup'
        FROM [dbo].[AbilityEvaluationFormat] 
		WHERE Instance = @Instance
			AND IdGroup  IN (SELECT [ID] FROM @_IDS)
    
           
END
GO
PRINT N'Creating Procedure [dbo].[GetSoundLikesFromDictionaryWords]...';


GO

CREATE PROCEDURE[dbo].[GetSoundLikesFromDictionaryWords] 
	@VCC					VARCHAR(50) = NULL,
	@DictionaryWordId		VARCHAR(50) = NULL,
	@SoundLikes             VARCHAR(MAX) = NULL
AS
BEGIN
	SET NOCOUNT ON;
	SELECT [SoundLike] 'soundLike',
		   [Word] 'word'
		FROM [dbo].[DictionaryWordSoundLike] SL (NOLOCK)
		INNER JOIN [dbo].[DictionaryWord] DW (NOLOCK)
			ON SL.DictionaryWordId = DW.ID
		WHERE SL.[VCC] = @VCC 
			AND [DictionaryWordId] != @DictionaryWordId
			AND [SoundLike] in (SELECT VALUE FROM STRING_SPLIT(@SoundLikes, ','))
   
END
GO
PRINT N'Creating Procedure [dbo].[GetSubGroupsUsage]...';


GO

CREATE PROCEDURE [dbo].[GetSubGroupsUsage] 
	@Instance VARCHAR(50) = NULL,
	@SubGroupIDs VARCHAR(MAX) = NULL
AS
BEGIN
	-- SET NOCOUNT ON added to prevent extra result sets from
	-- interfering with SELECT statements.
	SET NOCOUNT ON;

    DECLARE @_IDS TABLE(
	 ID VARCHAR(50)
	)

    INSERT INTO @_IDS SELECT [Value] FROM [dbo].[Split](@SubGroupIDs,',')

	SELECT [IdSubGroup] 'idSubGroup'
        FROM [dbo].[AbilityEvaluationFormat] 
		WHERE Instance = @Instance 
			AND IdSubGroup  IN (SELECT [ID] FROM @_IDS)
    
           
END
GO
PRINT N'Refreshing Procedure [dbo].[GetUniqueNLUByIntents]...';


GO
EXECUTE sp_refreshsqlmodule N'[dbo].[GetUniqueNLUByIntents]';


GO
PRINT N'Refreshing Procedure [dbo].[ReportAuditsByAgent]...';


GO
EXECUTE sp_refreshsqlmodule N'[dbo].[ReportAuditsByAgent]';


GO
PRINT N'Update complete.';


GO
